package com.yipin.liuwanr;

import java.util.ArrayList;
import java.util.List;

import javax.sql.DataSource;

import org.apache.http.HttpHost;
import org.apache.http.auth.AuthScope;
import org.apache.http.auth.Credentials;
import org.apache.http.auth.UsernamePasswordCredentials;
import org.apache.http.client.CredentialsProvider;
import org.apache.http.impl.client.BasicCredentialsProvider;
import org.elasticsearch.client.RestClient;
import org.elasticsearch.client.RestClientBuilder;
import org.elasticsearch.client.RestHighLevelClient;
import org.jboss.logging.Logger;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.springframework.beans.factory.ObjectProvider;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.elasticsearch.rest.RestClientBuilderCustomizer;
import org.springframework.boot.autoconfigure.elasticsearch.rest.RestClientProperties;
import org.springframework.boot.autoconfigure.http.HttpMessageConverters;
import org.springframework.boot.autoconfigure.jdbc.DataSourceProperties;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.PropertyMapper;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.data.redis.connection.RedisConnectionFactory;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.StringRedisSerializer;
import org.springframework.http.MediaType;
import org.springframework.http.converter.HttpMessageConverter;

import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.alibaba.fastjson.support.config.FastJsonConfig;
import com.alibaba.fastjson.support.spring.FastJsonHttpMessageConverter;
import com.yipin.liuwanr.tcpserver.MinaContextManager;
import com.yipin.liuwanr.tcpserver.TimeServerHandler;
import com.zaxxer.hikari.HikariDataSource;

@Configuration
public class AppConfig {

	private static Logger logger = Logger.getLogger(AppConfig.class);

	@Autowired
	DataSourceProperties dataSourceProperties;

	@Value("${spring.mina.port}")
	int port;

	@Value("${spring.mina.buffersize}")
	int buffersize;

	@Value("${spring.mina.idletime}")
	int idletime;

	@Bean(name = "dataSource")
	@Primary
	@ConfigurationProperties(prefix = "spring.datasource")
	DataSource realDataSource() {
		HikariDataSource dataSource = new HikariDataSource();
		dataSource.setDriverClassName(this.dataSourceProperties.getDriverClassName());
		dataSource.setJdbcUrl(this.dataSourceProperties.getUrl());
		dataSource.setUsername(this.dataSourceProperties.getUsername());
		dataSource.setPassword(this.dataSourceProperties.getPassword());
		logger.info("DataSource Bean Created");
		return dataSource;
	}

//	@Bean
//	public SqlSessionFactoryBean sqlSessionFactory() {
//		SqlSessionFactoryBean bean = new SqlSessionFactoryBean();
//		bean.setDataSource(realDataSource());
//		logger.info("SqlSessionFactoryBean Bean Created");
//		return bean;
//	}

	@Bean
	public HttpMessageConverters fastJsonConverters() {
		FastJsonHttpMessageConverter fastJsonConverter = new FastJsonHttpMessageConverter();
		FastJsonConfig fastConf = new FastJsonConfig();
		fastConf.setSerializerFeatures(SerializerFeature.PrettyFormat);
		List<MediaType> fastMediaTypes = new ArrayList<MediaType>();
		fastMediaTypes.add(MediaType.APPLICATION_JSON);
		fastJsonConverter.setSupportedMediaTypes(fastMediaTypes);
		fastJsonConverter.setFastJsonConfig(fastConf);
		HttpMessageConverter<?> converter = fastJsonConverter;
		logger.info("MessageConverter Bean Created");
		return new HttpMessageConverters(converter);
	}

	@Bean
	public RedisSerializer<Object> redisSerializer() {
		logger.info("RedisSerializer Bean Created");
		return new FastJsonRedisSerializer<Object>(Object.class);
	}

	@Bean
	public RedisTemplate<String, Object> redisTemplate(RedisConnectionFactory redisConnectionFactory,
			RedisSerializer<Object> redisSerializer) {
		RedisTemplate<String, Object> redisTemplate = new RedisTemplate<String, Object>();
		redisTemplate.setConnectionFactory(redisConnectionFactory);
		// 全局开启AutoType，不建议使用
		// ParserConfig.getGlobalInstance().setAutoTypeSupport(true);
		// 建议使用这种方式，小范围指定白名单
		ParserConfig.getGlobalInstance().addAccept("com.yipin.liuwanr.entity.");
		redisTemplate.setValueSerializer(redisSerializer);
		redisTemplate.setHashValueSerializer(redisSerializer);
		redisTemplate.setKeySerializer(new StringRedisSerializer());
		redisTemplate.setHashKeySerializer(new StringRedisSerializer());
		redisTemplate.afterPropertiesSet();
		logger.info("RedisTemplate Bean Created");
		return redisTemplate;
	}

	@Bean
	public MinaContextManager minaContextManager() {
		logger.info("MinaContextManager Bean Created");
		MinaContextManager minaContextManager = MinaContextManager.getInstance(port, buffersize, idletime);
		minaContextManager.startServer(serverHandler());
		return minaContextManager;
	}

//	@Bean
//	public FilterRegistrationBean<AuthFilter> authFilterRegistration() {
//		FilterRegistrationBean<AuthFilter> registration = new FilterRegistrationBean<AuthFilter>();
//		registration.setFilter(authFilter());
//		registration.addUrlPatterns("/*");
//		registration.setOrder(6);
//		registration.setName("AuthFilter");
//		logger.info("FilterRegistrationBean Bean Created");
//		return registration;
//	}
//
//	@Bean
//	AuthFilter authFilter() {
//		return new AuthFilter();
//	}

	@Bean
	TimeServerHandler serverHandler() {
		return new TimeServerHandler();
	}

	@Bean
	public RestClientBuilder elasticsearchRestClientBuilder(RestClientProperties properties,
			ObjectProvider<RestClientBuilderCustomizer> builderCustomizers) {
		HttpHost[] hosts = properties.getUris().stream().map(HttpHost::create).toArray(HttpHost[]::new);
		RestClientBuilder builder = RestClient.builder(hosts);
		PropertyMapper map = PropertyMapper.get();
		map.from(properties::getUsername).whenHasText().to((username) -> {
			CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
			Credentials credentials = new UsernamePasswordCredentials(properties.getUsername(),
					properties.getPassword());
			credentialsProvider.setCredentials(AuthScope.ANY, credentials);
			builder.setHttpClientConfigCallback(
					(httpClientBuilder) -> httpClientBuilder.setDefaultCredentialsProvider(credentialsProvider));
		});
		builderCustomizers.orderedStream().forEach((customizer) -> customizer.customize(builder));
		return builder;
	}

	@Bean
	public RestHighLevelClient elasticsearchRestHighLevelClient(RestClientBuilder restClientBuilder) {
		return new RestHighLevelClient(restClientBuilder);
	}
}