package com.yipin.liuwanr.controller;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import com.yipin.liuwanr.entity.Assesment;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.service.AssesmentService;
import com.yipin.liuwanr.vo.AssesmentStudentVo;

@RestController
@RequestMapping("/assesment")
@CrossOrigin
public class AssesmentController {

	@Autowired
	private AssesmentService service;
	
	/**
	 * 考核管理列表
	 * @param className：行政班级名称
	 * @param assesmentState：考核状态
	 * @param releaseType：发布方式
	 * @param creationTime：起始时间
	 * @param endTime：结束时间
	 * @param month：月份
	 * @param pageSize：每页多少条数据
	 * @param pageNo：第几页
	 * @return
	 */
	@GetMapping("/queryAssesmentcondition")
	Response queryAssementCondition(@RequestParam Integer staffId,@RequestParam Integer courseId,@RequestParam String className,
			@RequestParam Integer assesmentState,@RequestParam  Integer releaseType,
			@RequestParam  String creationTime,@RequestParam  String endTime,@RequestParam  Integer month,
			@RequestParam(defaultValue = "0")Integer pageSize,
			@RequestParam(defaultValue = "0")Integer pageNo ) {
		Response resp = new Response();
		Assesment assesment  = new Assesment();
		if(staffId!=null) {
			assesment.setStaffId(staffId);
		}
		if(courseId!=null) {
			assesment.setCourseId(courseId);
		}
		if(className!=null&&className!="") {
		    assesment.setClassName(className);	
		}
		if (assesmentState!=null) {
			assesment.setAssesmentState(assesmentState);
		}
		if (releaseType!=null) {
			assesment.setReleaseType(releaseType);
		}
		if (month!=null) {
			assesment.setMonth(month);
		}
		if (creationTime!=null&&creationTime!="") {
			assesment.setCreationTime(creationTime);
		}
		if (endTime!=null&&endTime!="") {
			assesment.setEndTime(endTime);
		}
		HashMap<String, Object> ret = service.queryAssesmentCondition(assesment, pageNo, pageSize);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}	
		return resp;
	}
	
	
	/**
	 * 创建考核
	 * @param vo
	 * @return
	 */
	@Log("创建考核")
	@PostMapping("/addAssesment")
	Response addAssesment(@RequestBody AssesmentStudentVo vo) {
		Response resp = new Response();
		Assesment assesment=vo.getAssesment();
		List<Integer> studentIds=vo.getStudentIds();
		if(StringUtils.isEmpty(assesment)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else if(studentIds.isEmpty()&&studentIds.size()<=0){
			resp.setStatus(300);
			resp.setErrmessage("学生信息为空");
		}else{
			HashMap<String, Object> ret = service.addAssesment(assesment, studentIds);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	
	/**
	 * 查询选中的学生有哪些正在参与考核
	 * @param studentIds
	 * @return
	 */
	@GetMapping("/queryStudentisAssess")
	Response queryStudentisAssess(@RequestParam List<Integer> studentIds) {
		Response resp = new Response();
		if(studentIds.isEmpty()&&studentIds.size()<=0){
			resp.setStatus(300);
			resp.setErrmessage("学生信息为空");
		}else{
			HashMap<String, Object> ret = service.queryStudentisAssess(studentIds);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 根据id查询考核的信息
	 * @param id
	 * @return
	 */
	@GetMapping("/queryGetById")
	Response getByAssesmentId(@RequestParam Integer id) {
		Response resp = new Response();
		if(StringUtils.isEmpty(id)){
			resp.setStatus(300);
			resp.setErrmessage("项目信息为空");
		}else{
			HashMap<String, Object> ret = service.queryGetById(id);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 修改考核
	 * @param vo
	 * @return
	 */
	@Log("修改考核")
	@PostMapping("/updateAssesment")
	Response updateAssesment(@RequestBody AssesmentStudentVo vo) {
		Response resp = new Response();
		Assesment assesment=vo.getAssesment();
		List<Integer> studentIds=vo.getStudentIds();
		if(StringUtils.isEmpty(assesment)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else if(studentIds.isEmpty()&&studentIds.size()<=0){
			resp.setStatus(300);
			resp.setErrmessage("学生信息为空");
		}else{
			HashMap<String, Object> ret = service.updateAssesment(assesment,studentIds);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 启动考核前的判断
	 * @param assesmentId
	 * @return
	 */
	@GetMapping("/assessmentJudgment")
	Response updateState(@RequestParam Integer assesmentId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.assessmentJudgment(assesmentId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 修改考核状态
	 * @return
	 */
	@Log("修改考核状态")
	@PostMapping("/updateState")
	Response updateState(@RequestBody Assesment assesment) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesment)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.updateState(assesment);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}


	/**
	 * 查询实验班级一级栏目
	 * @param staffId
	 * @return
	 */
	@GetMapping("/getExperimentalClass")
	Response getExperimentalClass(@RequestParam Integer staffId,@RequestParam Integer schoolId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(staffId)){
			resp.setStatus(300);
			resp.setErrmessage("教师信息为空");
		}else if(StringUtils.isEmpty(schoolId)){
			resp.setStatus(300);
			resp.setErrmessage("学校信息为空");
		} else{
			HashMap<String, Object> ret = service.queryCretionTime(staffId,schoolId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}


	/**
	 * 查询实验班级名称，以及班级一下的学生
	 * @param creationTime
	 * @return
	 */
	@GetMapping("/getCreationTime")
	Response getCreationTime(@RequestParam String creationTime,@RequestParam Integer staffId,@RequestParam Integer schoolId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(staffId)){
			resp.setStatus(300);
			resp.setErrmessage("教师信息为空");
		}else if(StringUtils.isEmpty(creationTime)){
			resp.setStatus(300);
			resp.setErrmessage("实验班级创建时间信息为空");
		}else if(StringUtils.isEmpty(schoolId)){
			resp.setStatus(300);
			resp.setErrmessage("学校信息为空");
		}else {
			HashMap<String, Object> ret = service.queryCretionTime(creationTime,staffId,schoolId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	
	/**
	 * 考核信息展示
	 * @param assesmentId
	 * @return
	 */
	@GetMapping("/queryAssesmet")
	Response queryAssesmet(@RequestParam Integer assesmentId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.queryAssesment(assesmentId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	
	/**
	 * 班级筛选
	 * @param assesmentId
	 * @return
	 */
	@GetMapping("/getByclass")
	Response getByclass(@RequestParam Integer assesmentId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.getByclass(assesmentId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	
	
	/**
	 * 成绩概况
	 */
	@GetMapping("/queryClassScore")
	Response queryClassScore(@RequestParam Integer assesmentId,@RequestParam Integer experimentalClassId,@RequestParam Integer classId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.queryScore(assesmentId,experimentalClassId,classId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}

		return resp;
	}


	/**
	 * 成绩分布柱状图
	 * @param assesmentId
	 * @param experimentalClassId
	 * @param classId
	 * @return
	 */
	@GetMapping("/queryHistogram")
	Response queryHistogram(@RequestParam Integer assesmentId,@RequestParam Integer experimentalClassId,@RequestParam Integer classId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else {
			HashMap<String, Object> ret = service.queryHistogram(assesmentId, experimentalClassId, classId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}


	/**
	 * 错误分布折线图
	 * @param assesmentId
	 * @param experimentalClassId
	 * @param classId
	 * @return
	 */
	@GetMapping("/getLinechart")
	Response getLinechart(@RequestParam Integer assesmentId,@RequestParam Integer experimentalClassId,@RequestParam Integer classId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.getLinechart(assesmentId,experimentalClassId,classId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}


    /**
     * 成绩明细
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
	@GetMapping("/queryAssesmentScore")
	Response queryAssesmentScore(@RequestParam Integer assesmentId,@RequestParam Integer experimentalClassId,@RequestParam Integer classId) {
		Response resp = new Response();
		if(StringUtils.isEmpty(assesmentId)){
			resp.setStatus(300);
			resp.setErrmessage("考核信息为空");
		}else{
			HashMap<String, Object> ret = service.queryAssesmentScore(assesmentId,experimentalClassId,classId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}


	/**
	 * 发布考核
	 * @param courseId
	 * @return
	 */
	@Log("发布考核")
	@GetMapping("/releaseAssesment")
	Response releaseAssesment(@RequestParam  Integer courseId){
		Response resp = new Response();

		HashMap<String, Object> ret = service.releaseAssesment(courseId);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}

		return resp;
	}

	@Log("删除考核")
    @PostMapping("/deleteAssesment")
    Response deleteAssesment(@RequestBody Assesment assesment){
        Response resp = new Response();
		Integer assesmentId=assesment.getId();
        if(StringUtils.isEmpty(assesmentId)){
            resp.setStatus(300);
            resp.setErrmessage("考核信息为空");
        }else{
            HashMap<String, Object> ret = service.deleteAssesment(assesmentId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    @GetMapping("/isNameExistis")
    Response isNameExistis(@RequestParam  String assesmentName){
        Response resp = new Response();
        if(StringUtils.isEmpty(assesmentName)){
            resp.setStatus(300);
            resp.setErrmessage("考核信息为空");
        }else{
            HashMap<String, Object> ret = service.isNameExistis(assesmentName);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }


	@GetMapping("/getByCourseId")
	Response getByCourseId(@RequestParam  Integer courseId){
		Response resp = new Response();
		HashMap<String, Object> ret = service.getByCourseId(courseId);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

}

