package com.yipin.liuwanr.controller;

import java.io.IOException;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.tcpserver.MinaSessionManager;

import com.yipin.liuwanr.helper.ElasticHelper;

@RestController
public class BaseController {

	@Autowired
	private RedisHelper redisHelper;

	@Autowired
	private ElasticHelper elasticHelper;

	private static Logger logger = Logger.getLogger(BaseController.class);

	@RequestMapping("/")
	String hello() {
		return "Liuwanr Backend Index!";
	}

	@RequestMapping("/test/redis/get/{key}")
	String getRedis(@PathVariable("key") String key) {
		return redisHelper.get(key).toString();
	}

	@RequestMapping("/test/redis/set/{key}")
	String putRedis(@PathVariable("key") String key, @RequestParam("value") String value) {
		redisHelper.set(key, value);
		return "SUCCESS";
	}

	@RequestMapping("/test/elastic/get/{key}")
	String getElastic(@PathVariable("key") String key) {
		String ret = "ERROR";
		try {
			ret = elasticHelper.get(key);
		} catch (IOException e) {
			logger.error(e.getMessage());
		}
		return ret;
	}

	@RequestMapping("/test/elastic/set/{key}")
	String putElastic(@PathVariable("key") String key, @RequestParam("value") String value, @RequestParam(value="ts", required = false, defaultValue = "0") long timestamp) {
		String ret = "SUCCESS";
		try {
			switch (key) {
			case "_create":
				elasticHelper.create(value);
				break;
			case "_delete":
				elasticHelper.delete(value);
				break;
			default:
				elasticHelper.set(key, value, timestamp);
				break;
			}
		} catch (IOException e) {
			logger.error(e.getMessage());
			ret = "ERROR";
		}
		return ret;
	}

	@RequestMapping("/test/tcp/put/{key}/{msg}")
	String putTcpMessage(@PathVariable("key") String key, @PathVariable("msg") String msg) {
		MinaSessionManager.getSessionByDevice(key).write(msg.replace("-", "|") + "\r");
		return "SUCCESS";
	}
}
