package com.yipin.liuwanr.controller;

import com.yipin.liuwanr.entity.Customer;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.entity.School;
import com.yipin.liuwanr.entity.UserM;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.CustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.HashMap;

@RestController
@RequestMapping("/customer")
@CrossOrigin
public class CustomerController {

    @Autowired
    private CustomerService customerService;

    @Autowired
    RedisHelper redisHelper;

    /**
     * 添加客户
     */
    @PostMapping("/addCustomer")
    Response addCustomer(@RequestBody @Valid Customer customer) {
        Response resp = new Response();
        UserM userm = new UserM();
        Integer provinceId = customer.getProvinceId();
        Integer cityId = customer.getCityId();
        String countries = customer.getCountries();
        String phone = customer.getAdminPhone();
        String email = customer.getEmail();
        String name = customer.getAdminName();
        Integer schoolId = customer.getSchoolId();
        userm.setSchoolId(schoolId);
        userm.setCityId(cityId);
        userm.setCountries(countries);
        userm.setProvinceId(provinceId);
        userm.setPhone(phone);
        userm.setEmail(email);
        userm.setName(name);
        userm.setPassword("huoran123");
        if (email == null || email == "") {
            resp.setStatus(300);
            resp.setErrmessage("邮箱不能为空！");
        }
        if (phone == null || phone == "") {
            resp.setStatus(300);
            resp.setErrmessage("电话不能为空！");
        } else if (name == null || name == "") {
            resp.setStatus(300);
            resp.setErrmessage("姓名不能为空！");
        } else if (schoolId == null) {
            resp.setStatus(300);
            resp.setErrmessage("学校不能为空！");
        } else if (provinceId == null) {
            resp.setStatus(300);
            resp.setErrmessage("省份不能为空！");
        } else if (cityId == null) {
            resp.setStatus(300);
            resp.setErrmessage("城市不能为空！");
        } else {
            HashMap<String, Object> ret = customerService.addCustomer(customer);
            HashMap<String, Object> ret1 = customerService.addAdmin(userm);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 查询客户
     */
    @GetMapping("/queryCustomer")
    Response queryCustomer(@RequestParam String countries, Integer provinceId, Integer cityId, Integer pageNo, Integer pageSize, String searchContent) {
        Response resp = new Response();
        Customer customer = new Customer();
        if (searchContent != null && searchContent != "") {
            customer.setSearchContent(searchContent);
        }
        if (countries != null && countries != "") {
            customer.setCountries(countries);
        }
        if (provinceId != null) {
            customer.setProvinceId(provinceId);
        }
        if (cityId != null) {
            customer.setCityId(cityId);
        }
        HashMap<String, Object> ret = customerService.queryCustomer(customer, pageNo, pageSize);
        int status = (int) ret.get("retcode");
        if (200 == status) {
            resp.setStatus(status);
            resp.setMessage(ret.get("retvalue"));
        } else {
            resp.setStatus(status);
            resp.setErrmessage(ret.get("retvalue").toString());
        }
        return resp;
    }

    /**
     * 查询客户详情
     */
    @GetMapping("/queryCustomerDetails")
    Response queryCustomerDetails(@RequestParam Integer customerId) {
        Response resp = new Response();
        if (customerId == null) {
            resp.setStatus(300);
            resp.setErrmessage("Parameter Invalid");
        } else {
            HashMap<String, Object> ret = customerService.queryCustomerDetails(customerId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 删除客户
     */
    @PostMapping("/deleteCustomer")
    Response deleteCustomer(@RequestBody Customer customer) {
        Response resp = new Response();
        if (customer.getCustomer().isEmpty()) {
            resp.setStatus(300);
            resp.setErrmessage("客户不能为空！");
        } else {
            HashMap<String, Object> ret = customerService.deleteCustomer(customer);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 更新客户
     */
    @PostMapping("/updateCustomer")
    Response updateCustomer(@RequestBody Customer customer) {
        Response resp = new Response();
        if (customer.getCustomerId() == null) {
            resp.setStatus(300);
            resp.setErrmessage("客户不能为空！");
        } else {
            HashMap<String, Object> ret = customerService.updateCustomer(customer);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 查询客户是否存在
     */
    @GetMapping("/queryCustomerIsExists")
    Response queryCustomerIsExists(@RequestParam Integer schoolId) {
        Response resp = new Response();
        if (schoolId == null) {
            resp.setStatus(300);
            resp.setErrmessage("学校不能为空！");
        } else {
            HashMap<String, Object> ret = customerService.queryCustomerIsExists(schoolId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 查询行业类
     */
    @GetMapping("/queryCustomerIndustryClass")
    Response queryCustomerIndustryClass() {
        Response resp = new Response();
        HashMap<String, Object> ret = customerService.queryCustomerIndustryClass();
        int status = (int) ret.get("retcode");
        if (200 == status) {
            resp.setStatus(status);
            resp.setMessage(ret.get("retvalue"));
        } else {
            resp.setStatus(status);
            resp.setErrmessage(ret.get("retvalue").toString());
        }
        return resp;
    }

    /**
     * 查询行业
     */
    @GetMapping("/queryCustomerIndustry")
    Response queryCustomerIndustry(@RequestParam Integer industryClassId) {
        Response resp = new Response();
        HashMap<String, Object> ret = customerService.queryCustomerIndustry(industryClassId);
        int status = (int) ret.get("retcode");
        if (200 == status) {
            resp.setStatus(status);
            resp.setMessage(ret.get("retvalue"));
        } else {
            resp.setStatus(status);
            resp.setErrmessage(ret.get("retvalue").toString());
        }
        return resp;
    }

    /**
     * 查询学校
     */
    @GetMapping("/querySchool")
    Response querySchool(@RequestParam String schoolName,@RequestParam Integer provinceId,@RequestParam Integer cityId) {
        Response resp = new Response();
        School school = new School();
        if (schoolName != null || schoolName != "") {
            school.setSchoolName(schoolName);
        }
        if (provinceId !=null){
            school.setProvinceId(provinceId);
        }
        school.setCityId(cityId);
        if (cityId !=null ){
        }
        HashMap<String, Object> ret = customerService.querySchool(school);
        resp.setStatus(200);
        resp.setErrmessage("Parameter effective");
        int status = (int) ret.get("retcode");
        if (200 == status) {
            resp.setStatus(status);
            resp.setMessage(ret.get("retvalue"));
        } else {
            resp.setStatus(status);
            resp.setErrmessage(ret.get("retvalue").toString());
        }
        return resp;
    }
}
