package com.yipin.liuwanr.controller;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.entity.ExperimentalClass;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.entity.Student;
import com.yipin.liuwanr.service.ExperimentalClassService;
import com.yipin.liuwanr.vo.ExperimentalClassVo;

@RestController
@RequestMapping("/experimentalClass")
public class ExperimentalClassController {

	@Autowired
	private ExperimentalClassService classService;

	/**
	 * 实验班级面板，根据实验班级名称查询信息
	 * @param experimentalClassName
	 * @return
	 */
	@GetMapping("/queryExperimentClassByName")
	Response queryExperimentClass(@RequestParam String experimentalClassName) {
	    	Response resp = new Response(); 
				
			HashMap<String, Object> ret=classService.queryGetByExperimentalClassName(experimentalClassName);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
			return resp;
     }

	/**
	 * 查询实验班级
	 * @return
	 */
	@GetMapping("/queryExperimentalClass")
	Response queryExperimentalClass(@RequestParam Integer schoolId,@RequestParam Integer courseId,@RequestParam Integer userId) {
	    	Response resp = new Response(); 
    		if(StringUtils.isEmpty(schoolId)){
				resp.setStatus(300);
				resp.setErrmessage("学校信息为空");
			}else if(StringUtils.isEmpty(courseId)){
				resp.setStatus(300);
				resp.setErrmessage("课程信息为空");
		}else if (StringUtils.isEmpty(userId)){
				resp.setStatus(300);
				resp.setErrmessage("用户信息为空");
			}
    		else{
				HashMap<String, Object> ret=classService.queryExperimentalClass(schoolId,courseId,userId);
				int status = (int) ret.get("retcode");
				if (200 == status) {
					resp.setStatus(status);
					resp.setMessage(ret.get("retvalue"));
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
				}
			}
		return resp;
     }
	
	
	/**
	 * 查询实验班级详情
	 * @param experimentalClassId
	 * @return
	 */
	@GetMapping("/queryExperimentClassDetails")
	Response queryExperimentClassDetails(@RequestParam String experimentalClassId,@RequestParam Integer courseId,
			@RequestParam Integer professionalId,@RequestParam Integer classId,@RequestParam String studentNameNumber) {
	    	Response resp = new Response(); 
	    	Student student = new Student();
	    	if (experimentalClassId!=null&&experimentalClassId!="") {
	    		if (professionalId!=null) {
					student.setProfessionalId(professionalId);
				}
	    		if (classId!=null) {
					student.setClassId(classId);
				}
	    		if (studentNameNumber!=null&&studentNameNumber!="") {
					student.setStudentNameNumber(studentNameNumber);
				}
	    		student.setExperimentalClassId(experimentalClassId);
	    		HashMap<String, Object> ret=classService.queryExperimentalClassDetails(student,courseId);
				int status = (int) ret.get("retcode");
				if (200 == status) {
					resp.setStatus(status);
					resp.setMessage(ret.get("retvalue"));
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
				}
			}else {
				resp.setStatus(300);
				resp.setErrmessage("Parameter Invalid");
			}
			
			return resp;
     }
	
	
	/**
	 * 	实验班级添加学生
	 */
	@Log("实验班级添加学生")
	@PostMapping("/experimentClassAddStudent")
	Response experimentClassAddStudent(@RequestBody List<Student> studentList) {
		Response resp = new Response();
		if (studentList.isEmpty()) {
			resp.setStatus(300);
			resp.setErrmessage("参数为空！");
		}else {
				HashMap<String, Object> ret = classService.experimentClassAddStudent(studentList);
				int status = (int) ret.get("retcode");
				if (200 == status) {
					resp.setStatus(status);
					resp.setMessage(ret.get("retvalue"));
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
				}
			}
		return resp;
	}
	
	/**
	 * 	实验班级删除学生
	 */
	@Log("实验班级删除学生")
	@PostMapping("/experimentClassDeleteStudent")
	Response experimentClassDeleteStudent(@RequestBody List<Student> studentList) {
		Response resp = new Response();
		if (studentList.isEmpty()) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = classService.experimentClassDeleteStudent(studentList);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	实验班级删除学生
	 */
	@PostMapping("/experimentClassUpdatePN")
	Response experimentClassUpdatePN(@RequestParam Integer classSize,Integer experimentalClassId) {
		Response resp = new Response();
		if (classSize==null) {
			resp.setStatus(300);
			resp.setErrmessage("班级人数为空！");
		}else {
			HashMap<String, Object> ret = classService.experimentClassUpdatePN(classSize,experimentalClassId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	修改实验班级名称
	 */
	@Log("修改实验班级名称")
	@PostMapping("/updateExperimentClassName")
	Response updateExperimentClassName(@RequestBody ExperimentalClass experimentalClass) {
		Response resp = new Response();
		Integer experimentalClassId = experimentalClass.getExperimentalClassId();
		String experimentalClassName = experimentalClass.getExperimentalClassName();
		if (experimentalClassId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else if(experimentalClassName==null||experimentalClassName==""){
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
				HashMap<String, Object> ret = classService.updateExperimentClassName(experimentalClass);
				int status = (int) ret.get("retcode");
				if (200 == status) {
					resp.setStatus(status);
					resp.setMessage(ret.get("retvalue"));
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
				}
			}
		return resp;
	}
	
	/**
	 * 查询实验班级学生专业
	 * @param experimentalClassId
	 * @return
	 */
//	@GetMapping("/queryExperimentalClassSP")
//	Response queryExperimentalClassSP(@RequestParam Integer experimentalClassId) {
//	    	Response resp = new Response();
//    		HashMap<String, Object> ret=classService.queryExperimentalClassSP(experimentalClassId);
//			int status = (int) ret.get("retcode");
//			if (200 == status) {
//				resp.setStatus(status);
//				resp.setMessage(ret.get("retvalue"));
//			} else {
//				resp.setStatus(status);
//				resp.setErrmessage(ret.get("retvalue").toString());
//			}
//		return resp;
//     }
	
	/**
	 * 专业下拉框
	 * @param experimentalClassId
	 * @return
	 */
	@GetMapping("/getProfessionals")
	Response getProfessionals(@RequestParam Integer experimentalClassId) {
    	Response resp = new Response(); 
		HashMap<String, Object> ret=classService.getProfessionals(experimentalClassId);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	 }
	
	
	/**
	 * 班级下拉框
	 * @param experimentalClassId
	 * @return
	 */
	@GetMapping("/getStudentClass")
	Response getStudentClass(@RequestParam Integer experimentalClassId) {
    	Response resp = new Response(); 
		HashMap<String, Object> ret=classService.getStudentClass(experimentalClassId);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	 }
	
	
	/**
	 * 查询学生行政班级
	 * @param experimentalClassId
	 * @return
	 */
//	@GetMapping("/queryStudentClass")
////	Response queryStudentClass(@RequestParam Integer experimentalClassId) {
////	    	Response resp = new Response();
////    		HashMap<String, Object> ret=classService.queryStudentClass(experimentalClassId);
////			int status = (int) ret.get("retcode");
////			if (200 == status) {
////				resp.setStatus(status);
////				resp.setMessage(ret.get("retvalue"));
////			} else {
////				resp.setStatus(status);
////				resp.setErrmessage(ret.get("retvalue").toString());
////			}
////		return resp;
////     }
	
	/**
	 * 	添加实验班级
	 * @throws Exception 
	 */
	@Log("添加实验班级")
	@Transactional
	@PostMapping("/addExperimentalClass")
 	public Response addExperimentalClass(@RequestBody ExperimentalClassVo vo) throws Exception {
		Response resp = new Response();
		ExperimentalClass experimentalClass = vo.getExperimentalClass();
		List<Student> studentList = vo.getStudentList();
		Integer schoolId = experimentalClass.getSchoolId();
		if (schoolId==null) {
			resp.setStatus(300);
			resp.setErrmessage("学校为空，新增失败！");
		}else {
			HashMap<String, Object> ret = classService.addExperimentalClass(experimentalClass);
			Integer experimentalClassId = experimentalClass.getExperimentalClassId();
			int size = studentList.size();
			for (int i = 0; i < size; i++) {
				studentList.get(i).setExperimentalClassId(experimentalClassId+"");
			}
			int status = (int) ret.get("retcode");
			if (200 == status) {
				HashMap<String, Object> ret1 = classService.experimentClassAddStudent(studentList);
				int status1 = (int) ret1.get("retcode");
				if (status1 == 200) {
					resp.setStatus(status1);
					resp.setMessage(ret.get("retvalue"));
				}else {
					resp.setStatus(status1);
					resp.setErrmessage(ret.get("retvalue").toString());
					throw new Exception();
				}
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
				throw new Exception();
			}
		}
		return resp;
	}
	
	
	//删除实验班级
	@Log("删除实验班级")
	@PostMapping("/deleteExperimentalClass")
	Response deleteExperimentalClass(@RequestBody ExperimentalClass experimentalClass) {
		Response resp = new Response();
		Integer experimentalClassId = experimentalClass.getExperimentalClassId();
		if (experimentalClassId==null) {
			resp.setStatus(300);
			resp.setErrmessage("实验班级为空，删除失败！");
		}else {
			HashMap<String, Object> ret = classService.deleteExperimentalClass(experimentalClassId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
}
