package com.yipin.liuwanr.controller;

import java.util.HashMap;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.yipin.liuwanr.entity.Group;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.service.GroupService;

@RestController
@RequestMapping("/group")
public class GroupController {

	Logger logger = Logger.getLogger(GroupController.class);

	@Autowired
	GroupService groupService;

	@PostMapping("/handle")
	Response handleMessage(@RequestBody String message) {
		Response resp = new Response();
		logger.info(message);
		JSONObject group = JSON.parseObject(message);
		// 消息发送者
		String from = group.getString("fromAccount");
		/*
		 * "eventType"="1",
		 * 表示CONVERSATION消息，即会话类型的消息（目前包括P2P聊天消息，群组聊天消息，群组操作，好友操作）
		 * PERSON（二人会话数据）、TEAM（群聊数据）、CUSTOM_PERSON（个人自定义系统通知）、CUSTOM_TEAM（
		 * 群组自定义系统通知）
		 */
		if (1 == group.getInteger("eventType")) {
			if (0 == group.getString("convType").compareToIgnoreCase("CUSTOM_TEAM")
					|| 0 == group.getString("convType").compareToIgnoreCase("TEAM")) {
				// 消息接受者,也就是群id
				long to = group.getLongValue("to");
				if (0 == group.getString("msgType").compareToIgnoreCase("TEAM_INVITE")
						|| 0 == group.getString("msgType").compareToIgnoreCase("NOTIFICATION")) {
					// 消息附加信息.群资料以及用户信息等
					JSONObject attach = JSON.parseObject(group.getString("attach").replace("\\\"", "\""));
					// 群操作信息
					JSONObject data = attach.getJSONObject("data");
					// 群信息
					JSONObject tinfo = data == null ? attach.getJSONObject("tinfo") : data.getJSONObject("tinfo");
					// 群对象
					Group thisgroup = new Group();
					/*
					 * "1":"群组id，可转为Long型", "3":"群名称",
					 * "4":"群类型,0表示讨论组,1表示高级群", "5":"创建者用户帐号",
					 * "7":"群公告等各种属性", "8":"群有效标记,0表示无效,1表示有效",
					 * "9":"群有效成员个数", "10":"群组成员列表更新的时间戳，精确到毫秒",
					 * "11":"创建时间,精确到毫秒", "12":"更新时间,精确到毫秒", "14":"群介绍",
					 * "15":"群公告，为JSONArray的toString，格式参考下文",
					 * "16":"群属性，0表示入群不需要申请，1表示入群需要申请", "18":"第三方扩展字段",
					 * "19":"第三方服务器扩展字段", "20":"群头像", "21":"被邀请人同意方式",
					 * 0：需要统一(默认)，1：不需要同意, "22":"谁可以邀请他人入群",
					 * 0：管理员(默认)，1：所有人, "23":"谁可以修改群资料", 0：管理员(默认)，1：所有人,
					 * "24":"谁可以更新群自定义属性"，0：管理员(默认)，1：所有人
					 */
					if (tinfo != null) {
						thisgroup.setGuid(tinfo.getLong("1"));
						if(tinfo.containsKey("3")){
							thisgroup.setName(tinfo.getString("3"));
						}
						if(tinfo.containsKey("5")){
							thisgroup.setUuid(tinfo.getString("5"));
						}
						if(tinfo.containsKey("9")){
							thisgroup.setMembers(tinfo.getIntValue("9"));
						}
						if(tinfo.containsKey("14")){
							thisgroup.setDescription(tinfo.getString("14"));
						}
						if(tinfo.containsKey("18")){
							String[] location = tinfo.getString("18").split(",");
							thisgroup.setLongitude(Double.parseDouble(location[0]));
							thisgroup.setLatitude(Double.parseDouble(location[1]));
						}
						if(tinfo.containsKey("20")){
							thisgroup.setAvatar(tinfo.getString("20"));
						}
					}
					if (0 == group.getString("msgType").compareToIgnoreCase("TEAM_INVITE")) {
						if (1 == thisgroup.getMembers()) {
							createGroup(thisgroup);
							addMember(thisgroup.getUuid(), thisgroup.getGuid(), thisgroup.getUuid());
						} else {
							updateGroup(thisgroup);
							JSONArray ids = data.getJSONArray("ids");
							for (Object s : ids) {
								addMember(thisgroup.getUuid(), thisgroup.getGuid(), s.toString());
							}
						}
						
					} else if (0 == group.getString("msgType").compareToIgnoreCase("NOTIFICATION")) {
						// 群操作类型
						int actiontype = attach.getIntValue("id");
						// 处理相应群消息
						switch (actiontype) {
						case 0: // TEAM_INVITE，即群拉人
							break;
						case 1: // TEAM_KICK，即群踢人
							updateGroup(thisgroup);
							JSONArray ids = data.getJSONArray("ids");
							for (Object s : ids) {
								removeMember(thisgroup.getUuid(), thisgroup.getGuid(), s.toString());
							}
							break;
						case 2: // TEAM_LEAVE，即退出群
							updateGroup(thisgroup);
							removeMember(thisgroup.getUuid(), thisgroup.getGuid(), data.getString("id"));
							break;
						case 3: // TEAM_UPDATE，即群更新群信息
							updateGroup(thisgroup);
							break;
						case 4: // TEAM_DISMISS，即群解散
							dismissGroup(from, to);
							break;
						case 5: // TEAM_APPLY_PASS，即群申请加入成功
							updateGroup(thisgroup);
							addMember(thisgroup.getUuid(), thisgroup.getGuid(), data.getString("id"));
							break;
						case 6: // TEAM_OWNER_TRANSFER，即群主退群并移交群主
							updateGroup(thisgroup);
							removeMember(thisgroup.getUuid(), thisgroup.getGuid(), data.getString("id"));
							break;
						case 7: // TEAM_ADD_MANAGER，即增加管理员
							break;
						case 8: // TEAM_REMOVE_MANAGER，即群删除管理员
							break;
						case 9: // TEAM_INVITE_ACCEPT，即群接受邀请进群
							updateGroup(thisgroup);
							addMember(thisgroup.getUuid(), thisgroup.getGuid(), data.getString("id"));
							break;
						default:
							break;
						}
					}
				}
			}
		}
		return resp;
	}

	@PostMapping("/create")
	Response createGroup(@RequestBody Group group) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.create(group);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@PostMapping("/update")
	Response updateGroup(@RequestBody Group group) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.update(group);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/add")
	Response addMember(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid,
			@RequestParam("uuid") String buuid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.addMember(uuid, guid, buuid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/kick")
	Response removeMember(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid,
			@RequestParam("uuid") String buuid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.deleteMember(uuid, guid, buuid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/block")
	Response blockUser(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid,
			@RequestParam("uuid") String buuid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.blockUser(uuid, guid, buuid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/unblock")
	Response unblockUser(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid,
			@RequestParam("uuid") String buuid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.unblockUser(uuid, guid, buuid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@DeleteMapping("/dismiss")
	Response dismissGroup(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.delete(uuid, guid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/detail")
	Response getGroupDetail(@RequestHeader("X-UUID") String uuid, @RequestParam("guid") long guid) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.detail(guid);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	@GetMapping("/around")
	Response getAroundGroup(@RequestHeader("X-UUID") String uuid, @RequestParam("longitude") double longi, @RequestParam("latitude") double lati) {
		Response resp = new Response();
		HashMap<String, Object> ret = groupService.around(uuid, longi, lati);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}
}
