package com.yipin.liuwanr.controller;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.entity.ContractInformation;
import com.yipin.liuwanr.entity.CoursePermissions;
import com.yipin.liuwanr.entity.Order;
import com.yipin.liuwanr.vo.OrderVo;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.OrderService;

@RestController
@RequestMapping("/order")
@CrossOrigin
public class OrderController {

	@Autowired
	private OrderService orderService;

	@Autowired
	RedisHelper redisHelper;

	/**
	 * 	添加订单
	 * @throws Exception 
	 */
	@Log("添加订单")
	@Transactional
	@PostMapping("/addOrder")
	public Response addOrder(@RequestBody OrderVo vo) throws Exception {
		Response resp = new Response();
		Order order = vo.getOrder();
		ContractInformation contractInformation = vo.getContractInformation();
		if (vo.getOrder().getCityId() == null) {
			resp.setStatus(300);
			resp.setErrmessage("参数为空！");
		} else {
			HashMap<String, Object> ret = orderService.addOrder(order);
			Integer orderId = (Integer) ret.get("orderId");
			contractInformation.setOrderId(orderId);
			Integer size = vo.getCoursePermissionss().size();
			for (int i = 0; i < size; i++) {
				vo.getCoursePermissionss().get(i).setOrderId(orderId);
			}
			List<CoursePermissions> coursePermissionss = vo.getCoursePermissionss();
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
				//添加合同信息
				if (!coursePermissionss.isEmpty()) {
					HashMap<String, Object> ret1 = orderService.addContractInformation(contractInformation);
					int status1 = (int) ret1.get("retcode");
					if (status1 == 200) {
						resp.setStatus(status1);
						resp.setMessage(ret1.get("retvalue"));
						//添加课程权限
						HashMap<String, Object> ret2 = orderService.addCoursePermissionss(coursePermissionss);
						int status2 = (int) ret2.get("retcode");
						if (status2 == 200) {
							resp.setStatus(status2);
							resp.setMessage(ret2.get("retvalue"));
						}else {
							resp.setStatus(status2);
							resp.setErrmessage(ret2.get("retvalue").toString());
							throw new Exception("添加课程权限失败！");
						}
					}else {
						resp.setStatus(status1);
						resp.setErrmessage(ret1.get("retvalue").toString());
						throw new Exception("添加合同信息失败！");
					}
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
					throw new Exception("添加订单失败！");
				}
			}
		}
		return resp;
	}
	
	/**
	 * 	查询订单
	 */
	@GetMapping("/queryOrder")
	Response queryOrder(@RequestParam Integer provinceId,Integer cityId,Integer pageNo,Integer pageSize,Integer orderType,Integer orderStatus,String searchContent) {
		Response resp = new Response();
		Order order  = new Order();
		if(provinceId!=null) {
			order.setProvinceId(provinceId);
		}
		if(cityId!=null) {
			order.setCityId(cityId);
		}
		if (orderType!=null) {
			order.setOrderType(orderType);
		}
		if (orderStatus!=null) {
			order.setOrderStatus(orderStatus);
		}
		if (searchContent!=null&&searchContent!="") {
			order.setSearchContent(searchContent);
		}
		HashMap<String, Object> ret = orderService.queryOrder(order,pageNo,pageSize);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
	return resp;
}
	
	/**
	 * 	查询订单详情
	 */
	@GetMapping("/queryOrderDetails")
	Response queryOrderDetails(@RequestParam Integer orderId) {
		Response resp = new Response();
		if(orderId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = orderService.queryOrderDetails(orderId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		
	return resp;
}
	
	/**
	 * 	删除订单
	 */
	@PostMapping("/deleteOrder")
	Response deleteOrder(@RequestBody List<Integer> orderId) {
		Response resp = new Response();
		if (orderId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = orderService.deleteOrder(orderId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	更新订单
	 * @throws Exception 
	 */
	@Log("更新订单")
	@Transactional
	@PostMapping("/updateOrder")
	public Response updateOrder(@RequestBody OrderVo vo) throws Exception {
		Response resp = new Response();
		Order order = vo.getOrder();
		List<CoursePermissions> coursePermissionss= vo.getCoursePermissionss();
		ContractInformation contractInformation = vo.getContractInformation();
		if (vo.getOrder().getOrderId()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = orderService.updateOrder(order);
			int status = (int) ret.get("retcode"); 
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
				int orderId = order.getOrderId();
				HashMap<String, Object> ret0 = orderService.deleteCoursePermissions(orderId);
				HashMap<String, Object> ret1 = orderService.updateCoursePermissions(coursePermissionss);

				//查询订单对应的所有课程是否全部发货，如果是全部发货，则修改订单状态为已发货
				List<Integer>list = orderService.selectByOrderId(orderId);

				if(!list.contains(0)){//如果list中不存在状态为未发货,则修改订单状态为已发货
					int orderStatus=2;
					int i = orderService.updateOrderStatus(orderId,orderStatus);
				}else{//修改订单状态为待发货
					int orderStatus=1;
					int i = orderService.updateOrderStatus(orderId,orderStatus);
				}

				int status1 = (int) ret1.get("retcode");
				if (status1 == 200) {
					resp.setStatus(status1);
					resp.setMessage(ret.get("retvalue"));
					HashMap<String, Object> ret2 = orderService.updateContractInformation(contractInformation);
					int status2 = (int) ret2.get("retcode"); 
					if (status2 == 200) {
						resp.setStatus(status2);
						resp.setMessage(ret.get("retvalue"));
					}else {
						resp.setStatus(status2);
						resp.setMessage(ret.get("retvalue"));
						throw new Exception();
					}
				}else {
					resp.setStatus(status1);
					resp.setMessage(ret.get("retvalue"));
					throw new Exception();
				}
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
				throw new Exception();
			}
		}
		return resp;
	}
	
	/**
	 * 	查询课程权限
	 */
	@GetMapping("/queryCoursePermissions")
	Response queryApplicationPermissions(@RequestParam String courseId) {
		Response resp = new Response();
			HashMap<String, Object> ret = orderService.queryCoursePermissions(courseId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		return resp;
	}
	
//	/**
//	 * 	绑定应用权限
//	 */
//	@PostMapping("/bindingApplicationPermissions")
//	Response bindingApplicationPermissions(@RequestBody ApplicationPermissions applicationPermissions) {
//		Response resp = new Response();
//		String systemId = applicationPermissions.getSystemId();
//		Integer orderId = applicationPermissions.getOrderId();
//		if (systemId==null||systemId==""||orderId ==null) {
//			resp.setStatus(300);
//			resp.setErrmessage("Parameter Invalid");
//		}
//		else {
//			HashMap<String, Object> ret = orderService.bindingApplicationPermissions(applicationPermissions);
//			int status = (int) ret.get("retcode");
//			if (200 == status) {
//				resp.setStatus(status);
//				resp.setMessage(ret.get("retvalue"));
//			} else {
//				resp.setStatus(status);
//				resp.setErrmessage(ret.get("retvalue").toString());
//			}
//		}
//		return resp;
//	}
	/**
	 * 	是否发货控制
	 */
	@PostMapping("/isDeliverGoods")
	Response isDeliverGoods(@RequestBody CoursePermissions coursePermissions) {
		Response resp = new Response();
		if (coursePermissions.getCoursePermissionsId()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else if (coursePermissions.getIsDeliverGoods() == null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = orderService.isDeliverGoods(coursePermissions);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	查询订单客户
	 */
	@GetMapping("/queryOrderCustomer")
	Response queryOrderCustomer(@RequestParam Integer cityId,Integer provinceId) {
		Response resp = new Response();
		if(cityId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else if (provinceId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = orderService.queryOrderCustomer(cityId,provinceId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		
	return resp;
	}
	
	/**
	 * 	查询订单客户联系人
	 */
	@GetMapping("/queryOrderCustomerContact")
	Response queryOrderCustomerContact(@RequestParam Integer customerId) {
		Response resp = new Response();
		if(customerId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = orderService.queryOrderCustomerContact(customerId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		
	return resp;
	}
	
	/**
	 * 	查询订单课程列表
	 */
	@GetMapping("/queryCourseList")
	Response queryCourseList(@RequestParam String searchContent,@RequestParam List<Integer> courseId,Integer pageNo,Integer pageSize) {
		Response resp = new Response();
		HashMap<String, Object> ret = orderService.queryCourseList(searchContent,courseId,pageNo,pageSize);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
	return resp;
}
}
