package com.yipin.liuwanr.controller;

import com.yipin.liuwanr.entity.Pet;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.service.PetService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;

@RestController
@RequestMapping("/pet")
public class PetController {

	@Autowired
	private PetService petService;

    @PostMapping("/create")
    Response createPet(@RequestHeader("X-UUID") String uuid, @RequestBody Pet pet) {
    	Response resp = new Response();
	          	HashMap<String, Object> ret = petService.create(uuid, pet);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @PostMapping("/update")
    Response updatePet(@RequestHeader("X-UUID") String uuid, @RequestBody Pet pet) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.update(uuid, pet);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @DeleteMapping("/delete")
    Response deletePet(@RequestHeader("X-UUID") String uuid, @RequestParam("puid") String puid) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.delete(uuid, puid);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @GetMapping("/detail")
    Response watchPet(@RequestHeader("X-UUID") String uuid, @RequestParam("puid") String puid) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.getOne(uuid, puid);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString() );
		}
		return resp;
    }
    
    @GetMapping("/list")
    Response listPet(@RequestHeader("X-UUID") String uuid) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.getMyPets(uuid);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @GetMapping("/findown")
    Response locatePet(@RequestHeader("X-UUID") String uuid) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.whereisMyPets(uuid);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @GetMapping("/around")
    Response searchPet(@RequestParam("longitude") double longitude, @RequestParam("latitude") double latidude) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.getNearByPets(longitude, latidude);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @GetMapping("/breeds")
    Response getPetBreeds(@RequestParam("category") int category) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.getBreedsByCategory(category);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
    @GetMapping("/greet")
    Response sayHello(@RequestHeader("X-UUID") String from, @RequestParam("uuid") String to, @RequestParam("puid") String puid, @RequestParam(value="type", required = false, defaultValue = "1") int type, @RequestParam(value="message", required = false, defaultValue = "") String message) {
    	Response resp = new Response();
		HashMap<String, Object> ret = petService.sayHelloToPet(from, to, puid, type, message);
		int status = (int) ret.get("retcode");
		if(200 == status){
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		}
		else{
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }
    
}
