package com.yipin.liuwanr.controller;

import java.util.HashMap;

import javax.servlet.http.HttpServletResponse;

import com.yipin.liuwanr.entity.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.service.PracticeService;

@RestController
@RequestMapping("/experiment")
/**
 * 练习+考核记录
 * @author 或然
 *
 */
public class PracticeController {

	@Autowired
	private PracticeService service;
	
	/**
	 * 练习记录 And 考核记录
	 * 
	 * @param studentId
	 * @param pageNum
	 * @param pageSize
	 * @return
	 */
	@GetMapping("/queryStudentByPage")
	Response queryStudentByPage(@RequestParam Integer studentId,@RequestParam Integer projectPermissions,
			@RequestParam Integer courseId,@RequestParam Integer pageNum,@RequestParam Integer pageSize) {
		Response resp = new Response();
		if(StringUtils.isEmpty(studentId)) {
			resp.setStatus(300);
			resp.setErrmessage("学生信息为空");
		}else {
			HashMap<String, Object> ret = service.queryStudentByPage(studentId,projectPermissions,courseId,pageNum,pageSize);
			int status = (int) ret.get("retcode");
			if (status == 200) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 练习记录 And 考核记录导出
	 * @param response
	 * @param studentId：学生id
	 * @param projectPermissions：权限(练习、考核)
	 * @param titles(标题)
	 * @return
	 */
	@Log("练习记录和考核记录导出")
	@GetMapping("/exportPractice")
	Response exportPractice(HttpServletResponse response,@RequestParam Integer studentId,@RequestParam Integer projectPermissions,@RequestParam Integer courseId,@RequestParam String[] titles) {
		try {
			service.exportPractice(response,studentId,projectPermissions,courseId,titles);
		} catch (Exception e) {
		}		
		return null;	

	}


	/**
	 * 练习信息
	 * @return
	 */
	@GetMapping("/queryPracticeVo")
    Response queryPracticeVo(Integer studentId,Integer courseId) {
		Response resp = new Response();
		HashMap<String, Object> ret = service.queryPracticeVo(studentId,courseId);
		int status = (int) ret.get("retcode");
		if (status == 200) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
    }

	
	/**
	 *  实验项目表格数据渲染接口
	 * @param courseId
	 * @return
	 */
	 @GetMapping("/queryAllExperiment")
	 Response queryAllExperiment(Integer courseId) {
			Response resp = new Response();
			HashMap<String, Object> ret = service.queryAllExperiment(courseId);
			int status = (int) ret.get("retcode");
			if (status == 200) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
			return resp;
	    }

	
}
