package com.yipin.liuwanr.controller;

import java.util.HashMap;

import com.yipin.liuwanr.entity.annotation.Log;
import org.apache.ibatis.annotations.Delete;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.entity.ServiceConfig;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.ServiceConfigService;

@RestController
@RequestMapping("/serviceConfig")
@CrossOrigin
public class ServiceConfigController {

	@Autowired
	private ServiceConfigService serviceConfigService;

	@Autowired
	RedisHelper redisHelper;

	/**
	 * 	添加服务配置
	 */
	@Log("添加服务配置")
	@PostMapping("/addServiceConfig")
	Response addServiceConfig(@RequestBody ServiceConfig serviceConfig) {
		Response resp = new Response();
		if (serviceConfig.getSystemName()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = serviceConfigService.addServiceConfig(serviceConfig);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	查询服务配置
	 */
	@GetMapping("/queryServiceConfig")
	Response queryServiceConfig(@RequestParam Integer systemAttribution,Integer systemType,String searchContent,Integer pageNo,Integer pageSize) {
		Response resp = new Response();
		ServiceConfig serviceConfig  = new ServiceConfig();
		if (systemAttribution!= null) {
			serviceConfig.setSystemAttribution(systemAttribution);
		}if(systemType!=null) {
			serviceConfig.setSystemType(systemType);
		}if (searchContent!=null && searchContent!="") {
			serviceConfig.setSearchContent(searchContent);
		}
		HashMap<String, Object> ret = serviceConfigService.queryServiceConfig(serviceConfig,pageNo,pageSize);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
	return resp;
}
	
	/**
	 * 	查询服务配置
	 */
	@GetMapping("/queryServiceConfigDetails")
	Response queryServiceConfigDetails(@RequestParam Integer systemId) {
		Response resp = new Response();
		if (systemId== null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}
		HashMap<String, Object> ret = serviceConfigService.queryServiceConfigDetails(systemId);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
	return resp;
}
	
	/**
	 * 	删除服务配置
	 */
	@Log("删除服务配置")
	@Delete("/deleteServiceConfig")
	Response deleteServiceConfig(@RequestBody ServiceConfig serviceConfig) {
		Response resp = new Response();
		if (serviceConfig.getSystemId()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = serviceConfigService.deleteServiceConfig(serviceConfig);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	更新服务配置
	 */
	@Log("更新服务配置")
	@PostMapping("/updateServiceConfig")
	Response updateServiceConfig(@RequestBody ServiceConfig serviceConfig) {
		Response resp = new Response();
		if (serviceConfig.getSystemName()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = serviceConfigService.updateServiceConfig(serviceConfig);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
}
