package com.yipin.liuwanr.controller;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.annotation.Log;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.entity.StaffGrade;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.StaffGradeService;

@RestController
@RequestMapping("/staffGrade")
@CrossOrigin
public class StaffGradeController {

	@Autowired
	private StaffGradeService staffGradeService;

	@Autowired
	RedisHelper redisHelper;

	/**
	 * 	添加员工年级
	 */
	@Log("添加员工年级")
	@PostMapping("/addStaffGrade")
	Response addCustomer(@RequestBody StaffGrade staffGrade) {
		Response resp = new Response();
		if (staffGrade.getStaffProfessionalArchitectureId()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = staffGradeService.addStaffGrade(staffGrade);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	查询员工年级
	 */
	@GetMapping("/queryStaffGrade")
	Response queryCustomer(@RequestParam Integer staffProfessionalArchitectureId) {
		Response resp = new Response();
		if (staffProfessionalArchitectureId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = staffGradeService.queryStaffGrade(staffProfessionalArchitectureId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
	return resp;
}
	
	/**
	 * 	查询员工年级详情
	 */
	@GetMapping("/queryStaffGradeDetails")
	Response queryStaffGradeDetails(@RequestParam Integer staffGradeId) {
		Response resp = new Response();
		if (staffGradeId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = staffGradeService.queryStaffGradeDetails(staffGradeId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}	
		}
	return resp;
}
	
	/**
	 * 	删除员工年级
	 */
	@Log("删除员工年级")
	@PostMapping("/deleteStaffGrade")
	Response deleteStaffGrade(@RequestBody StaffGrade staffGrade) {
		Response resp = new Response();
		Integer staffGradeId = staffGrade.getStaffGradeId();
		HashMap<String, Object> ret = new HashMap<>();
		HashMap<String, Object> ret2 = new HashMap<>();
		if (staffGradeId==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			List<Integer> userIds = staffGradeService.queryUserIdsByGradeId(staffGradeId);
			if(userIds.size()>0){
				ret2 = staffGradeService.deleteStaffGrade(userIds);
				ret = staffGradeService.deleteStaffGradePs(staffGradeId);
			}else{//如果组织架构下面没有员工，则只删除组织架构
				ret = staffGradeService.deleteStaffGradePs(staffGradeId);
			}

			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	
	/**
	 * 	更新员工年级
	 */
	@Log("更新员工年级")
	@PostMapping("/updateStaffGrade")
	Response updateStaffGrade(@RequestBody StaffGrade staffGrade) {
		Response resp = new Response();
		if (staffGrade.getStaffGradeId()==null) {
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		} else {
			HashMap<String, Object> ret = staffGradeService.updateStaffGrade(staffGrade);
			int status = (int) ret.get("retcode");
			if (200 == status) { 
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
}
