package com.yipin.liuwanr.controller;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.entity.Response;
import com.yipin.liuwanr.entity.annotation.Log;
import com.yipin.liuwanr.helper.PushHelper;
import com.yipin.liuwanr.helper.RandomUtil;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.StaffService;
import com.yipin.liuwanr.service.StudentService;
import com.yipin.liuwanr.service.UserService;
import com.yipin.liuwanr.vo.UserVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;

@RestController
@RequestMapping("/user")
public class UserController {

	@Autowired
	private UserService userService;

	@Autowired
	private StudentService studentService;

	@Autowired
	private StaffService staffService;

	@Autowired
	RedisHelper redisHelper;

	@Log("用户登录")
	@GetMapping("/login")
	Response loginUser(@RequestParam("id") String id, @RequestParam("password") String password,
					   HttpServletResponse response) {
		Response resp = new Response();
		HashMap<String, Object> ret = userService.login(id, password);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			User user = (User) ret.get("retvalue");
			String uuid = user.getUuid();
			String token = RandomUtil.getToken(uuid);
			int tokenexpire = 60 * 60 * 24 * 7;
			String refreshtoken = RandomUtil.getToken(uuid, token);
			int refreshtokenexpire = 60 * 60 * 24 * 365;
			if (PushHelper.refreshIMToken(uuid, refreshtoken)) {
				resp.setStatus(status);
				resp.setMessage(user);
				redisHelper.setTokenById(uuid, token, tokenexpire);
				redisHelper.setRefreshTokenById(uuid, refreshtoken, refreshtokenexpire);
				response.addHeader("X-TOKEN", token);
				response.addHeader("X-TOKEN-EXPIRES-AFTER", (System.currentTimeMillis() + 1000 * tokenexpire) + "");
				response.addHeader("X-FRESH-TOKEN", refreshtoken);
				response.addHeader("X-FRESH-TOKEN-EXPIRES-AFTER",
						(System.currentTimeMillis() + 1000 * refreshtokenexpire) + "");
			} else {
				resp.setStatus(500);
				resp.setErrmessage("Operation Failed");
			}
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}


	@GetMapping("/reauth")
	Response getNewToken(@RequestHeader("X-UUID") String uuid, @RequestHeader("X-TOKEN") String stoken,
						 @RequestHeader("X-SIGN") String sign, HttpServletResponse response) {
		Response resp = new Response();
		String oldtoken = redisHelper.getTokenById(uuid);
		String oldrefreshtoken = redisHelper.getRefreshTokenById(uuid);
		if (oldtoken == null || oldrefreshtoken == null) {
			resp.setStatus(500);
			resp.setErrmessage("Cache Error, Try Again");
		} else if (oldrefreshtoken == "none") {
			resp.setStatus(400);
			resp.setErrmessage("Authentication Info Expired");
		} else if (0 == RandomUtil.getMD5String((stoken + oldrefreshtoken).getBytes()).compareToIgnoreCase(sign)) {
			resp.setStatus(300);
			resp.setErrmessage("Authentication Failed");
		} else {
			String token = RandomUtil.getToken(uuid);
			int tokenexpire = 60 * 60 * 24 * 7;
			redisHelper.setTokenById(uuid, token, tokenexpire);
			response.addHeader("X-TOKEN", token);
			response.addHeader("X-TOKEN-EXPIRES-AFTER", (System.currentTimeMillis() + 1000 * tokenexpire) + "");
			resp.setStatus(200);
			resp.setMessage("Success");
		}
		return resp;
	}

	/**
	 * 	查询电话
	 */
	@GetMapping("/queryPhone")
	Response queryPhone(@RequestParam String phone) {
		Response resp = new Response();
		if (phone==null||phone=="") {//前台传来的值是否为空
			resp.setStatus(300);
			resp.setErrmessage("手机号为空！查询失败！");
		}else {
			HashMap<String, Object> ret = userService.queryPhone(phone);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	添加用户
	 */
	@Log("添加用户")
	@Transactional
	@PostMapping("/addUser")
	Response addUser(@RequestBody UserVO vo) {
		Response resp = new Response();
		//用户实体
		UserM user = vo.getUser();
		//学生实体
		Student student = vo.getStudent();
		//员工实体
		Staff staff = vo.getStaff();
		//用户手机号
		String phone = user.getPhone();
		//用户名称
		String name = user.getName();
		//省份id
		Integer provinceId = user.getProvinceId();
		//用户角色id
		Integer accountRole = user.getAccountRole();
		//城市id
		Integer cityId = user.getCityId();
		//学校id
		Integer schoolId = user.getSchoolId();
		if (phone==null||phone=="") {
			resp.setStatus(300);
			resp.setErrmessage("电话不能为空！");
		}else if(name==null||name==""){
			resp.setStatus(300);
			resp.setErrmessage("姓名不能为空！");
		}else if(provinceId==null){
			resp.setStatus(300);
			resp.setErrmessage("省份不能为空！");
		}else if(accountRole==null){
			resp.setStatus(300);
			resp.setErrmessage("用户角色不能为空！");
		}else if(cityId==null){
			resp.setStatus(300);
			resp.setErrmessage("城市不能为空！");
		}else if(schoolId==null){
			resp.setStatus(300);
			resp.setErrmessage("学校不能为空！");
		}else {
			HashMap<String, Object> ret = userService.addUser(user);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
				if (accountRole == 4){
					HashMap<String, Object> stu = studentService.addStudent(student);
					int stuStatus = (int) stu.get("retcode");
					if (stuStatus == 200){
						resp.setStatus(stuStatus);
						resp.setMessage(stu.get("retvalue"));
					}else {
						resp.setStatus(stuStatus);
						resp.setErrmessage(stu.get("retvalue").toString());
						throw new RuntimeException();
					}
				}
				if(accountRole == 3||accountRole==2){
					HashMap<String, Object> sta = staffService.addStaff(staff);
					int staStatus = (int) sta.get("retcode");
					if (staStatus == 200){
						resp.setStatus(staStatus);
						resp.setMessage(sta.get("retvalue"));
					}else {
						resp.setStatus(staStatus);
						resp.setErrmessage(sta.get("retvalue").toString());
						throw new RuntimeException();
					}
				}
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
				throw new RuntimeException();
			}
		}
		return resp;
	}

	/**
	 * 	查询用户(根据国家、省份、城市)
	 */
	@GetMapping("/queryUser")
	Response queryUser(@RequestParam String countries,Integer provinceId,Integer cityId,Integer pageNo,Integer pageSize,Integer schoolId,Integer accountRole,String searchContent,Integer month,String creationTime,String endTime) {
		Response resp = new Response();
		UserM user  = new UserM();
		//设置国家
		if (countries != null&&countries!="") {
			user.setCountries(countries);
		}
		//设置省份
		if(provinceId!=null) {
			user.setProvinceId(provinceId);
		}
		//设置城市
		if(cityId!=null) {
			user.setCityId(cityId);
		}
		//学校
		if (schoolId!=null) {
			user.setSchoolId(schoolId);
		}
		//角色
		if (accountRole!=null) {
			user.setAccountRole(accountRole);
		}
		//搜索内容
		if (searchContent!=null&&searchContent!="") {
			user.setSearchContent(searchContent);
		}
		//月份
		if (month!=null) {
			user.setMonth(month);;
		}
		//创建时间
		if (creationTime!=null&&creationTime!="") {
			user.setCreationTime(creationTime);
		}
		//结束时间
		if (endTime!=null&&endTime!="") {
			user.setEndTime(endTime);
		}
		HashMap<String, Object> ret = userService.queryUser(user,pageNo,pageSize);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}

	/**
	 * 	删除用户(根据ID修改isdel状态,0可见  1不可见)
	 */
	@Log("删除用户")
	@Transactional
	@PostMapping("/deleteUser")
	Response deleteUser(@RequestBody List<UserM> userList) {
		Response resp = new Response();
		int size = userList.size();
		for(int i=0;i<size;i++){
			UserM user = userList.get(i);
			Integer userId = user.getUserId();
			Integer roleId = user.getAccountRole();
			String phone = user.getPhone();
			if (userId==null) {
				resp.setStatus(300);
				resp.setErrmessage("用户id为空，删除用户失败！");
			}else if (phone==null||phone==""){
				resp.setStatus(300);
				resp.setErrmessage("用户电话为空，删除用户失败！");
			}else if (roleId==null){
				resp.setStatus(300);
				resp.setErrmessage("用户角色为空，删除用户失败！");
			} else {
				HashMap<String, Object> ret = userService.deleteUser(userId);
				int status = (int) ret.get("retcode");
				if (200 == status) {
					resp.setStatus(status);
					resp.setMessage(ret.get("retvalue"));
					if (roleId==3||roleId==2){
						HashMap<String, Object> sta = userService.deleteStaff(user);
						int staStatus = (int) ret.get("retcode");
						if (200 == staStatus) {
							resp.setStatus(staStatus);
							resp.setMessage(sta.get("retvalue"));
						}else{
							resp.setStatus(staStatus);
							resp.setErrmessage(sta.get("retvalue").toString());
							throw new RuntimeException();
						}
					}
					if (roleId==4){
						HashMap<String, Object> stu = userService.deleteStudent(user);
						int stuStatus = (int) stu.get("retcode");
						if (200 == stuStatus) {
							resp.setStatus(stuStatus);
							resp.setMessage(stu.get("retvalue"));
						}else{
							resp.setStatus(stuStatus);
							resp.setErrmessage(stu.get("retvalue").toString());
							throw new RuntimeException();
						}
					}
				} else {
					resp.setStatus(status);
					resp.setErrmessage(ret.get("retvalue").toString());
					throw new RuntimeException();
				}
			}
		}
		return resp;
	}

	/**
	 * 	更新用户
	 */
	@Log("更新用户")
	@Transactional
	@PostMapping("/updateUser")
	Response updateUser(@RequestBody UserVO vo) {
		Response resp = new Response();
		UserM user = vo.getUser();
		Staff staff = vo.getStaff();
		Student student = vo.getStudent();
		Integer userId = user.getUserId();
		Integer roleId = user.getAccountRole();
		if (userId==null) {
			resp.setStatus(300);
			resp.setErrmessage("用户ID为空，修改用户失败！");
		}else if (roleId==null){
			resp.setStatus(300);
			resp.setErrmessage("角色ID为空，修改用户失败！");
		}
		else {
			HashMap<String, Object> ret = userService.updateUser(user);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
				if (roleId ==3||roleId==2){
					HashMap<String, Object> sta = userService.updateStaff(staff);
					int staStatus = (int) sta.get("retcode");
					if (200 == status) {
						resp.setStatus(staStatus);
						resp.setMessage(sta.get("retvalue"));
					}else{
						resp.setStatus(staStatus);
						resp.setErrmessage(sta.get("retvalue").toString());
						throw new RuntimeException("修改员工失败！");
					}
				}
				if (roleId ==4){
					HashMap<String, Object> stu = userService.updateStudent(student);
					int stuStatus = (int) stu.get("retcode");
					if (200 == status) {
						resp.setStatus(stuStatus);
						resp.setMessage(stu.get("retvalue"));
					}else{
						resp.setStatus(stuStatus);
						resp.setErrmessage(stu.get("retvalue").toString());
						throw new RuntimeException("修改学生失败！");
					}
				}
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
				throw new RuntimeException("修改用户失败！");
			}
		}
		return resp;
	}


	/**
	 * 	登陆(前台传来的key必须是phone、password)
	 */
	@Log("登录")
	@GetMapping("/logins")
	Response logins(@RequestParam("phone") String phone, @RequestParam("password") String password,
					HttpServletRequest req, HttpServletResponse res) {
		Response resp = new Response();
		UserM user  = new UserM();
		if (phone != null) {
			user.setPhone(phone);
		}if(password!=null) {
			user.setPassword(password);
		}
		HashMap<String, Object> ret = userService.logins(user);
		int status = (int) ret.get("retcode");
		if (200 == status) {
			resp.setStatus(status);
			resp.setMessage(ret.get("retvalue"));
		} else {
			resp.setStatus(status);
			resp.setErrmessage(ret.get("retvalue").toString());
		}
		return resp;
	}


	/**
	 * 	查询用户详情(ID)
	 */
	@GetMapping("/queryUserDetails")
	Response queryUserDetails(@RequestParam Integer userId,Integer roleId) {
		Response resp = new Response();
		if (roleId == null){
			resp.setStatus(300);
			resp.setErrmessage("用户角色id为空！查询失败！");
		}else if (userId==null) {
			resp.setStatus(300);
			resp.setErrmessage("用户id为空！查询失败！");
		}else {
			HashMap<String, Object> ret = userService.queryUserDetails(userId,roleId);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	@PostMapping("/uploadUserAvatars")
	Response uploadUserAvatars(MultipartFile file,Integer userId) {
		Response resp = new Response();
		if (userId==null) {//前台传来的值是否为空
			resp.setStatus(300);
			resp.setErrmessage("Parameter Invalid");
		}else {
			HashMap<String, Object> ret = userService.uploadUserAvatars(file,userId);

			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	更新登录次数和时间
	 */
	@PostMapping("/updateLogInNumber")
	Response updateLogInNumber(@RequestBody UserM user) {
		Response resp = new Response();
		Integer userId = user.getUserId();
		String account = user.getUserAccount();
		Integer accountRole = user.getAccountRole();
		if (userId==null) {
			resp.setStatus(300);
			resp.setErrmessage("用户id不能为空!");
		}else if(account==null||account==""){
			resp.setStatus(300);
			resp.setErrmessage("用户账号不能为空!");
		} else if(accountRole==null){
			resp.setStatus(300);
			resp.setErrmessage("用户角色不能为空!");
		} else {
			HashMap<String, Object> ret = userService.updateLogInNumber(user);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}
	/**
	 * 	用户模块查询客户
	 */
	@GetMapping("/queryCustomer")
	Response queryCustomer(@RequestParam Integer cityId,Integer provinceId) {
		Response resp = new Response();
		if(provinceId == null){
			resp.setStatus(300);
			resp.setErrmessage("省份id为空！查询失败！");
		}else if (cityId==null) {
			resp.setStatus(300);
			resp.setErrmessage("城市id为空！查询失败！");
		}else {
			HashMap<String, Object> ret = userService.queryCustomer(cityId,provinceId);
			resp.setStatus(200);
			resp.setErrmessage("查询成功！");
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	查询账号是否存在
	 */
	@GetMapping("/queryAccountIsExist")
	Response queryAccountIsExist(@RequestParam String userAccount) {
		Response resp = new Response();
		if (userAccount==null) {
			resp.setStatus(300);
			resp.setErrmessage("账号为空！");
		}else {
			HashMap<String, Object> ret = userService.queryAccountIsExist(userAccount);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	查询学号、工号是否存在
	 */
	@GetMapping("/queryWorkNumberIsExist")
	Response queryWorkNumberIsExist(@RequestParam String workNumber) {
		Response resp = new Response();
		if (workNumber==null) {
			resp.setStatus(300);
			resp.setErrmessage("账号为空！");
		}else {
			HashMap<String, Object> ret = userService.queryWorkNumberIsExist(workNumber);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

	/**
	 * 	查询邮箱是否存在
	 */
	@GetMapping("/queryEmail")
	Response queryEmail(@RequestParam String email) {
		Response resp = new Response();
		if (email==null||email=="") {//前台传来的值是否为空
			resp.setStatus(300);
			resp.setErrmessage("邮箱为空！查询失败！");
		}else {
			HashMap<String, Object> ret = userService.queryEmail(email);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

}
