package com.yipin.liuwanr.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.entity.annotation.Log;
import com.yipin.liuwanr.entity.response.ResponseResult;
import com.yipin.liuwanr.entity.vo.AccountLoginVO;
import com.yipin.liuwanr.entity.vo.AdminLoginVO;
import com.yipin.liuwanr.entity.vo.UserInfoReq;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.service.*;
import com.yipin.liuwanr.util.PageUtils;
import com.yipin.liuwanr.util.UserIdUtils;
import com.yipin.liuwanr.vo.UserInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/userInfo")
public class UserInfoController {

    @Autowired
    private StudentService studentService;

    @Autowired
    private StaffService staffService;

    @Autowired
    private UserInfoService userInfoService;

    @Autowired
    private UserService userService;

    @Autowired
    RedisHelper redisHelper;

    @Autowired
    private ISysPermissionService permissionService;

    @Autowired
    private UserIdUtils userIdUtils;

    @Autowired
    private IHrUserAccountService iHrUserAccountService;


    /**
     * 	添加用户
     */
    @Log("添加用户")
    @Transactional
    @PostMapping("/addUser")
    public Response addUser(@RequestBody UserInfoVO vo) {
        Response resp = new Response();
        //个人档案实体
        List<UserProfiles> userProfilesList = vo.getUserProfilesList();
        //员工list
        List<Staff> staffList = vo.getStaffList();
        //学生实体
        Student student = vo.getStudent();
        //用户实体
        UserInfo user = vo.getUserInfo();
        //用户账号
        String account = user.getAccount();
        //用户名称
        String name = user.getUserName();
        //学校id
        Integer schoolId = user.getSchoolId();
        if(name==null||name==""){
            resp.setStatus(300);
            resp.setErrmessage("姓名不能为空！");
        }else if(account==null||account==""){
            resp.setStatus(300);
            resp.setErrmessage("账号不能为空！");
        }else if(schoolId==null){
            resp.setStatus(300);
            resp.setErrmessage("学校不能为空！");
        }else {
            HashMap<String, Object> ret = userInfoService.addUser(user,student,staffList,userProfilesList);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
                throw new RuntimeException();
            }
        }
        return resp;
    }

    /**
     * 	查询用户(根据国家、省份、城市)
     */
    @GetMapping("/queryUserInfo")
    Response queryUserInfo(@RequestParam String countries, Integer provinceId, Integer cityId, Integer pageNo, Integer pageSize, Integer schoolId, String roleId, String searchContent, Integer month, String creationTime, String endTime) {
        Response resp = new Response();
        UserInfo userInfo  = new UserInfo();
        //设置国家
        if (countries != null&&countries!="") {
            userInfo.setCountries(countries);
        }
        //设置省份
        if(provinceId!=null) {
            userInfo.setProvinceId(provinceId);
        }
        //设置城市
        if(cityId!=null) {
            userInfo.setCityId(cityId);
        }
        //学校
        if (schoolId!=null) {
            userInfo.setSchoolId(schoolId);
        }
        //角色
        if (roleId!=null) {
            userInfo.setRoleId(roleId);
        }
        //搜索内容
        if (searchContent!=null&&searchContent!="") {
            userInfo.setSearchContent(searchContent);
        }
        //月份
        if (month!=null) {
            userInfo.setMonth(month);;
        }
        //创建时间
        if (creationTime!=null&&creationTime!="") {
            userInfo.setCreationTime(creationTime);
        }
        //结束时间
        if (endTime!=null&&endTime!="") {
            userInfo.setEndTime(endTime);
        }
        HashMap<String, Object> ret = userInfoService.queryUserInfo(userInfo,pageNo,pageSize);
        int status = (int) ret.get("retcode");
        if (200 == status) {
            resp.setStatus(status);
            resp.setMessage(ret.get("retvalue"));
        } else {
            resp.setStatus(status);
            resp.setErrmessage(ret.get("retvalue").toString());
        }
        return resp;
    }

    /**
     * 	查询用户管理列表
     */
    @PostMapping("/queryUserInfoList")
    ResponseResult queryUserInfoList(@RequestBody UserInfoReq userInfoReq) {
        List data = userInfoService.queryPage(userInfoReq.getPage(), userInfoReq.getSize(), userInfoReq);
        return ResponseResult.SUCCESS(data);
    }

    /**
     * 	查询用户管理列表(不可用)
     */
    @PostMapping("/queryUserInfoList2")
    ResponseResult queryUserInfoList2(@RequestBody UserInfoReq userInfoReq) {
        PageUtils data = iHrUserAccountService.queryPage2(userInfoReq.getPage(), userInfoReq.getSize(), userInfoReq);
        return ResponseResult.SUCCESS(data);
    }

    /**
     * 	删除用户(根据ID修改isdel状态,0可见  1不可见)
     */
    @Log("删除用户")
    @Transactional
    @PostMapping("/deleteUserInfo")
    public Response deleteUserInfo(@RequestBody List<Integer> userIdList) {
        Response resp = new Response();
            if (userIdList.isEmpty()) {
                resp.setStatus(300);
                resp.setErrmessage("用户id为空，删除用户失败！");
            } else {
                HashMap<String, Object> ret = userInfoService.deleteUserInfo(userIdList);
                int status = (int) ret.get("retcode");
                if (200 == status) {
                    resp.setStatus(status);
                    resp.setMessage(ret.get("retvalue"));
                }else {
                    resp.setStatus(status);
                    resp.setErrmessage(ret.get("retvalue").toString());
                    throw new RuntimeException();
                }
            }
        return resp;
    }

    /**
     * 	更新用户
     */
    @Log("更新用户")
    @Transactional
    @PostMapping("/updateUserInfo")
    public Response updateUserInfo(@RequestBody UserInfo userInfo) {
        Response resp = new Response();
        Integer userId = userInfo.getUserId();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户ID为空，修改用户失败！");
        } else {
            HashMap<String, Object> ret = userInfoService.updateUser(userInfo);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
                throw new RuntimeException("修改用户失败！");
            }
        }
        return resp;
    }

    /**
     * 	更新用户角色id
     */
    @Transactional
    @PostMapping("/updateUserRoleId")
    public Response updateUserRoleId(@RequestBody UserInfo userInfo) {
        Response resp = new Response();
        Integer userId = userInfo.getUserId();
        String roleId = userInfo.getRoleId();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户ID为空，修改用户失败！");
        }else if (roleId==null){
            resp.setStatus(300);
            resp.setErrmessage("用户ID为空，修改用户失败！");
        } else {
            HashMap<String, Object> ret = userInfoService.updateUserRoleId(userId,roleId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
                throw new RuntimeException("修改用户失败！");
            }
        }
        return resp;
    }

    /**
     * 	更新用户个人档案
     */
    @Log("更新用户个人档案")
    @Transactional
    @PostMapping("/updateUserProfiles")
    public Response updateUserProfiles(@RequestBody List<UserProfiles> userProfilesList) {
        Response resp = new Response();
//        Integer userId = userProfilesList.get(0).getUserId();
        if (userProfilesList.isEmpty()) {
            resp.setStatus(300);
            resp.setErrmessage("用户个人档案为空，修改失败！");
        } else {
            HashMap<String, Object> ret = userInfoService.updateUserProfiles(userProfilesList);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
                throw new RuntimeException("修改用户个人档案失败！");
            }
        }
        return resp;
    }

    /**
     * 	更新用户组织关系
     */
    @Log("更新用户组织关系")
    @Transactional
    @PostMapping("/updateOR")
    public Response updateOrganizationRelationship(@RequestBody UserInfoVO vo) {
        Response resp = new Response();
        List<Staff> staffList = vo.getStaffList();
        List<Student> studentList = vo.getStudentList();
        if (staffList.isEmpty()&&studentList.isEmpty()) {
            resp.setStatus(300);
            resp.setErrmessage("用户组织关系为空，修改组织关系失败！");
        } else {
            HashMap<String, Object> ret = userInfoService.updateOR(staffList,studentList);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
                throw new RuntimeException("修改用户组织关系失败！");
            }
        }
        return resp;
    }

    /**
     * 	登陆查询学校
     */
    @GetMapping("/loginSchool")
    Response loginSchool(@RequestParam("account") String account, @RequestParam("password") String password, HttpServletRequest req, HttpServletResponse res) {
        Response resp = new Response();
        UserInfo userInfo  = new UserInfo();
        if (account == null || account=="") {
            resp.setStatus(300);
            resp.setErrmessage("用户账号为空，登录失败！");
        }else if(password ==null || password=="") {
            resp.setStatus(300);
            resp.setErrmessage("用户密码为空，登录失败！");
        }else{
            userInfo.setAccount(account);
            userInfo.setPassword(password);
            HashMap<String, Object> ret = userInfoService.loginSchool(userInfo);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }
    /**
     * 	登陆查询学校/电子科大
     */
    @PostMapping("/loginSchoolClient")
    Response loginSchoolClient(@RequestBody AccountLoginVO accountLogin) {
        Response resp = new Response();
        String account = accountLogin.getAccount();
        String password = accountLogin.getPassword();
        Integer schoolId = accountLogin.getSchoolId();
        Integer source = accountLogin.getSource();
        if (account == null || account=="") {
            resp.setStatus(300);
            resp.setErrmessage("用户账号为空，登录失败！");
        }else if(password ==null || password=="") {
            resp.setStatus(300);
            resp.setErrmessage("用户密码为空，登录失败！");
        }else{
            HashMap<String, Object> ret = userInfoService.loginSchoolClient(account,password,schoolId,source);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }


    @PostMapping("/schoolLogins")
    public Response schoolLogins(){

        return Response.ok();
    }

    /**
     * 	科大教师端登陆
     */
    @Log("科大教师端登录")
    @PostMapping("/adminLogins")
    public Response adminLogins(@RequestBody AdminLoginVO adminLogin) {
        Response resp = new Response();
        String account = adminLogin.getAccount();
        String password = adminLogin.getPassword();
        Integer source = adminLogin.getSource();
        HashMap<String, Object> map = new HashMap<>();
        if (account == null) {
            resp.setStatus(300);
            resp.setErrmessage("用户账号为空，登录失败！");
        }else if(password == null) {
            resp.setStatus(300);
            resp.setErrmessage("用户密码为空，登录失败！");
        } else{
            HashMap<String, Object> ret = userInfoService.adminLogins(account,password,source);

            int status = (int) ret.get("retcode");
            if (200 == status) {
                UserInfo userInfo1 = (UserInfo)ret.get("retvalue");
                String roleIds = userInfo1.getRoleId();

                if(roleIds.equals(null) || roleIds.equals("")){
                    resp.setStatus(401);
                    resp.setErrmessage("无登录权限，请联系管理员处理！");
                    return resp;
                }else{
                    List list = permissionService.getPermission(roleIds);
                    if (list == null){
                        resp.setStatus(401);
                        resp.setErrmessage("无登录权限，请联系管理员处理！");
                        return resp;
                    }
                    map.put("retvalue",ret.get("retvalue"));
                    map.put("listValue",list);
                }
                resp.setStatus(status);
                //resp.setMessage(ret.get("retvalue"));
                resp.setMessage(map);
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	客户端登陆
     */
    @Log("客户端登录")
    @GetMapping("/logins")
    Response logins(@RequestParam("userId") Integer userId, @RequestParam("schoolId") Integer schoolId,@RequestParam("roleId") String roleId, HttpServletRequest req, HttpServletResponse res) {
        Response resp = new Response();
        UserInfo userInfo  = new UserInfo();
        if (userId == null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id为空，登录失败！");
        }else if(schoolId ==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户学校id为空，登录失败！");
        }else if(roleId ==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户角色id为空，登录失败！");
        }
        else{
            userInfo.setRoleId(roleId);
            userInfo.setUserId(userId);
            userInfo.setSchoolId(schoolId);
            HashMap<String, Object> ret = userInfoService.logins(userInfo);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	登陆查询角色
     */
    @GetMapping("/loginRole")
    Response loginRole(@RequestParam("userId") Integer userId, @RequestParam("schoolId") Integer schoolId, HttpServletRequest req, HttpServletResponse res) {
        Response resp = new Response();
        Staff staff  = new Staff();
        Student student = new Student();
        if (userId == null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id为空，登录失败！");
        }else if(schoolId ==null) {
            resp.setStatus(300);
            resp.setErrmessage("角色id为空，登录失败！");
        }else{
//            staff.setUserId(userId);
//            staff.setSchoolId(schoolId);
//            staff.setUserId(userId);
//            staff.setSchoolId(schoolId);
            HashMap<String, Object> ret = userInfoService.loginRole(userId,schoolId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询用户详情(ID)
     */
    @GetMapping("/queryUserInfoDetails")
    Response queryUserInfoDetails(@RequestParam Integer userId) {
        Response resp = new Response();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id为空！查询失败！");
        }else {
            HashMap<String, Object> ret = userInfoService.queryUserInfoDetails(userId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询用户组织架构OR(organization relationship)
     */
    @GetMapping("/queryUserOR")
    Response queryUserOR(@RequestParam Integer userId,Integer platformId) {
        Response resp = new Response();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id为空！查询失败！");
        }else if (platformId==null){
            resp.setStatus(300);
            resp.setErrmessage("平台id为空！查询失败！");
        } else {
            Integer token = userIdUtils.getUserIdByToken();
            HashMap<String, Object> ret = userInfoService.queryUserOR(token,platformId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询用户个人档案
     */
    @GetMapping("/queryUserProfiles")
    Response queryUserProfiles(@RequestParam Integer userId) {
        Response resp = new Response();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id为空！查询失败！");
        }else {
            Integer token = userIdUtils.getUserIdByToken();
            HashMap<String, Object> ret = userInfoService.queryUserProfiles(token);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    @PostMapping("/uploadUserAvatars")
    Response uploadUserAvatars(MultipartFile file, Integer userId) {
        Response resp = new Response();
        if (userId==null) {//前台传来的值是否为空
            resp.setStatus(300);
            resp.setErrmessage("Parameter Invalid");
        }else {
            HashMap<String, Object> ret = userInfoService.uploadUserAvatars(file,userId);

            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	更新登录次数和时间
     */
    @PostMapping("/updateLogInNumber")
    Response updateLogInNumber(@RequestBody UserInfo user) {
        Response resp = new Response();
        Integer userId = user.getUserId();
        if (userId==null) {
            resp.setStatus(300);
            resp.setErrmessage("用户id不能为空!");
        }else{
            HashMap<String, Object> ret = userInfoService.updateLogInNumber(user);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }
    /**
     * 	用户模块查询客户
     */
    @GetMapping("/queryCustomer")
    Response queryCustomer(@RequestParam String searchContent,@RequestParam List<Integer> customerIds) {
        Response resp = new Response();
            HashMap<String, Object> ret = userInfoService.queryCustomer(searchContent,customerIds);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        return resp;
    }

    /**
     * 	查询账号是否存在
     */
    @GetMapping("/queryAccountIsExist")
    Response queryAccountIsExist(@RequestParam String account,Integer schoolId) {
        Response resp = new Response();
        if (account == null && account == "") {
            resp.setStatus(300);
            resp.setErrmessage("账号为空！");
        }else if (schoolId==null){
            resp.setStatus(300);
            resp.setErrmessage("学校为空！");
        }
        else {
            HashMap<String, Object> ret = userInfoService.queryAccountIsExist(account,schoolId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询服务端账号是否存在
     */
    @GetMapping("/queryServerAccountIsExist")
    Response queryServerAccountIsExist(@RequestParam String account) {
        Response resp = new Response();
        if (account==null&&account=="") {
            resp.setStatus(300);
            resp.setErrmessage("账号为空！");
        } else {
            HashMap<String, Object> ret = userInfoService.queryServerAccountIsExist(account);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 查询学号、工号是否存在
     */
    @GetMapping("/queryWorkNumberIsExist")
    Response queryWorkNumberIsExist(@RequestParam String workNumber,Integer roleId,Integer schoolId) {
        Response resp = new Response();
        if (workNumber==null){
            resp.setStatus(300);
            resp.setErrmessage("学号、工号为空！");
        }else if (roleId==null){
           resp.setStatus(300);
           resp.setErrmessage("角色id为空！");
        }
        else {
            HashMap<String, Object> ret = userInfoService.queryWorkNumberIsExist(workNumber,roleId,schoolId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询平台
     */
    @GetMapping("/queryPlatform")
    Response queryPlatform(@RequestParam String platformId) {
        Response resp = new Response();
        UserInfo userInfo  = new UserInfo();
        //平台id
        if (platformId==null&&platformId=="") {
            resp.setStatus(300);
            resp.setErrmessage("平台id为空！");
        }else{
            HashMap<String, Object> ret = userInfoService.queryPlatform(platformId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            }else{
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	删除平台
     */
    @Log("删除平台")
    @PostMapping("/deletePlatform")
    Response deletePlatform(@RequestBody OrganizationRelationship OR) {
        Response resp = new Response();
        Integer platformId = OR.getPlatformId();
        Integer userId = OR.getUserId();
        //平台id
        if (platformId==null) {
            resp.setStatus(300);
            resp.setErrmessage("平台id为空！");
        }else if(userId==null){
            resp.setStatus(300);
            resp.setErrmessage("用户id为空！");
        }
        else{
            HashMap<String, Object> ret = userInfoService.deletePlatform(platformId,userId);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 	查询平台
     */
    @GetMapping("/queryStuAndSta")
    Response queryStuAndSta(@RequestParam Integer platformId,Integer userId) {
        Response resp = new Response();
        UserInfo userInfo  = new UserInfo();
        //平台id
        if (platformId==null) {
            resp.setStatus(300);
            resp.setErrmessage("平台id为空！");
        }else{
            Integer token = userIdUtils.getUserIdByToken();
            HashMap<String, Object> ret = userInfoService.queryStuAndSta(platformId,token);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    	/**
	 * 	查询电话
	 */
	@GetMapping("/queryPhone")
	Response queryPhone(@RequestParam String phone) {
		Response resp = new Response();
		if (phone==null||phone=="") {//前台传来的值是否为空
			resp.setStatus(300);
			resp.setErrmessage("手机号为空！查询失败！");
		}else {
			HashMap<String, Object> ret = userInfoService.queryPhone(phone);
			int status = (int) ret.get("retcode");
			if (200 == status) {
				resp.setStatus(status);
				resp.setMessage(ret.get("retvalue"));
			} else {
				resp.setStatus(status);
				resp.setErrmessage(ret.get("retvalue").toString());
			}
		}
		return resp;
	}

    /**
     * 	查询token是否存在
     */
    @GetMapping("/queryToken")
    Response queryToken(@RequestParam String token) {
        Response resp = new Response();
        if (token==null||token=="") {//前台传来的值是否为空
            resp.setStatus(300);
            resp.setErrmessage("token为空,查询失败！");
        }else {
            HashMap<String, Object> ret = userInfoService.queryToken(token);
            int status = (int) ret.get("retcode");
            if (200 == status) {
                resp.setStatus(status);
                resp.setMessage(ret.get("retvalue"));
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        }
        return resp;
    }

    /**
     * 根据角色id查询具有超管和管理员角色的账户的人（角色id必须唯一）
     * @return
     */
    @GetMapping("/queryUserIds")
    Response queryUserIds() {
        Response resp = new Response();
            HashMap<String, Object> ret = userInfoService.queryUserIds();
            int status = (int) ret.get("retcode");
            Map map = new HashMap();
            if (200 == status) {
                resp.setStatus(status);
                map.put("retvalue",ret.get("retvalue"));
                resp.setMessage(map);
            } else {
                resp.setStatus(status);
                resp.setErrmessage(ret.get("retvalue").toString());
            }
        return resp;
    }
}