package com.yipin.liuwanr.helper;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import org.elasticsearch.action.admin.indices.delete.DeleteIndexRequest;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.index.IndexResponse;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.action.support.master.AcknowledgedResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.client.indices.CreateIndexRequest;
import org.elasticsearch.client.indices.CreateIndexResponse;
import org.elasticsearch.common.xcontent.XContentBuilder;
import org.elasticsearch.common.xcontent.XContentType;
import org.elasticsearch.common.xcontent.json.JsonXContent;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.MatchQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

@Repository
public class ElasticHelper {

	@Autowired
	private RestHighLevelClient client;

	private final String DEFAULTINDEX = "test";
	private final String DEFAULTYPE = "_doc";

	public void create(String indexName) throws IOException {
		CreateIndexRequest index = new CreateIndexRequest(StringUtils.isEmpty(indexName)?DEFAULTINDEX:indexName);
		Map<String, Map<String, Object>> properties = new HashMap<String, Map<String, Object>>();
		Map<String, Object> propertie1 = new HashMap<String, Object>();
		propertie1.put("type", "keyword");
		propertie1.put("index", true);
		properties.put("key", propertie1);
		Map<String, Object> propertie2 = new HashMap<String, Object>();
		propertie2.put("type", "text");
		propertie2.put("index", true);
		propertie2.put("analyzer", "ik_max_word");
		properties.put("value", propertie2);
		Map<String, Object> propertie3 = new HashMap<String, Object>();
		propertie3.put("type", "date");
		propertie3.put("index", true);
		properties.put("timestamp", propertie3);
		Map<String, Object> propertie4 = new HashMap<String, Object>();
		propertie4.put("type", "date");
		propertie4.put("index", true);
		properties.put("@servertime", propertie4);

		XContentBuilder builder = JsonXContent.contentBuilder();
		builder.startObject().startObject("mappings").startObject("index_name").field("properties", properties)
				.endObject().endObject().endObject();
		index.source(builder);
		CreateIndexResponse response = client.indices().create(index, RequestOptions.DEFAULT);
		if(!response.isAcknowledged()){
			throw new IOException();
		}
	}

	public void delete(String indexName) throws IOException {
		DeleteIndexRequest request = new DeleteIndexRequest(StringUtils.isEmpty(indexName)?DEFAULTINDEX:indexName);
		AcknowledgedResponse response = client.indices().delete(request, RequestOptions.DEFAULT);
		if(!response.isAcknowledged()){
			throw new IOException();
		}
	}

	public int set(String key, String value, long timestamp) throws IOException {
		IndexRequest indexRequest = new IndexRequest();
		HashMap<String,Object> content = new HashMap<String,Object>();
		content.put("key", key);
		content.put("value", value);
		content.put("timestamp", timestamp==0?System.currentTimeMillis():timestamp);
		content.put("@servertime", System.currentTimeMillis());
		indexRequest.index(DEFAULTINDEX).source(JSON.toJSONString(content), XContentType.JSON);
		IndexResponse response = client.index(indexRequest, RequestOptions.DEFAULT);
		return response.status().getStatus();
	}

	public int set(String indexName, String key, String value, long timestamp) throws IOException {
		IndexRequest indexRequest = new IndexRequest();
		HashMap<String,Object> content = new HashMap<String,Object>();
		content.put("key", key);
		content.put("value", value);
		content.put("timestamp", timestamp==0?System.currentTimeMillis():timestamp);
		content.put("@servertime", System.currentTimeMillis());
		indexRequest.index(indexName).source(JSON.toJSONString(content), XContentType.JSON);
		IndexResponse response = client.index(indexRequest, RequestOptions.DEFAULT);
		return response.status().getStatus();
	}

	public String get(String key) throws IOException {
		SearchRequest searchRequest = new SearchRequest();
		SearchSourceBuilder sourceBuilder = new SearchSourceBuilder();
		sourceBuilder.from(0);
		sourceBuilder.size(10);
		BoolQueryBuilder boolBuilder = QueryBuilders.boolQuery();
		MatchQueryBuilder matchQueryBuilder = QueryBuilders.matchQuery("key", key);
		boolBuilder.must(matchQueryBuilder);
		searchRequest.indices(DEFAULTINDEX).source(sourceBuilder);
		SearchResponse response = client.search(searchRequest, RequestOptions.DEFAULT);
		JSONObject ret = new JSONObject();
		JSONArray hits = new JSONArray();
		for(SearchHit h : response.getHits().getHits()){
			hits.add(h.getSourceAsMap());
		}
		ret.put("total", response.getHits().getTotalHits());
		ret.put("hits", hits);
		return ret.toJSONString();
	}
}
