package com.yipin.liuwanr.helper;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.vo.MakeupStudentsVo;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.util.StringUtils;
import org.springframework.web.multipart.MultipartFile;

import com.yipin.liuwanr.entity.Makeuplist;
import com.yipin.liuwanr.entity.Staff;
import com.yipin.liuwanr.entity.Student;

public class ExcelImportHelper {

	/**
	 * 读取补考名单
	 * @param file
	 * @return
	 */
	public static HashMap<String,Object> readExcel(MultipartFile file) {
		HashMap<String,Object> resp=new HashMap<String,Object>();
		List<Makeuplist> list = new ArrayList<Makeuplist>();
		List<String> names=new ArrayList<String>();
		Integer uploadType=null;
		try {
			String fileName = file.getOriginalFilename();
			Workbook workbook = null;
			if (fileName.endsWith("xlsx")) {
				workbook = new XSSFWorkbook(file.getInputStream());// Excel 2007
			} else if (fileName.endsWith("xls")) {
				workbook = new HSSFWorkbook(file.getInputStream());// Excel 2003
			}
			Makeuplist makeuplist = null;
			// 循环工作表Sheet

				Sheet hssfSheet = workbook.getSheetAt(0);
				if (hssfSheet != null) {
					Row row1 = hssfSheet.getRow(0);
					if(row1!=null){
						row1.getCell(0).setCellType(CellType.STRING);
						Cell readClassName = row1.getCell(0);
						String  readName=readClassName.getStringCellValue();
						if(!StringUtils.isEmpty(readName)){
							if(readName.equals("实验班级名称")){
								uploadType=0;
							}else if(readName.equals("行政班级名称")){
								uploadType=1;
							}else{
								throw new RuntimeException("数据模板被修改");
							}
						}
						// 循环行Row
						for (int rowNum = 1; rowNum <= hssfSheet.getLastRowNum(); rowNum++) {
							Row row = hssfSheet.getRow(rowNum);
							if (row != null) {
								makeuplist = new Makeuplist();
								row.getCell(0).setCellType(CellType.STRING);
								Cell className = row.getCell(0);
								row.getCell(1).setCellType(CellType.STRING);
								Cell studentNumber = row.getCell(1);
								row.getCell(2).setCellType(CellType.STRING);
								Cell studentName = row.getCell(2);
								if(uploadType.equals(0)){
									String name=className.getStringCellValue();
									names.add(name);
								}
								makeuplist.setClassName(className.getStringCellValue());
								makeuplist.setStudentNumber(studentNumber.getStringCellValue());
								makeuplist.setStudentName(studentName.getStringCellValue());
								list.add(makeuplist);
							}
						}
						if(uploadType.equals(0)){
							if(!names.isEmpty()&&names.size()>0){
								for (int i=0;i<names.size()-1;i++){
									String name1=names.get(i);
									String name2=names.get(i+1);
									if(!name1.equals(name2)){
										return  null;
									}
								}
							}
						}
					}else{
						return  null;
					}

				}
			resp.put("uploadType",uploadType);
			resp.put("makeuplists",list);
		} catch (Exception e) {
		}

		return resp;
	}

	/**
	 * 读取学生管理
	 * @param file
	 * @return
	 */
	public static List<Student> readStudent(MultipartFile file) {
		List<Student> list = new ArrayList<Student>();

		Workbook workbook=getWorkbook(file);
		Student student = null;
		// 循环工作表Sheet
		for (int numSheet = 0; numSheet < workbook.getNumberOfSheets(); numSheet++) {
			Sheet hssfSheet = workbook.getSheetAt(numSheet);
			if (hssfSheet == null) {
				continue;
			}
			// 循环行Row
			for (int rowNum = 1; rowNum <= hssfSheet.getLastRowNum(); rowNum++) {
				Row row = hssfSheet.getRow(rowNum);

				if (row != null) {
					student = new Student();
					row.getCell(0).setCellType(CellType.STRING);
					Cell studentName = row.getCell(0);
					row.getCell(2).setCellType(CellType.STRING);
					Cell studentNumber = row.getCell(2);
					row.getCell(3).setCellType(CellType.STRING);
					Cell professionalName = row.getCell(3);
					row.getCell(4).setCellType(CellType.STRING);
					Cell gradeName = row.getCell(4);
					row.getCell(5).setCellType(CellType.STRING);
					Cell className = row.getCell(5);
					row.getCell(6).setCellType(CellType.STRING);
					Cell phone = row.getCell(6);
					row.getCell(7).setCellType(CellType.STRING);
					Cell email = row.getCell(7);
				

					// 学生姓名
					student.setStudentName(studentName.getStringCellValue());
					// 角色id
					student.setRoleId(4);
					// 学生学号
					student.setWorkNumber(studentNumber.getStringCellValue());
					//专业
					student.setProfessionalName(professionalName.getStringCellValue());
					//年级
					student.setGradeName(gradeName.getStringCellValue());
					// 班级
					student.setClassName(className.getStringCellValue());
					// 电话
					student.setPhone(phone.getStringCellValue());
					//邮箱
					student.setEmail(email.getStringCellValue());				
					// 唯一标示性账号
					student.setUniqueIdentificationAccount(Long.toString(System.currentTimeMillis()));
					list.add(student);
				}
			}

		}

		return list;
	}

	/**
	 * 读取员工管理
	 * @param file
	 * @return
	 */
	public static List<Staff> readStaff(MultipartFile file) {
		List<Staff> list = new ArrayList<Staff>();

		Workbook workbook=getWorkbook(file);
		Staff staff = null;
		// 循环工作表Sheet
		for (int numSheet = 0; numSheet < workbook.getNumberOfSheets(); numSheet++) {
			Sheet hssfSheet = workbook.getSheetAt(numSheet);
			if (hssfSheet == null) {
				continue;
			}
			// 循环行Row
			for (int rowNum = 1; rowNum <= hssfSheet.getLastRowNum(); rowNum++) {
				Row row = hssfSheet.getRow(rowNum);

				if (row != null) {
					staff = new Staff();
					row.getCell(0).setCellType(CellType.STRING);
					Cell staffName = row.getCell(0); // 员工姓名
					row.getCell(2).setCellType(CellType.STRING);
					Cell staffWorkNumber = row.getCell(2); // 员工工号
					row.getCell(3).setCellType(CellType.STRING);
					Cell staffProfessionalArchitectureName = row.getCell(3); // 部门
					row.getCell(4).setCellType(CellType.STRING);
					Cell staffGradeName = row.getCell(4);// 手机
					row.getCell(5).setCellType(CellType.STRING);
					Cell phone = row.getCell(5);// 手机
					row.getCell(6).setCellType(CellType.STRING);
					Cell email = row.getCell(6);// 手机

					// 职工姓名
					staff.setStaffName(staffName.getStringCellValue());
					// 角色id
					staff.setRoleId(3);
					// 职工工号
					staff.setWorkNumber(staffWorkNumber.getStringCellValue());
					// 专业
					staff.setStaffProfessionalArchitectureName(staffProfessionalArchitectureName.getStringCellValue());
                    //部门
					staff.setStaffGradeName(staffGradeName.getStringCellValue());
					// 电话
					staff.setPhone(phone.getStringCellValue());
					//邮箱
					staff.setEmail(email.getStringCellValue());
					// 唯一标示性账号
					staff.setUniqueIdentificationAccount(Long.toString(System.currentTimeMillis()));

					list.add(staff);
				}
			}

		}
		return list;
	}

	
	private static  Workbook getWorkbook(MultipartFile file) {
		String fileName = file.getOriginalFilename();
		Workbook workbook = null;
	
		if (fileName.endsWith("xlsx")) {
			try {
				workbook = new XSSFWorkbook(file.getInputStream());
			} catch (IOException e) {
				e.printStackTrace();
			}
		}else if (fileName.endsWith("xls")) {
			try {
				workbook = new HSSFWorkbook(file.getInputStream());
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return workbook;
	}
}
