package com.yipin.liuwanr.helper;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.http.HttpServletResponse;

import org.jboss.logging.Logger;
import org.springframework.web.multipart.MultipartFile;

import com.aliyun.oss.ClientException;
import com.aliyun.oss.OSSClient;
import com.aliyun.oss.OSSException;
import com.aliyun.oss.model.CannedAccessControlList;
import com.aliyun.oss.model.CreateBucketRequest;
import com.aliyun.oss.model.OSSObject;
import com.aliyun.oss.model.ObjectMetadata;
import com.aliyun.oss.model.PutObjectRequest;
import com.yipin.liuwanr.AliyunOssConfig;
import com.yipin.liuwanr.entity.FilesResult;



public class OssConfigUtil {

	private static String sdf = new SimpleDateFormat("yyyyMMdd").format(new Date());

	private static Logger logger = Logger.getLogger(OssConfigUtil.class);

	/**
	 * 创建存储空间
	 * 
	 * @param client
	 */
	public static void createBucket(OSSClient client, AliyunOssConfig config) {
		// 判断存储空间是否存在，不存在，则创建
		if (!client.doesBucketExist(config.getBucketName())) {
			CreateBucketRequest bucketRequest = new CreateBucketRequest(null);
			// 设置仓库名称
			bucketRequest.setBucketName(config.getBucketName());
			// 设置仓库权限
			bucketRequest.setCannedACL(CannedAccessControlList.PublicRead);
			// 创建仓库
			client.createBucket(bucketRequest);
		}
	}

	/**
	 * 上传文件
	 * 
	 * @param file 需要上传的文件
	 * @return
	 * @throws IOException 
	 * @throws ClientException 
	 * @throws OSSException 
	 */
	public static FilesResult uploadFiles(MultipartFile file, OSSClient client, AliyunOssConfig config) throws OSSException, ClientException, IOException {
		FilesResult result = new FilesResult();
		// 创建存储空间
		createBucket(client, config);
		// 获取文件名
		String fileUrl = file.getOriginalFilename();
		// 获取文件尾缀
		String ext = fileUrl.substring(fileUrl.lastIndexOf("."));
		// 获取文件类型
		String fileType = getFileType(ext);
		//创建文件
		String folderName=ext.substring(ext.indexOf(".")+1);
		String folder=createFolder(client,config.getBucketName(),folderName);
		// 组合储存路径
		String fileName = folder + "/" + sdf + "/" + System.currentTimeMillis() + ext;
		long fileSize = file.getSize();
		
		ObjectMetadata metadata = new ObjectMetadata();
		// 指定该Object被下载时的网页的缓存行为
		metadata.setCacheControl("no-cache");
		// 指定该Object下设置Header
		metadata.setHeader("Pragma", "no-cache");
		// 指定该Object被下载时的内容编码格式
		metadata.setContentEncoding("utf-8");
		// 文件的MIME，定义文件的类型及网页编码，决定浏览器将以什么形式、什么编码读取文件。如果用户没有指定则根据Key或文件名的扩展名生成，
		// 如果没有扩展名则填默认值application/octet-stream
		metadata.setContentType(fileType);
		// 指定该Object被下载时的名称（指示MINME用户代理如何显示附加的文件，打开或下载，及文件名称）
		metadata.setContentDisposition("filename/filesize=" + file.getName() + "/" + fileSize + "Byte.");
		// 上传文件 (上传文件流的形式)
		client.putObject(config.getBucketName(), fileName, new ByteArrayInputStream(file.getBytes()), metadata);
		result.setFileName(fileName);
		result.setFileUrl(config.getSufferUrl() + fileName);
	
		if (null != client)
			client.shutdown();
		
		return result;
	}
	
	/**
	 * 用户头像上传
	 * @param file 需要上传的文件
	 * @return
	 * @throws IOException 
	 * @throws ClientException 
	 * @throws OSSException 
	 */
	public static FilesResult uploadUserAvatars(MultipartFile file, OSSClient client, AliyunOssConfig config) throws OSSException, ClientException, IOException {
		FilesResult result = new FilesResult();
		String userAvatars=config.getUserAvatars();
		// 创建存储空间
		createBucket(client, config);
		// 获取文件名
		String fileUrl = file.getOriginalFilename();
		// 获取文件尾缀
		String ext = fileUrl.substring(fileUrl.lastIndexOf("."));
		// 获取文件类型
		String fileType = getFileType(ext);
		// 组合储存路径
		String fileName = userAvatars + "/" + sdf + "/" + System.currentTimeMillis() + ext;
		long fileSize = file.getSize();
		
		ObjectMetadata metadata = new ObjectMetadata();
		// 指定该Object被下载时的网页的缓存行为
		metadata.setCacheControl("no-cache");
		// 指定该Object下设置Header
		metadata.setHeader("Pragma", "no-cache");
		// 指定该Object被下载时的内容编码格式
		metadata.setContentEncoding("utf-8");
		// 文件的MIME，定义文件的类型及网页编码，决定浏览器将以什么形式、什么编码读取文件。如果用户没有指定则根据Key或文件名的扩展名生成，
		// 如果没有扩展名则填默认值application/octet-stream
		metadata.setContentType(fileType);
		// 指定该Object被下载时的名称（指示MINME用户代理如何显示附加的文件，打开或下载，及文件名称）
		metadata.setContentDisposition("filename/filesize=" + file.getName() + "/" + fileSize + "Byte.");
		// 上传文件 (上传文件流的形式)
		client.putObject(config.getBucketName(), fileName, new ByteArrayInputStream(file.getBytes()), metadata);
		result.setFileName(fileName);
		result.setFileUrl(config.getSufferUrl() + fileName);
	
		if (null != client)
			client.shutdown();
		
		return result;
	}
	
	
	/**
	 * 简单上传
	 * @param client
	 * @param config
	 * @param objectName:表示上传文件到OSS时需要指定包含文件后缀在内的完整路径，例如abc/efg/123.jpg。
	 * @param stream
	 * @return
	 */
	public static FilesResult uploadFiles(OSSClient client, AliyunOssConfig config,String objectName,ByteArrayInputStream stream) {
		FilesResult result = new FilesResult();
		try {
			 PutObjectRequest putObjectRequest = new PutObjectRequest(config.getBucketName(), objectName, stream);
	         client.putObject(putObjectRequest);
	         result.setFileName(objectName);
             result.setFileUrl(config.getSufferUrl()+objectName);
             
		} catch (Exception e) {
			 logger.info(e.getMessage());
		}finally {
			if (null != client)
				client.shutdown();
		}
		return result;
	    
	}
	
	
	/**
	 * 文件下载
	 * 
	 * @param objectName 下载的文件名称
	 * @param fileurl    本地路径
	 * @throws IOException 
	 */
	public static void downloadFiles(HttpServletResponse response, OSSClient client, AliyunOssConfig config,
			String objectName) {

		OSSObject ossObject = client.getObject(config.getBucketName(), objectName);
		InputStream input=null;
		OutputStream outputStream=null;
		try {
			// 获取文件名
			String fileName = objectName.substring(objectName.lastIndexOf("/") + 1);
            //获取输入流
			input = ossObject.getObjectContent();
			// 获取OutputStream输出流
			outputStream = response.getOutputStream();
			byte[] buffer = new byte[input.available()];

			response.setHeader("content-Type", "application/vnd.ms-excel");
			response.setHeader("Content-disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
			response.flushBuffer();

			for (int length = 0; (length = input.read(buffer)) > 0;) {
				outputStream.write(buffer, 0, length);
			}
		} catch (Exception e) {
			logger.info(e.getMessage());
		} finally {
            if(null!=outputStream) {
            	try {
					outputStream.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
            }
            if(null!=input) {
            	try {
            		input.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
            }
			if (null != client)
				client.shutdown();
		}

	}

	/**
	 * 删除存储空间buckName
	 * 
	 * @param ossClient  oss对象
	 * @param bucketName 存储空间
	 */
	public static void deleteBucket(OSSClient ossClient, String bucketName) {
		ossClient.deleteBucket(bucketName);
	}

	/**
	 * 创建模拟文件夹
	 * 
	 * @param ossClient  oss连接
	 * @param bucketName 存储空间
	 * @param folder     模拟文件夹名如"qj_nanjing/"
	 * @return 文件夹名
	 */
	public static String createFolder(OSSClient ossClient, String bucketName, String folder) {
		// 文件夹名
		final String keySuffixWithSlash = folder;
		// 判断文件夹是否存在，不存在则创建
		if (!ossClient.doesObjectExist(bucketName, keySuffixWithSlash)) {
			// 创建文件夹
			ossClient.putObject(bucketName, keySuffixWithSlash, new ByteArrayInputStream(new byte[0]));
			// 得到文件夹名
			OSSObject object = ossClient.getObject(bucketName, keySuffixWithSlash);
			String fileDir = object.getKey();
			return fileDir;
		}
		return keySuffixWithSlash;
	}

	/**
	 * 根据key删除OSS服务器上的文件
	 * 
	 * @param ossClient  oss连接
	 * @param bucketName 存储空间
	 * @param folder     模拟文件夹名 如"qj_nanjing/"
	 * @param key        Bucket下的文件的路径名+文件名 如："upload/cake.jpg"
	 */
	public static void deleteFile(OSSClient ossClient, String bucketName, String fileName) {
		ossClient.deleteObject(bucketName, fileName);
	}

	/**
	 * 获取文件类型
	 * 
	 * @param fileExtension 文件后缀
	 * @return
	 */
	public static String getFileType(String fileExtension) {
		if (".bmp".equalsIgnoreCase(fileExtension)) {
			return "image/bmp";
		}
		if (".gif".equalsIgnoreCase(fileExtension)) {
			return "image/gif";
		}
		if (".jpeg".equalsIgnoreCase(fileExtension) || ".jpg".equalsIgnoreCase(fileExtension)
				|| ".png".equalsIgnoreCase(fileExtension)) {
			return "image/jpg";
		}
		if (".html".equalsIgnoreCase(fileExtension)) {
			return "text/html";
		}
		if (".txt".equalsIgnoreCase(fileExtension)) {
			return "text/plain";
		}
		if (".vsd".equalsIgnoreCase(fileExtension)) {
			return "application/vnd.visio";
		}
		if (".ppt".equalsIgnoreCase(fileExtension) || ".pptx".equalsIgnoreCase(fileExtension)) {
			return "application/vnd.ms-powerpoint";
		}
		if (".doc".equalsIgnoreCase(fileExtension) || ".docx".equalsIgnoreCase(fileExtension)) {
			return "application/msword";
		}
		if (".xml".equalsIgnoreCase(fileExtension)) {
			return "text/xml";
		}
		if (".mp4".equalsIgnoreCase(fileExtension)||".avi".equalsIgnoreCase(fileExtension)) {
			return "video/mp4";
		}
		if (".mpg".equalsIgnoreCase(fileExtension) || ".mpeg".equalsIgnoreCase(fileExtension)) {
			return "video/mpeg";
		}
		if("pdf".equalsIgnoreCase(fileExtension)) {
			return "application/pdf";
		}
		return "application/octet-stream";
	}

}
