package com.yipin.liuwanr.helper;

import java.math.BigDecimal;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.HashMap;
import java.util.Random;
import java.util.UUID;
import java.util.zip.CRC32;

import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.SecretKeySpec;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang3.ArrayUtils;
import org.jboss.logging.Logger;

public class RandomUtil {

	private static Logger logger = Logger.getLogger(RandomUtil.class);

	/**
	 * 自动生成32位的UUid，对应数据库的主键id进行插入用。
	 * 
	 * @return
	 */
	public static String getUUID() {
		return UUID.randomUUID().toString().replace("-", "");
	}

	/**
	 * 自动生成16位的Token,返回给客户端进行鉴权。
	 * 
	 * @return
	 */
	public static String getToken(String uuid) {
		String token = null;
		if (uuid.isEmpty()) {
			return null;
		}
		try {
			String oritoken = System.currentTimeMillis() + new Random().nextInt() + uuid;
			byte[] md5 = MessageDigest.getInstance("md5").digest(oritoken.getBytes());
			token = Base64.encodeBase64URLSafeString(md5);
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getMessage());
		}
		return token;
	}

	/**
	 * 自动生成16位的RefreshToken,返回给客户端进行鉴权。
	 * 
	 * @return
	 */
	public static String getToken(String uuid, String token) {
		String refreshtoken = null;
		if (uuid.isEmpty()) {
			return null;
		}
		try {
			String oritoken = token + System.currentTimeMillis() + new Random().nextInt() + uuid;
			byte[] md5 = MessageDigest.getInstance("md5").digest(oritoken.getBytes());
			refreshtoken = Base64.encodeBase64URLSafeString(md5);
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getMessage());
		}
		return refreshtoken;
	}

	/**
	 * 获取字符串的MD5签名的字节数组。
	 * 
	 * @return
	 */
	public static byte[] getMD5Bytes(byte[] string) {
		try {
			return MessageDigest.getInstance("MD5").digest(string);
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getMessage());
		}
		return null;
	}

	/**
	 * 获取字符串的MD5签名。
	 * 
	 * @return
	 */
	public static String getMD5String(byte[] string) {
		try {
			byte[] md5pass = MessageDigest.getInstance("MD5").digest(string);
			StringBuilder sb = new StringBuilder();
			for (byte b : md5pass) {
				sb.append(String.format("%02x", b & 0xff));
			}
			return sb.toString();
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getMessage());
		}
		return null;
	}

	/**
	 * 将客户端加密后的密码解密并MD5。
	 * 
	 * @return
	 */
	public static String parsePassword(String password) {
		byte[] bytearr = Base64.decodeBase64(password);
		byte[] high = new byte[4];
		byte[] low = new byte[4];
		byte[] crc = new byte[8];
		byte[] content = new byte[bytearr.length - 8];
		String passwordToStore = null;
		try {
			System.arraycopy(bytearr, 0, high, 0, 4);
			System.arraycopy(bytearr, bytearr.length - 4, low, 0, 4);
			System.arraycopy(bytearr, 4, content, 0, bytearr.length - 8);
			crc = ArrayUtils.addAll(high, low);
			// KeyGenerator kg = KeyGenerator.getInstance("AES");
			// kg.init(128, new SecureRandom(crc));
			// SecretKeySpec sks = new
			// SecretKeySpec(kg.generateKey().getEncoded(), "AES");
			SecretKeySpec sks = new SecretKeySpec(ArrayUtils.addAll(crc, crc), "AES");
			Cipher cp = Cipher.getInstance("AES");
			cp.init(Cipher.DECRYPT_MODE, sks);
			byte[] truepass = cp.doFinal(content);
			logger.info(new String(truepass));
			passwordToStore = getMD5String(truepass);
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getCause());
		} catch (NoSuchPaddingException e) {
			logger.error(e.getCause());
		} catch (InvalidKeyException e) {
			logger.error(e.getCause());
		} catch (IllegalBlockSizeException e) {
			logger.error(e.getCause());
		} catch (BadPaddingException e) {
			logger.error(e.getCause());
		}
		return passwordToStore;
	}
	
	public static String getNonce(String mobile){
		CRC32 crcEncoder = new CRC32();
		crcEncoder.update((mobile + System.currentTimeMillis()).getBytes());
		return Long.toHexString(crcEncoder.getValue());
	}
	
	/**
	 * 计算并获取CheckSum.
	 * 
	 * @return
	 */
	public static String getCheckSum(String appSecret, String nonce, String curTime) {
		String value = appSecret + nonce + curTime;
		try {
			MessageDigest messageDigest = MessageDigest.getInstance("SHA1");
			messageDigest.update(value.getBytes());
			StringBuilder sb = new StringBuilder();
			for (byte b : messageDigest.digest()) {
				sb.append(String.format("%02x", b & 0xff));
			}
			return sb.toString().toLowerCase();
		} catch (NoSuchAlgorithmException e) {
			logger.error(e.getLocalizedMessage());
			return null;
		}
	}
	
	/**
	 * 获取随机经纬度.
	 * 
	 * @return
	 */
	public static HashMap<String,Double> randomLonLat(double MinLon, double MaxLon, double MinLat, double MaxLat) {
		HashMap<String,Double> ret = new HashMap<String,Double>();
	    BigDecimal db = new BigDecimal(Math.random() * (MaxLon - MinLon) + MinLon);
	    Double lon = db.setScale(6, BigDecimal.ROUND_HALF_UP).doubleValue();
	    db = new BigDecimal(Math.random() * (MaxLat - MinLat) + MinLat);
	    Double lat = db.setScale(6, BigDecimal.ROUND_HALF_UP).doubleValue();
	    ret.put("longitude", lon);
	    ret.put("latitude", lat);
	    return ret;
	  }
}