package com.yipin.liuwanr.mapper;

import java.util.List;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.entity.Class;
import org.apache.ibatis.annotations.*;

/**
 * 考核
 * @author 或然
 *
 */
@Mapper
public interface AssesmentMapper {


    /**
     * 查询项目权限为考核的项目
     *
     * @return
     */
    @Select("select projectId,projectName,projectPermissions,founder,creationTime from hr_project_management " +
            " where isdel=0 and projectPermissions=1 AND systemId in (select systemId FROM hr_course_tc where courseId=#{courseId} GROUP BY systemId)")
    List<Project_Management> queryGetByAssesmentProject(Integer courseId);


    /**
     * 考核列表信息查询
     *
     * @param assesment
     * @return
     */
    @Select({"<script>",
            "SELECT a.id,a.assesmentName as assesmentName,a.assessmentSize as assessmentSize,p.projectName as projectName,a.timeSum as timeSum,GROUP_CONCAT(c.className) as className,"
            + "a.releaseType as releaseType,a.creationTime as creationTime,a.endTime as endTime,a.assesmentState as assesmentState FROM "
            + "(assessment a left join hr_project_management p on a.experimentId=p.projectId ) left join class c  on FIND_IN_SET(c.classId,a.classId )>0  "
            + "WHERE a.staffId=#{staffId} AND a.courseId=#{courseId} ",
            " <if test='month==1'>and a.creationTime>DATE_SUB(CURDATE(), INTERVAL 1 MONTH)</if>",
            " <if test='month==3'>and a.creationTime>DATE_SUB(CURDATE(), INTERVAL 3 MONTH)</if>",
            " <if test='month==6'>and a.creationTime>DATE_SUB(CURDATE(), INTERVAL 6 MONTH)</if>",
            " <if test='creationTime!=null and endTime!=null and endTime!=\"\" and creationTime!=\"\" '> and a.creationTime between #{creationTime} and #{endTime}</if>",
            " <if test='releaseType!=null'>and a.releaseType=#{releaseType} </if>",
            " <if test='assesmentState!=null'>and a.assesmentState=#{assesmentState} </if>",
            " <if test='className!=null  and className!=\"\"'>and c.className like concat('%',#{className},'%') </if>",
            " GROUP BY a.id  ORDER BY a.id desc ",
            "</script> "})
    List<Assesment> getByCondition(Assesment assesment);


    /**
     * 查询选中的学生，有哪些正在参与考核
     *
     * @param studentIds
     * @return
     */
    @Select({"<script>",
            "select studentName from student where isAssess=1 and studentId  in "
                    + "<foreach collection='studentIds' item='stu' open='(' separator=',' close=')'>"
                    + "#{stu}"
                    + "</foreach> ",
            "</script>"})
    List<Student> queryStudentisAssess(@Param("studentIds") List<Integer> studentIds);


    /**
     * 创建考核
     *
     * @param assesment
     */
    @Insert("insert into assessment (assesmentName,releaseType,creationTime,endTime,timesum,experimentId,classId,assesmentState,assessmentSize,experimentalClassId,staffId,courseId,assessmentNumber)"
            + " values (#{assesmentName},#{releaseType},#{creationTime},#{endTime},#{timesum},#{experimentId},#{classId},#{assesmentState},#{assessmentSize},#{experimentalClassId},#{staffId},#{courseId},#{assessmentNumber})")
    @Options(useGeneratedKeys = true, keyColumn = "id", keyProperty = "id")
    void insertAssesment(Assesment assesment);


    @Delete("delete from assessment where id=#{id}")
    boolean deleteAssesment(Integer assesmentId);


    /**
     * 修改考核
     *
     * @param assesment
     */
    @Update("update assessment set assesmentName=#{assesmentName},releaseType=#{releaseType},creationTime=#{creationTime},endTime=#{endTime},timesum=#{timesum},assessmentSize=#{assessmentSize},assessmentNumber=#{assessmentNumber},"
            + "experimentId=#{experimentId},assesmentState=#{assesmentState},classId=#{classId},experimentalClassId=#{experimentalClassId} where id=#{id}")
    void updateAssesment(Assesment assesment);


    /**
     * 添加考核记录
     */
    @Insert({"<script>",
            "insert into record (projectId,courseId,studentId,assesmentId) values"
                    + "<foreach collection = 'studentIds' item='studentId' separator=','>"
                    + "(#{projectId},#{courseId},#{studentId},#{assesmentId})" + "</foreach>",
            "</script>"})
    void insertRecore(@Param("studentIds") List<Integer> studentIds, @Param("projectId") Integer projectId, @Param("courseId") Integer courseId, @Param("assesmentId") Integer assesmentId);


    /**
     * 根据考核id查询数据
     *
     * @param id
     * @return
     */
    @Select("select id,experimentId,creationTime,endTime,assesmentName,releaseType,timesum,experimentalClassId,classId from assessment where id=#{id}")
    Assesment queryGetById(Integer id);

    @Select("select assessmentNumber from assessment where id=#{assesmentId}")
    Integer getAssesmentNumber(Integer assesmentId);

    /**
     * 查询行政班级id
     *
     * @param studentIds
     * @return
     */
    @Select({"<script>",
            "select  classId from student WHERE studentId in "
            + "<foreach collection='studentIds' item='stu' open='(' separator=',' close=')'>#{stu}</foreach> ",
            "GROUP BY classId",
            "</script>"})
    List<String> queryClassId(@Param("studentIds") List<Integer> studentIds);


    /**
     * 创建考核时选中的学生
     *
     * @param assesmentId
     * @return
     */
    @Select("SELECT stu.studentId as studentId,studentName as studentName FROM record re,student stu WHERE re.studentId=stu.studentId AND re.assesmentId=#{assesmentId}")
    List<Student> queryStudent(Integer assesmentId);


    /**
     * 删除多余的记录信息
     *
     * @param assesmentId
     * @param students
     */
    @Delete({"<script>", "delete from  record where assesmentId=#{assesmentId} ",
            "<if test='students!=null'>",
            "<foreach collection='students' item='stu' open='and studentId in(' separator=',' close=')'>" +
                    "#{stu.studentId} "
                    + "</foreach> ",
            "</if>",
            "</script>"})
    void deleteRecord(@Param("assesmentId") Integer assesmentId, @Param("students") List<Student> students);


    /**
     * 正在参与考核的学生
     *
     * @return
     */
    @Select("select studentId from  record re left join assessment ass on re.assesmentId=ass.id where ass.assesmentState=1 and re.assesmentId is not null")
    List<Integer> getStudentisAssess();


    /**
     * 修改考核状态
     */
    @Update({"<script>",
            "update assessment set assesmentState=#{assesmentState} " +
            "<if test='releaseType==0 and assesmentState==1'>,creationTime=#{creationTime},endTime=#{endTime}</if>",
            "<if test='assesmentState==2 and timesum!=null'>,endTime=#{endTime},timesum=#{timesum} </if>",
            "where id=#{id}",
            "</script>"})
    void updateAssesmentState(Assesment assesment);


    /**
     * 查询实验班级一级标题：创建时间
     *
     * @param staffId
     * @return
     */
    @Select("select DISTINCT DATE_FORMAT(creationTime,'%Y') as creationTime from experimental_class_ning " +
            " WHERE isdel=0 and founder=(select staffName from staff where staffId=#{staffId}) and schoolId=#{schoolId} GROUP BY creationTime ORDER BY creationTime desc ")
    List<ExperimentalClass> queryCreationTime(@Param("staffId") Integer staffId,@Param("schoolId")Integer schoolId);


    /**
     * 查询实验班级信息,及班级下的学生
     *
     * @param creationTime
     * @return
     */
    @Select("select experimentalClassId,experimentalClassName from experimental_class_ning where isdel=0 and creationTime like concat('%',#{creationTime},'%') and founder=(select staffName from staff where staffId=#{staffId}) and schoolId=#{schoolId} ")
    @Results({
            @Result(id = true, column = "experimentalClassId", property = "experimentalClassId"),
            @Result(column = "experimentalClassName", property = "experimentalClassName"),
            @Result(column = "experimentalClassId", property = "students", many = @Many(select = "com.yipin.liuwanr.mapper.StudentMapper.getByStudents"))
    })
    List<ExperimentalClass> queryExperimentalClass(@Param("creationTime") String creationTime, @Param("staffId") Integer staffId,@Param("schoolId")Integer schoolId);

    /**
     * 考核名称、创建时间、结束时间、教师名称、考核人数、实到人数
     * @param assesmentId
     * @return
     */
    @Select("SELECT ass.assesmentName as assesmentName ,ass.creationTime as creationTime,ass.endTime as endTime,ass.assessmentSize as assessmentSize,count(re.score) as actualNumber,st.staffName as  staffName "
            + " FROM (assessment ass left join  staff st on ass.staffId=st.staffId) left join record re  on ass.id=re.assesmentId WHERE  ass.id=#{assesmentId} and re.score is not null")
    Assesment queryAssesmentId(Integer assesmentId);


    /**
     * 实验班级
     *
     * @param assesmentId
     * @return
     */
    @Select("SELECT  ex.experimentalClassId as experimentalClassId,ex.experimentalClassName as experimentalClassName from assessment ass left join"
            + "  experimental_class_ning ex on FIND_IN_SET(ex.experimentalClassId,ass.experimentalClassId)  where ass.id=#{assesmentId}")
    List<ExperimentalClass> queryExperimental(Integer assesmentId);


    /**
     * 行政班级
     *
     * @param assesmentId
     * @return
     */
    @Select("SELECT  c.classId  as classId,c.className  as className from assessment ass left join class c on FIND_IN_SET(c.classId,ass.classId)  where ass.id=#{assesmentId}")
    List<Class> queryClass(Integer assesmentId);

    //s.isdel=0 and
    @Select("select s.studentId,studentName from student s left join experimental_class_student ecs on s.studentId=ecs.studentId where ecs.experimentalClassId=#{experimentalClassId} ")
    List<Student> getByExperimentalClassId(Integer experimentalClassId);

    //isdel=0 and
    @Select("SELECT studentId,studentName from student where  classId=#{classId} ")
    List<Student> getByclassId(Integer classId);


    /**
     * 查询成绩(升序)
     * @return
     */
    @Select({"<script>",
            "select score  FROM record where  score is not null and assesmentId=#{assesmentId} ",
            "<foreach collection='student' item='stu' open='and studentId in  (' separator=',' close=')'> #{stu.studentId}</foreach>",
            "  ORDER BY score",
            "</script>"})
    List<Integer> queryScore(Integer assesmentId,@Param("student") List<Student> student);


    /**
     * 分组查询分数和对应人数
     */
    @Select({"<script>",
            "select  score,count(studentId) as number from  record where assesmentId=#{assesmentId}",
            "<foreach collection='students' item='stu' open='and studentId in (' separator=',' close=')'>#{stu.studentId}</foreach>",
            "  and score is not null  GROUP BY score",
            "</script>"})
    List<Record> getGroupByScore(@Param("assesmentId") Integer assesmentId,@Param("students") List<Student> students);


    /**
     * 统计某个班的总错误量
     *
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
    @Select({"<script>",
            "select count(*) from PointRecord where rightAndWrong = -1 and assesmentId=#{assesmentId}",
            " <if test='experimentalClassId!=null '> and experimentalClassId=#{experimentalClassId} </if>",
            " <if test='classId!=null '> and classId=#{classId} </if>",
            "</script>"})
    Integer queryRight(@Param("assesmentId") Integer assesmentId, @Param("experimentalClassId") Integer experimentalClassId,
                       @Param("classId") Integer classId);


    /**
     * 统计该项目的判分点数量
     * (select experimentId from assessment where id=#{assesmentId})
     *
     * @return
     */
    @Select("select count(judgmentPointsId) from hr_judgment_points where FIND_IN_SET(#{projectId},projectId)")
    Integer queryPointNumber(Integer projectId);


    /**
     * 错误分布
     *
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
    @Select({"<script>",
            "select judgmentPointsName,count(pr.judgmentPointsId) as number from PointRecord pr left join hr_judgment_points jp on pr.judgmentPointsId=jp.judgmentPointsId "
                + "where rightAndWrong=-1 and assesmentId=#{assesmentId}  ",
            " <if test='experimentalClassId!=null '> and experimentalClassId=#{experimentalClassId}</if>",
            " <if test='classId!=null '> and classId =#{classId} </if>",
            "GROUP BY pr.judgmentPointsId",
            "</script>"})
    List<PointRecord> queryError(@Param("assesmentId") Integer assesmentId, @Param("experimentalClassId") Integer experimentalClassId,
                                 @Param("classId") Integer classId);


    @Select({"<script>",
            "select studentName,score from  record r left join  student s on r.studentId=s.studentId where  r.assesmentId=#{assesmentId}",
              "<foreach collection='students' item='stu' open=' and r.studentId in (' separator=',' close=')'> #{stu.studentId} </foreach>",
            "</script>"})
    List<Record> queryScoreDetailed(@Param("assesmentId") Integer assesmentId,@Param("students") List<Student> students);


    //开始考核
    @Select("select id,assesmentName,timesum from assessment where courseId=#{courseId}  and  releaseType=0  and assesmentState=0")
    List<Assesment> releaseAssesment(Integer courseId);


    //考核名称去重
    @Select("select count(*) from assessment where assesmentName=#{assesmentName}")
    Integer getByAssesmentName(String assesmentName);


    //自定义跳转
    @Select("select tc.systemId,c.systemName from hr_course_tc tc left join service_config c on tc.systemId=c.systemId  where courseId=#{courseId} GROUP BY tc.systemId")
    List<ServiceConfig> getByCourseId(Integer courseId);
}
