package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.*;

import com.yipin.liuwanr.entity.Course;
import com.yipin.liuwanr.entity.CourseLink;
import com.yipin.liuwanr.entity.Discipline;
import com.yipin.liuwanr.entity.Order;
import com.yipin.liuwanr.entity.Professional;
import com.yipin.liuwanr.entity.ProfessionalClass;
import com.yipin.liuwanr.entity.ServiceConfig;
import com.yipin.liuwanr.entity.UserM;
import com.yipin.liuwanr.vo.CourseVO;

@Mapper
public interface CourseMapper {
	
	//添加课程
	@Insert("INSERT INTO course(courseName,courseType,disciplineId,professionalClassId,professionalId,courseHours,marketPrice,courseIntroduction,teachingGoal,isdel,creationTime,systemId)"
			+ "VALUES(#{courseName},#{courseType},#{disciplineId},#{professionalClassId},#{professionalId},#{courseHours},#{marketPrice},#{courseIntroduction},#{teachingGoal},0,#{creationTime},#{systemId})")
	@Options(useGeneratedKeys=true, keyProperty="courseId", keyColumn="courseId")
	void addCourse(Course course);
	
	//添加课程实训配置
	@Insert({"<script>",
			"INSERT INTO hr_course_tc(courseId,systemId,projectId,isdel,isShow) VALUES"
			+ "<foreach collection = 'list' item='c' separator=','>"
			+ " (#{c.courseId},#{c.systemId},#{c.projectId},0,#{c.isShow})"
			+ "</foreach>",
			"</script> "})
	void addCoursePC(List<ServiceConfig> serviceConfigList);
	
	//添加项目环节
	@Insert({"<script>",
		"INSERT INTO hr_course_link(projectId,fileLink,linkName,isdel,courseId) values"
				+ "<foreach collection = 'list' item='link' separator=','>"
				+ "(#{link.projectId},#{link.fileLink},#{link.linkName},0,#{link.courseId})" + "</foreach>",
        "</script> "})
	void addCourseLink(List<CourseLink> courseLinkList);
	
	//查询课程
	@Select({"<script>",
        "SELECT c.courseId,c.courseName,c.courseType,c.disciplineId,c.professionalClassId,c.professionalId,c.courseHours,c.marketPrice,c.courseIntroduction,c.teachingGoal,c.systemId,c.isShelves,(SELECT GROUP_CONCAT(ser.systemName) FROM `service_config` ser WHERE FIND_IN_SET(ser.systemId,c.systemId) ) as systemName from course c,service_config sc where c.isdel = 0 ",
//		 "SELECT c.creationTime,c.courseId,c.courseName,c.courseType,c.disciplineId,c.professionalClassId,c.professionalId,c.courseHours,c.marketPrice,c.courseIntroduction,c.teachingGoal,c.systemId,c.isShelves from course c where c.isdel = 0",
		" <if test='disciplineId!=null'>and c.disciplineId = #{disciplineId} </if>",
        " <if test='courseType!=null'>and c.courseType = #{courseType} </if>",
        " <if test='professionalClassId!=null'>and c.professionalClassId = #{professionalClassId} </if>",
        " <if test='professionalId!=null'>and c.professionalId = #{professionalId} </if>",
        " <if test='searchContent!=null'> and c.courseName like CONCAT('%',#{searchContent},'%')</if>",
        "GROUP BY c.courseId",
        "order by c.creationTime desc",
        "</script> "})
	List<Course> queryCourse(Course course);
	
	//查询课程详情
	@Select("SELECT courseId,courseName,courseType,disciplineId,professionalClassId,professionalId,courseHours,marketPrice,courseIntroduction,teachingGoal,systemId,isShelves from course where isdel = 0 and courseId = #{courseId}")
        @Results({
	        @Result(property = "course", column = "courseId",one = @One(select = "com.yipin.liuwanr.mapper.CourseMapper.queryCourseDetailsO")),
	        @Result(property = "serviceConfigList", column = "courseId",many = @Many(select = "com.yipin.liuwanr.mapper.CourseMapper.queryCourseDetailsTC")),
	})
	List<CourseVO> queryCourseDetails(Integer courseId);

	@Select({"<script>",
			"SELECT courseId,courseName from course where isdel = 0 and courseName = #{courseName}",
			"</script> "})
	List<Course> queryCourseNameIsExists(String courseName);

	@Select({"<script>",
        "SELECT courseId,courseName,courseType,disciplineId,professionalClassId,professionalId,courseHours,marketPrice,courseIntroduction,teachingGoal,systemId,isShelves from course where isdel = 0 and courseId = #{courseId}", 
        "</script> "})
	Course queryCourseDetailsO(Integer courseId);
	
	@Select({"<script>",
        "SELECT c.courseId,c.systemId,c.projectId,c.isShow,pm.projectName,sc.systemName from hr_course_tc c,service_config sc,hr_project_management pm where c.isdel = 0 and c.courseId = #{courseId} and pm.projectId = c.projectId and sc.systemId = c.systemId", 
        "</script> "})
	List<ServiceConfig> queryCourseDetailsTC(Integer courseId);
	
	@Select({"<script>",
        "SELECT o.orderId,o.orderNumber,o.orderName,o.orderAmount,o.orderDate,o.orderType,o.orderStatus,o.orderNature,o.provinceId,o.cityId,o.orderContact,o.phone,o.email,o.customerId,(SELECT c.customerName from customer c WHERE c.customerId = o.customerId) as customerName from orders o where o.isdel=0 and o.orderId = #{orderId} ", 
        "</script> "})
	Order queryOrderDetailsO(Integer orderId);

	//删除课程
	@Update({"<script>",
		"UPDATE course SET isdel = 1 where courseId in  "
		+ "<foreach collection = 'courseId' item='c' open='(' separator=',' close=')'>"
		+ " #{c}"
		+ "</foreach>",
		"</script> "})
	void deleteCourse(@Param("courseId")List<Integer> courseId);

	//修改课程
	@Update("UPDATE course SET courseName = #{courseName},courseType = #{courseType},disciplineId = #{disciplineId},professionalClassId = #{professionalClassId},professionalId = #{professionalId},"
			+ "courseHours = #{courseHours},marketPrice = #{marketPrice},courseIntroduction = #{courseIntroduction},teachingGoal = #{teachingGoal},systemId = #{systemId} where courseId = #{courseId}")
	void updateCourse(Course course);

	//修改课程实训配置
	@Update("UPDATE hr_course_tc SET systemId = #{systemId},projectId = #{projectId},isShow = #{isShow} where courseId = #{courseId} and systemId = #{systemId} and projectId = #{projectId}")
	void updateCoursePC(ServiceConfig serviceConfig);

	//删除课程实训配置
	@Delete("Delete FROM hr_course_tc where courseId = #{courseId}")
	void deleteCoursePC(Integer courseId);

	//查询课程学科
	@Select({"<script>",
        "SELECT disciplineId,disciplineName,disciplineLevelId from discipline",
        "</script> "})
	List<Discipline> queryCourseDiscipline();

	//查询课程专业类
	@Select({"<script>",
        "SELECT professionalClassId,professionalClassName,disciplineId from professional_class where disciplineId = #{disciplineId}",
        "</script> "})
	List<ProfessionalClass> queryCourseProfessionalClass(Integer disciplineId);

	//查询课程专业
	@Select({"<script>",
        "SELECT professionalId,professionalName,professionalClassId from professional where professionalClassId = #{professionalClassId}",
        "</script> "})
	List<Professional> queryCourseProfessional(Integer professionalClassId);
	
	//查询应用配置
	@Select({"<script>",
        "SELECT systemId,systemName,systemType,systemAttribution,systemStatus from service_config where isdel = 0 ",
        " <if test='searchContent!=null'> and systemName like CONCAT('%',#{searchContent},'%')</if>",
        " <if test='systemId!=null'>"
        + "<foreach collection='systemId' item='id' open='and systemId not in (' separator=',' close=')'> #{id}"
        +"</foreach>"
        + "</if>",
        "</script> "})
	List<ServiceConfig> queryAppConfig(@Param("searchContent") String searchContent, @Param("systemId") List<Integer> systemId);
	
	//查询实训配置
	@Select({"<script>",
        "SELECT sc.systemId,sc.systemName,sc.systemType,sc.systemAttribution,sc.systemStatus,pm.projectName,pm.projectId,pm.isShow from service_config sc,hr_project_management pm,course c where sc.isdel = 0 and  sc.systemId = pm.systemId  and FIND_IN_SET(sc.systemId,c.systemId) and pm.isdel = 0 and c.courseId = #{courseId} ",
        "</script> "})
	List<ServiceConfig> queryTrainingConfig(Integer courseId);
	
	//绑定实训配置
	@Update("UPDATE course SET systemId = #{systemId} where courseId = #{courseId}")
	void addTrainingConfig(Course course);
	
	//查询环节详情
	@Select({"<script>",
        "SELECT linkId,projectId,fileLink,linkName,courseId from hr_course_link where courseId = #{courseId} and projectId = #{projectId} ",
        "</script> "})
	List<CourseLink> queryLinkDetails(CourseLink courseLink);
	
	//更新环节
	@Update("UPDATE hr_course_link SET fileLink = #{fileLink},linkName = #{linkName},projectId = #{projectId} where linkId = #{linkId}")
	void updateLink(CourseLink courseLink);
	
	//删除实训配置
	@Update("UPDATE course SET systemId = 0 where courseId = #{courseId}")
	void deleteTrainingConfig(Course course);
	
	//是否展示项目控制
	@Update({"<script>",
        "UPDATE hr_project_management SET "
        + "<if test='isShow==1'> isShow = 1 </if>"
        + "<if test='isShow==0'> isShow = 0 </if>"
        + "where projectId = #{projectId} ",
        "</script> "})
	void isShow(Course course);
	
	//是否上架课程控制
	@Update({"<script>",
        "UPDATE course SET "
        + "<if test='isShelves==1'> isShelves = 1 </if>"
        + "<if test='isShelves==0'> isShelves = 0 </if>"
        + "where courseId = #{courseId} ",
        "</script> "})
	void isShelves(Course course);
	
	//查询配置
	@Select({"<script>",
        "SELECT sc.systemId,sc.systemName,pm.projectId,pm.projectName FROM service_config sc,hr_project_management pm WHERE pm.systemId = sc.systemId and FIND_IN_SET(sc.systemId,#{systemId}) and pm.projectPermissions = 0 and pm.isdel = 0",
        "</script> "})
	List<ServiceConfig> queryConfig(String systemId);
	
	
	/**
	 * 得到用户的电话号码、唯一标识性账号、权限
	 * @param userId
	 * @return
	 */
	@Select("SELECT phone,uniqueIdentificationAccount,accountRole FROM `user` WHERE userId=#{userId}")
	UserM getByUserId(Integer userId);
	
	
	/**
	 * 得到学生的学校id
	 * @param user
	 * @return
	 */
	@Select("SELECT pro.schoolId FROM  class c,grade g,stu_professional_architecture pro WHERE pro.stuProfessionalArchitectureId=g.stuProfessionalArchitectureId "
			+ " AND g.gradeId=c.gradeId AND c.classId=(SELECT classId FROM student WHERE phone=#{phone} AND uniqueIdentificationAccount=#{uniqueIdentificationAccount})")
	Integer getByUser(UserM user);
	

	/**
	 * 得到课程信息
	 * @param schoolId
	 * @return
	 */
	@Select("select c.courseId,courseName from course c left join hr_course_permissions cp on (c.courseId=cp.courseId) left join orders o " +
			" on (cp.orderId=o.orderId) left join customer cu on(o.customerId=cu.customerId) where c.isdel=0 and c.isShelves=0 and cu.schoolId=#{schoolId}  GROUP BY c.courseId")
	List<Course> getBySchool(Integer schoolId);

	
	@Select("select courseName,courseIntroduction,teachingGoal from course where courseId=#{courseId}")
	Course getcouese(Integer courseId);

	//删除课程实训配置
	@Delete("Delete FROM hr_course_link where courseId = #{courseId}")
	int deleteCourseLink(Integer courseId);
}