package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.*;

import com.yipin.liuwanr.entity.Action;
import com.yipin.liuwanr.entity.Device;
import com.yipin.liuwanr.entity.Position;
import com.yipin.liuwanr.entity.Relationship;
import com.yipin.liuwanr.entity.UploadInfo;

@Mapper
public interface DeviceMapper {

	@Select("SELECT duid, version, tariff, createtime, updatetime FROM lw_device where duid = #{duid}")
	Device getById(String duid);
	
	@Select("SELECT lw_device.duid, version, tariff, lw_device.createtime, updatetime FROM lw_device join lw_pet_device on lw_device.duid=lw_pet_device.duid where puid = #{puid}")
	Device getByPet(String puid);
	
	@Select("select puid, duid from lw_pet_device where puid=#{puid} or duid=#{duid}")
	@Results({
		@Result(property="hid", column="puid"),
		@Result(property="lid", column="duid")
	})
	List<Relationship> check(String puid, String duid);
	
	@Select("select count(duid) from lw_user_pet join lw_pet_device on lw_user_pet.puid = lw_pet_device.puid where uuid=#{uuid} and duid=#{duid}")
	int checkDevice(String uuid, String duid);
	
	@Select("Select longitude, latitude from lw_device_action where duid=#{duid} and servertime between #{from} and #{to}")
	List<Position> track(String duid, String from, String to);
	
	@Insert("INSERT INTO lw_pet_device(puid, duid, createtime) values(#{puid}, #{duid}, now())")
	void bundling(String puid, String duid);
	
	@Insert("INSERT INTO lw_device(duid, tariff, statue, createtime) VALUES(#{duid},#{version},#{tariff},#{statue},now())")
	void create(Device device);
	
	@Insert("INSERT INTO lw_device_action(duid, longitude, latitude, distance, bssid1, rssi1, bssid2, rssi2, bssid3, rssi3, gsensorstr, step, jump, roll, move, servertime) VALUES(#{duid}, #{longitude}, #{latitude}, #{distance}, #{bssid1}, #{rssi1}, #{bssid2}, #{rssi2}, #{bssid3}, #{rssi3}, #{gsensorstr}, #{step}, #{jump}, #{roll}, #{move}, #{servertime})")
	void uploadInfo(UploadInfo info);
	
	@Update({ "<script>", 
		"UPDATE lw_device SET", 
		"<when test='version!=null'>", "version=#{version},", "</when>",
		"<when test='tariff!=-1'>", "tariff=#{tariff},", "</when>",
		"updatetime=now() WHERE duid =#{duid}", 
	"</script>"})
	void update(Device device);
	
	@Update("UPDATE lw_pet_device set duid=#{duid} where puid=#{puid}")
	void change(String puid, String duid);
	
	@Delete("DELETE FROM lw_device WHERE duid = #{duid}")
	void delete(String duid);
	
	@Delete("DELETE FROM lw_pet_device WHERE puid = #{puid} and duid = #{duid}")
	void unbundling(String puid, String duid);

	@Select("SELECT sum(step) as step, sum(jump) as jump, sum(roll) as roll, sum(move) as move, date_format(servertime,'%Y-%m-%d') as day FROM lw_device_action where duid = #{duid} and servertime between #{from} and #{to} group by day")
	Action getActionByDay(String duid, String from, String to);
}