package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.*;

import com.yipin.liuwanr.entity.ExperimentalClass;
import com.yipin.liuwanr.entity.Professional;
import com.yipin.liuwanr.entity.StuProfessionalArchitecture;
import com.yipin.liuwanr.entity.Student;

@Mapper
public interface ExperimentalClassMapper {
	//实验班级添加学生
	@Insert("INSERT INTO experimental_class_student(studentId,experimentalClassId)"
			+ "VALUES(#{studentId},#{experimentalClassId})")
	void experimentClassAddStudent(Student student);

	//实验班级删除学生
	@Delete("DELETE from experimental_class_student where studentId = #{studentId} and experimentalClassId = #{experimentalClassId}")
	void experimentClassDeleteStudent(Student student);

	//实验班级更新人数
	@Update("Update experimental_class_ning Set classSize = #{classSize} where experimentalClassId = #{experimentalClassId}")
	void experimentClassUpdatePN(Integer classSize,Integer experimentalClassId);

	//创建实验班级
	@Insert("INSERT INTO experimental_class_ning(experimentalClassName,classSize,creationTime,founder,courseId,isdel,userId,schoolId)"
			+ "VALUES(#{experimentalClassName},#{classSize},now(),#{founder},#{courseId},0,#{userId},#{schoolId})")
	@Options(useGeneratedKeys=true, keyProperty="experimentalClassId", keyColumn="experimentalClassId")
	void addExperimentalClass(ExperimentalClass experimentalClass);

	@Select({"<script>",
        "SELECT experimentalClassId,experimentalClassName,classSize,creationTime,founder,courseId,userId,schoolId "
        + "from experimental_class_ning where isdel = 0 and schoolId = #{schoolId} and courseId=#{courseId} and userId = #{userId}",
        "</script> "})
	List<ExperimentalClass> queryExperimentalClass(Integer schoolId,Integer courseId,Integer userId);
	
	//查询实验班级学生专业
	@Select({"<script>",
        "SELECT pro.professionalId,pro.professionalName FROM student stu,experimental_class_ning exp,professional pro WHERE stu.professionalId = pro.professionalId and FIND_IN_SET(#{experimentalClassId},stu.experimentalClassId) and exp.experimentalClassId = stu.experimentalClassId GROUP BY professionalName ",
        "</script> "})
	List<Student> queryExperimentalClassSP(Integer experimentalClassId);
	
	//查询学生行政班级
	@Select({"<script>",
        "SELECT cla.classId,cla.className FROM student stu,experimental_class_ning exp,class cla WHERE FIND_IN_SET(#{experimentalClassId},stu.experimentalClassId) and cla.classId = stu.classId and stu.experimentalClassId = exp.experimentalClassId GROUP BY className ",
        "</script> "})
	List<Student> queryStudentClass(Integer experimentalClassId);
	
	@Select({"<script>",
        "SELECT stu.*,pro.professionalName,gra.gradeName from student stu,experimental_class_ning exp,grade gra,professional pro WHERE stu.experimentalClassId = exp.experimentalClassId and stu.gradeId = gra.gradeId and FIND_IN_SET(exp.experimentalClassId,#{experimentalClassId}) ",
        " <if test='professionalId!=null'>and stu.professionalId = #{professionalId} </if>",
        " <if test='classId !=null'>and stu.classId = #{classId} </if>",
        " <if test='studentNameNumber !=null'>and stu.studentNumber like CONCAT('%',#{studentNameNumber},'%') or stu.studentName like CONCAT('%',#{studentNameNumber},'%')</if>",
        "GROUP BY stu.studentId",
		"</script> "})
	List<Student> queryExperimentalClassDetails(Student student);
	
	@Select({"<script>",
        "SELECT n.* from experimental_class_ning n where n.experimentalClassId = #{experimentalClassId}",
        "</script> "})
	List<ExperimentalClass> queryExperimentalClassDetails1(Integer experimentalClassId);
	
	@Update("UPDATE experimental_class_ning SET isdel = 1 where experimentalClassId = #{experimentalClassId}")
	void deleteExperimentalClass(Integer experimentalClassId);

	@Delete("Delete from experimental_class_student where experimentalClassId = #{experimentalClassId}")
	void deleteExperimentalClassStu(Integer experimentalClassId);

	@Update("UPDATE experimental_class_ning SET experimentalClassName = #{experimentalClassName},classSize = #{classSize},practiceNumber = #{practiceNumber},inspectionNumber = #{inspectionNumber},courseSchedule = #{courseSchedule},founder = #{founder},courseId = #{courseId} where experimentalClassId = #{experimentalClassId}")
	void updateExperimentalClass(ExperimentalClass experimentalClass);
	
	//修改实验班级名称
	@Update("UPDATE experimental_class_ning SET experimentalClassName = #{experimentalClassName} where experimentalClassId = #{experimentalClassId}")
	void updateExperimentClassName(ExperimentalClass experimentalClass);
	

//————————————————————————————————————————————全承珠
	@Select("select experimentalClassId,experimentalClassName from experimental_class_ning where"
			+ " experimentalClassName like concat(#{experimentalClassName},'%')")
	List<ExperimentalClass> queryGetByExperimentalClassName(String experimentalClassName);
	

	/**
	 * 班级学生详情
	 * @param student
	 * @return
	 */
	@Select({"<script>",
		"select s.studentId,studentName,studentNumber,g.gradeName,c.className,p.professionalName from experimental_class_student st,student s,class c,grade g,professional p"
				+ " where st.studentId=s.studentId and s.classId=c.classId and c.gradeId=g.gradeId and s.professionalId=p.professionalId and st.experimentalClassId=#{experimentalClassId} ",
				" <if test='professionalId!=null'>and stu.professionalId = #{professionalId} </if>",
				" <if test='classId !=null'>and stu.classId = #{classId} </if>",
				" <if test='studentNameNumber !=null'>and (stu.studentNumber like CONCAT('%',#{studentNameNumber},'%') or stu.studentName like CONCAT('%',#{studentNameNumber},'%'))</if>",
				"GROUP BY st.studentId",
	"</script> "})
	List<Student> getExperimentalClassDetails(Student student);
	
	
	@Select("select s.studentId,studentName from student s left join experimental_class_student exs on s.studentId=exs.studentId " +
			" where exs.experimentalClassId=#{experimentalClassId} GROUP BY s.studentId")
	List<Student> querystudent(Integer experimentalClassId);
	
	
	/**
	 * 学生签到次数
	 * @return
	 */
	@Select("select count(a.id) from attendance a left join teacher_project tp on (a.experimentalClassId=tp.experimentalClassId and a.experimentId=tp.projectId) " +
			" where a.studentId=#{studentId} and a.experimentalClassId=#{experimentalClassId}  and tp.courseId=#{courseId} and tp.isAttendance=1")
	Integer getAttendance(@Param("studentId")Integer studentId,@Param("courseId")Integer courseId,@Param("experimentalClassId") Integer experimentalClassId);
	
	
	/**
	 * 专业
	 * @param experimentalClassId
	 * @return
	 */
	@Select("select p.professionalId,professionalName from experimental_class_student stu,student s,professional p " + 
			" where stu.studentId=s.studentId and s.professionalId=p.professionalId and stu.experimentalClassId=#{experimentalClassId} GROUP BY p.professionalId")
	List<Professional> getProfessionals(Integer experimentalClassId);
	
	
	/**
	 * 班级
	 * @param experimentalClassId
	 * @return
	 */
	@Select("select c.classId,c.className from experimental_class_student stu,student s,class c " +
			"where stu.studentId=s.studentId and s.classId=c.classId and stu.experimentalClassId=#{experimentalClassId} GROUP BY c.classId")
	List<StuProfessionalArchitecture> getStudentClass(Integer experimentalClassId);
	
	
	/**
	 * 实验班级名称
	 * @param experimentalClassId
	 * @return
	 */
	@Select("select experimentalClassName from experimental_class_ning where experimentalClassId=#{experimentalClassId}")
	String getExperimentalClassName(Integer experimentalClassId);
}
