package com.yipin.liuwanr.mapper;

import java.util.List;

import com.yipin.liuwanr.entity.*;
import org.apache.ibatis.annotations.*;

/**
  * 学生_实验学习
 * @author 86151
 *
 */
@Mapper
public interface ExperimentallearningMapper {
	
	/**
	 * 查询该课程中，学生已签到的项目
	 * @param studentId
	 * @param courseId
	 * @return
	 */
	@Select("select experimentId from  attendance where signIn=0 and studentId=#{studentId} and courseId=#{courseId} ")
	List<Integer> queryIsAttendance(Integer studentId,Integer courseId);
	
	/**
	 * 查询实验项目信息
	 * @param systemIds
	 * @return
	 */
//	@Select({"<script>",
//		      "select projectId,projectName,isExperiment,isAttendance from  hr_project_management  WHERE isdel=0 and projectPermissions=0 and systemId in",
//		      "<foreach collection='systemIds' item='systemId' open='(' separator=',' close=')'>" + "#{systemId} " + "</foreach> ",
//		    "</script>"})
//	List<Project_Management> getBySystemId(@Param("systemIds") String[] systemIds);

	
	/**
	 * 查询对应项目的考勤记录
	 * @param attendance
	 * @return
	 */
	@Select("select id,signIn from attendance where experimentId=#{experimentId} and studentId=#{studentId}")
	Attendance getByProjectIdAndStudentId(Attendance attendance);
	
	
	/**
	 * 修改对应的考勤信息
	 * @param attendance
	 */
	@Update("update attendance set signIn=#{signIn} where id=#{id}")
	void updateAttendance(Attendance attendance);
	
	
	/**
	 * 添加考勤记录
	 * @param attendance
	 */
	@Insert("insert into attendance (courseId,experimentId,creationTime,signIn,studentId) "
			+ "values (#{courseId},#{experimentId},now(),#{signIn},#{studentId})")
	void insertAttendance(Attendance attendance);


	/**
	 * 获取实验班级信息
	 * @param courseId
	 * @param studentId
	 * @return
	 */
	@Select("select ecn.experimentalClassId from experimental_class_ning ecn left join experimental_class_student ecs on ecn.experimentalClassId=ecs.experimentalClassId where " +
			"ecn.courseId=#{courseId} and ecs.studentId=#{studentId} and ecn.isdel=0 GROUP BY ecn.experimentalClassId")
	Integer queryExperimentalClassId(@Param("courseId") Integer courseId,@Param("studentId")Integer studentId);

	/**
	  * 授课老师信息
	 * @return
	 */
	@Select("select name,userAvatars from experimental_class_ning ecs left join user u on ecs.userId=u.userId where ecs.experimentalClassId=#{experimentalClassId}")
	UserM queryTeacherName(Integer experimentalClassId);
	
	/**
	  * 多名学生信息展示
	 * @return
	 */
	@Select("select  name,userAvatars from user u left join student s on (u.phone=s.phone and u.uniqueIdentificationAccount=s.uniqueIdentificationAccount) left join experimental_class_student ecs " +
			" on s.studentId=ecs.studentId where ecs.experimentalClassId=#{experimentalClassId} GROUP BY u.userId")
	List<UserM> queryStudentName(Integer experimentalClassId);
	
	
	/**
	 * 查询教师启用考核的考核信息
	 * @param courseId
	 * @return
	 */
	@Select("select id,experimentId,experimentalClassId,classId from assessment a left join hr_project_management pm on a.experimentId=pm.projectId left join hr_course_tc tc on pm.systemId=tc.systemId" +
			" where a.assesmentState=1 AND pm.state=1  and pm.isdel=0 AND pm.projectPermissions=1 and a.courseId=tc.courseId  and tc.courseId=#{courseId}   GROUP BY tc.systemId")
	List<Assesment> queryAssesment(Integer courseId);
	
	
	/**
	 * 查询对应学生的行政班级和实验班级id
     *
	 * @param studentId
	 * @return
	 */
	@Select("SELECT classId,experimentalClassId FROM student WHERE studentId=#{studentId}")
	Student queryClassIdOrExperimentalClassId(Integer studentId);
	
	/**
	 * 参与指定考核的学生
	 * @param assesmentId
	 * @return
	 */
	@Select("select studentId from record where assesmentId=#{assesmentId}")
	List<Integer> queryStudentId(Integer assesmentId);


	@Select("select c.courseId,c.courseName from course c left join experimental_class_ning ecn on c.courseId=ecn.courseId left join experimental_class_student ecs " +
			" on ecn.experimentalClassId=ecs.experimentalClassId  where ecn.isdel=0 and c.isdel=0 and ecs.studentId=#{StudentId} GROUP BY c.courseId")
	List<Course> queryStudentCourse(Integer StudentId);



	@Select("select DISTINCT hpm.projectId,projectName,isAttendance from hr_project_management hpm left join teacher_project tp on hpm.projectId=tp.projectId " +
			" where tp.courseId=#{courseId} and tp.experimentalClassId=#{experimentalClassId} and  tp.isOpenProject=0")
	List<Project_Management> getBycourseId(@Param("experimentalClassId")Integer experimentalClassId,@Param("courseId") Integer courseId);
}
