package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.*;
import org.apache.ibatis.mapping.FetchType;

import com.yipin.liuwanr.entity.Group;
import com.yipin.liuwanr.entity.User;
@Mapper
public interface GroupMapper {

	@Results({
		@Result(property = "users", column = "gforu", many = @Many(select = "com.yipin.liuwanr.mapper.GroupMapper.getUserByGroup", fetchType = FetchType.EAGER)) 
	})
	@Select("SELECT guid, guid as gforu, name, avatar, uuid, description, latitude, longitude, members, createtime, updatetime FROM lw_group where guid = #{guid}")
	Group getById(long guid);
	
	@Select("SELECT g.guid, name, avatar, uuid, description, latitude, longitude, members, if(isnull(joined), 0, 1) as joined, createtime, updatetime FROM lw_group as g left join (select guid, id as joined from lw_group_user where uuid=#{uuid}) as u on g.guid=u.guid WHERE latitude BETWEEN #{minlatitude} and #{maxlatitude} AND longitude between #{minlongitude} and #{maxlongitude}")
	List<Group> getByLocation(String uuid, double maxlongitude, double minlongitude, double maxlatitude, double minlatitude);
	
	@Select("SELECT lw_user.* from lw_group_user join lw_user on lw_group_user.uuid=lw_user.uuid WHERE guid=#{guid}")
	List<User> getUserByGroup(long guid);
	
	@Select("select count(guid) from lw_group where guid=#{guid} and uuid=#{uuid}")
	int check(String uuid, long guid);
	
	@Insert("INSERT INTO lw_group(guid, name, avatar, uuid, description, latitude, longitude, members, createtime) VALUES(#{guid},#{name},#{avatar},#{uuid},#{description},#{latitude},#{longitude},#{members},now())")
	void create(Group device);
	
	@Update({ "<script>", 
		"UPDATE lw_group SET", 
		"<when test='name!=null'>", "name=#{name},", "</when>",
		"<when test='avatar!=null'>", "avatar=#{avatar},", "</when>",
		"<when test='uuid!=null'>", "uuid=#{uuid},", "</when>",
		"<when test='description!=null'>", "description=#{description},", "</when>",
		"<when test='latitude>0'>", "latitude=#{latitude},", "</when>",
		"<when test='longitude>0'>", "longitude=#{longitude},", "</when>",
		"<when test='members>0'>", "members=#{members},", "</when>",
		"updatetime=now() WHERE guid =#{guid}", 
	"</script>"})
	void update(Group device);
	
	@Insert("INSERT INTO lw_group_user(guid, uuid, createtime) VALUES(#{guid}, #{uuid}, now())")
	void addmember(long guid, String uuid);
	
	@Delete("DELETE FROM lw_group_user WHERE guid = #{guid} and uuid=#{uuid}")
	void removemember(long guid, String uuid);
	
	@Insert("INSERT INTO lw_group_block(guid, uuid, createtime) VALUES(#{guid}, #{uuid}, now())")
	void blockuser(long guid, String uuid);
	
	@Delete("DELETE FROM lw_group_block WHERE guid = #{guid} and uuid=#{uuid}")
	void unblockuser(long guid, String uuid);
	
	@Delete("DELETE FROM lw_group WHERE guid = #{guid}")
	void delete(long guid);
}