package com.yipin.liuwanr.mapper;

import com.yipin.liuwanr.entity.*;
import org.apache.ibatis.annotations.*;

import com.yipin.liuwanr.entity.ApplicationPermissions;
import com.yipin.liuwanr.entity.ContractInformation;
import com.yipin.liuwanr.entity.Course;
import com.yipin.liuwanr.entity.CoursePermissions;
import com.yipin.liuwanr.entity.Customer;
import com.yipin.liuwanr.entity.Order;
import com.yipin.liuwanr.vo.OrderVo;

import java.util.List;
@Mapper
public interface OrderMapper {
	
	//添加订单
	@Insert("INSERT INTO orders(orderNumber,customerName,orderName,orderAmount,orderDate,orderType,orderStatus,provinceId,cityId,orderContact,phone,email,isdel,customerId"
			+ ") VALUES(#{orderNumber},#{customerName},#{orderName},#{orderAmount},now(),#{orderType},1,#{provinceId},#{cityId},#{orderContact},#{phone},#{email},0,#{customerId})")
	@Options(useGeneratedKeys=true, keyProperty="orderId", keyColumn="orderId")
	void addOrder(Order order);
	
	//修改订单客户
	@Update("UPDATE customer SET customerType = #{orderType} where customerId = #{customerId}")
	void updateOrderCustomer(Order order);
	
	//添加合同信息
	@Insert("INSERT INTO hr_contract_information(contractInformationName,contractInformationNumber,contractInformationSum,contractInformationLink,orderId,isdel"
			+ ") VALUES(#{contractInformationName},#{contractInformationNumber},#{contractInformationSum},#{contractInformationLink},#{orderId},0)")
	void addContractInformation(ContractInformation contractInformation);
	
	//添加课程权限
	@Insert({"<script>",
//			"INSERT INTO hr_course_permissions(courseId,usePeriod,marketPrice,transactionPrice,discount,portAddressId,isDeliverGoods,isdel,orderId,expirationTime) VALUES"
            //缺少个过期时间
            "INSERT INTO hr_course_permissions(courseId,usePeriod,marketPrice,transactionPrice,discount,portAddressId,isDeliverGoods,isdel,orderId) VALUES"
                    + "<foreach collection = 'coursePermissionss' item='c' separator=','>"
                    + " (#{c.courseId},#{c.usePeriod},#{c.marketPrice},#{c.transactionPrice},#{c.discount},#{c.portAddressId},#{c.isDeliverGoods},0,#{c.orderId})"
                    + "</foreach>",
            "</script> "})
    void addCoursePermissionss(@Param("coursePermissionss") List<CoursePermissions> coursePermissionss);

    @Insert("INSERT INTO hr_application_permissions(systemId,isdel,orderId"
            + ") VALUES(#{systemId},0,#{orderId})")
    void bindingApplicationPermissions(ApplicationPermissions applicationPermissions);

    @Select("SELECT c.courseId,c.courseName,c.marketPrice from course c where c.isdel = 0 and  FIND_IN_SET(c.courseId,#{courseId})")
    List<Course> queryCoursePermissions(String courseId);

    @Select({"<script>",
            "SELECT o.orderId,o.orderNumber,o.orderName,o.orderAmount,o.orderDate,o.orderType,o.orderStatus,o.orderNature,o.provinceId,o.cityId,o.orderContact,o.phone,o.email,o.customerId,c.customerName from orders o,customer c where o.isdel=0 and c.customerId = o.customerId",
            " <if test='provinceId !=null'>and o.provinceId = #{provinceId} </if>",
            " <if test='cityId !=null'>and o.cityId = #{cityId} </if>",
            " <if test='orderType !=null'>and o.orderType = #{orderType} </if>",
            " <if test='orderStatus !=null'>and o.orderStatus = #{orderStatus} </if>",
            " <if test='searchContent!=null'> and (o.orderNumber like CONCAT('%',#{searchContent},'%') or c.customerName like CONCAT('%',#{searchContent},'%'))</if>",
            "order by o.orderDate desc",
            "</script> "})
    List<Order> queryOrder(Order order);

    @Select(
            "SELECT o.* from orders o where o.isdel = 0 and o.orderId = #{orderId} ")
    @Results({
            @Result(property = "orders", column = "orderId", one = @One(select = "com.yipin.liuwanr.mapper.OrderMapper.queryOrderDetailsO")),
            @Result(property = "contractInformations", column = "orderId", one = @One(select = "com.yipin.liuwanr.mapper.OrderMapper.queryOrderDetailsCI")),
            @Result(property = "coursePermissionss", column = "orderId", many = @Many(select = "com.yipin.liuwanr.mapper.OrderMapper.queryOrderDetailsCP"))
    })
    List<OrderVo> queryOrderDetails(Integer orderId);

    @Select({"<script>",
            "SELECT o.orderId,o.orderNumber,o.orderName,o.orderAmount,o.orderDate,o.orderType,o.orderStatus,o.orderNature,o.provinceId,o.cityId,o.orderContact,o.phone,o.email,o.customerId,(SELECT c.customerName from customer c WHERE c.customerId = o.customerId) as customerName from orders o where o.isdel=0 and o.orderId = #{orderId} ",
            "</script> "})
    Order queryOrderDetailsO(Integer orderId);

    @Select({"<script>",
            "SELECT cp.*,c.courseName FROM hr_course_permissions cp,course c where cp.courseId = c.courseId and cp.orderId = #{orderId}",
            "</script> "})
    List<CoursePermissions> queryOrderDetailsCP(Integer orderId);

    @Select({"<script>",
            "SELECT ci.* from hr_contract_information ci where ci.orderId = #{orderId}",
            "</script> "})
    ContractInformation queryOrderDetailsCI(Integer orderId);

    @Update({"<script>",
            "UPDATE orders SET isdel = 1 where orderId in  "
                    + "<foreach collection = 'orderId' item='c' open='(' separator=',' close=')'>"
                    + " #{c}"
                    + "</foreach>",
            "</script> "})
    void deleteOrder(@Param("orderId") List<Integer> orderId);

    @Update("UPDATE orders SET customerName = #{customerName},orderName = #{orderName},orderAmount = #{orderAmount},orderType = #{orderType},provinceId = #{provinceId},cityId = #{cityId},orderContact = #{orderContact},phone = #{phone},email = #{email},customerId = #{customerId} where orderId = #{orderId}")
    void updateOrder(Order order);

    @Delete("Delete from hr_course_permissions WHERE orderId = #{orderId}")
    void deleteCoursePermissions(Integer orderId);

    //缺少个过期时间
    @Update("INSERT INTO hr_course_permissions(courseId,usePeriod,marketPrice,transactionPrice,discount,portAddressId,isDeliverGoods,orderId) VALUES (#{courseId},#{usePeriod},#{marketPrice},#{transactionPrice},#{discount},#{portAddressId},#{isDeliverGoods},#{orderId})")
    void updateCoursePermissions(CoursePermissions coursePermissions);

    @Update("UPDATE hr_contract_information SET contractInformationName = #{contractInformationName},contractInformationNumber = #{contractInformationNumber},contractInformationSum = #{contractInformationSum},contractInformationLink = #{contractInformationLink} where contractInformationId = #{contractInformationId}")
    void updateContractInformation(ContractInformation contractInformation);

    @Update({"<script>",
            "UPDATE hr_course_permissions SET"
                    + "<if test='isDeliverGoods==1'> isDeliverGoods = 1 </if>"
                    + "<if test='isDeliverGoods==0'> isDeliverGoods = 0 </if>"
                    + "where coursePermissionsId = #{coursePermissionsId}",
            "</script> "})
    void isDeliverGoods(CoursePermissions coursePermissions);

    @Select({"<script>",
            "SELECT customerId,customerName FROM customer where isdel = 0",
            " <if test='provinceId !=null'>and provinceId = #{provinceId} </if>",
            " <if test='cityId !=null'>and cityId = #{cityId} </if>",
            "</script> "})
    List<Customer> queryOrderCustomer(Integer cityId, Integer provinceId);

    @Select({"<script>",
            "SELECT customerId,adminName,adminPhone,email FROM customer where isdel = 0 and customerId = #{customerId}",
            "</script> "})
    List<Customer> queryOrderCustomerContact(Integer customerId);

    //查询订单课程列表
    @Select({"<script>",
            "SELECT c.courseId,c.courseName,c.courseType,c.disciplineId,c.professionalClassId,c.professionalId,c.courseHours,c.marketPrice,c.courseIntroduction,c.teachingGoal,c.systemId,c.isShelves from course c where c.isdel = 0 ",
            " <if test='searchContent !=null and searchContent!=\"\" '> and c.courseName like CONCAT('%',#{searchContent},'%')</if>",
            " <if test='courseId!=null'>"
                    + "<foreach collection='courseId' item='id' open='and c.courseId not in (' separator=',' close=')'> #{id}"
                    + "</foreach>"
                    + "</if>",
            "</script> "})
    List<Course> queryCourseList(String searchContent, @Param("courseId") List<Integer> courseId);

    @Select({"<script>",
            "SELECT isDeliverGoods FROM hr_course_permissions where isdel = 0 and orderId = #{orderId}",
            "</script> "})
    List<Integer> selectByOrderId(int orderId);

    @Update({"<script>",
            "UPDATE orders SET"
                    + "<if test='orderStatus==1'> orderStatus = 1 </if>"
                    + "<if test='orderStatus==2'> orderStatus = 2 </if>"
                    + "where orderId = #{orderId}",
            "</script> "})
    int updateOrderStatus(@Param("orderId") int orderId,@Param("orderStatus") int orderStatus);
}