package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.*;
import org.apache.ibatis.mapping.FetchType;

import com.yipin.liuwanr.entity.Breed;
import com.yipin.liuwanr.entity.Pet;
@Mapper
public interface PetMapper {

	@Results({
		@Result(property="device", column="device", one=@One(select="com.yipin.liuwanr.mapper.DeviceMapper.getByPet",fetchType=FetchType.EAGER))
	})
	@Select("SELECT lw_user_pet.puid as puid,nickname,sex,birthday,category,height,weight,breed,sign,avatar,lw_pet.puid as device,lw_pet.createtime,updatetime FROM lw_user_pet join lw_pet on lw_user_pet.puid=lw_pet.puid where uuid = #{uuid}")
	List<Pet> getAll(String uuid);

	@Select("SELECT lw_pet.puid,uuid,nickname,avatar FROM lw_pet join lw_user_pet on lw_pet.puid=lw_user_pet.puid limit 50")
	List<Pet> listAll();
	
	@Select("SELECT lw_pet.puid,uuid,nickname,avatar FROM lw_pet join lw_user_pet on lw_pet.puid=lw_user_pet.puid")
	List<Pet> listAround();
	
	@Results({
		@Result(property="device", column="device", one=@One(select="com.yipin.liuwanr.mapper.DeviceMapper.getByPet",fetchType=FetchType.EAGER))
	})
	@Select("SELECT puid,nickname,sex,birthday,category,breed,height,weight,sign,avatar,puid as device,createtime,updatetime FROM lw_pet WHERE puid = #{puid}")
	Pet getOneSelf(String puid);
	
	@Select("SELECT puid,nickname,sex,birthday,category,breed,height,weight,sign,avatar,createtime,updatetime FROM lw_pet WHERE puid = #{puid}")
	Pet getOneOther(String puid);

	@Insert("INSERT INTO lw_pet(puid,nickname,sex,birthday,category,breed,height,weight,sign,avatar,createtime) VALUES(#{puid},#{nickname},#{sex},#{birthday},#{category},#{breed},#{height},#{weight},#{sign},#{avatar},now())")
	void insert(Pet Pet);
	
	@Insert("INSERT INTO lw_user_pet(uuid,puid,createtime) VALUES(#{uuid},#{puid},now())")
	void boundUser(String uuid, String puid);
	
	@Select("select count(puid) from lw_user_pet where uuid=#{uuid} and puid=#{puid}")
	int check(String uuid, String puid);

	@Update({ "<script>", 
				"UPDATE lw_pet SET", 
				"<when test='nickname!=null'>", "nickname=#{nickname},", "</when>",
				"<when test='sex!=-1'>", "sex=#{sex},", "</when>",
				"<when test='birthday!=null'>", "birthday=#{birthday},", "</when>",
				"<when test='category!=null'>", "category=#{category},", "</when>",
				"<when test='breed!=null'>", "breed=#{breed},", "</when>",
				"<when test='height!=null'>", "height=#{height},", "</when>",
				"<when test='weight!=null'>", "weight=#{weight},", "</when>",
				"<when test='sign!=null'>", "sign=#{sign},", "</when>",
				"<when test='avatar!=null'>", "avatar=#{avatar},", "</when>",
				"updatetime=now() WHERE puid =#{puid}", 
			"</script>"})
	void update(Pet pet);

	@Delete("DELETE FROM lw_pet WHERE puid = #{puid}")
	void delete(String puid);
	
	@Select("SELECT breedid as id, breedname as name FROM lw_breed WHERE category=#{category}")
	List<Breed> getBreeds(int category);

	@Insert("INSERT INTO lw_pet_greet(uuid,puid,type,content,createtime) values(#{uuid}, #{puid}, #{type}, #{message}, now())")
	void greet(String uuid, String puid, int type, String message);

}