package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import com.yipin.liuwanr.entity.Record;
import com.yipin.liuwanr.vo.PracticeRecordVo;
@Mapper
public interface RecordMapper {

	
	/**
	 * 练习记录 and 考核记录
	 * @param studentId:学生id
	 * @param projectPermissions:项目权限
	 * @return
	 */
	@Select("SELECT pm.projectName,re.score,re.timeSum,re.createTime,re.endTime FROM record re,hr_project_management pm "
			+ "  WHERE pm.projectId=re.projectId AND pm.projectPermissions=#{projectPermissions} AND re.courseId=#{courseId} AND re.studentId=#{studentId}")
	List<Record> getByStudentId(@Param("projectPermissions")Integer projectPermissions,@Param("courseId")Integer courseId,@Param("studentId")Integer studentId);
	
	
	/**
	 * 练习项目数量
	 * @return
	 */
	@Select("select count(*) from hr_project_management where isdel=0 and projectPermissions=0 AND systemId in (SELECT systemId FROM course WHERE courseId=#{courseId})")
	Integer queryPracticeNumber(Integer courseId);
	

	/**
	 * 完成练习项目数量
	 * @param studentId
	 * @return
	 */
	@Select("SELECT count(*) FROM (SELECT re.recordId,re.projectId FROM record AS re,hr_project_management As pm "
			+ " WHERE re.projectId=pm.projectId AND pm.projectPermissions=0 AND re.studentId=#{studentId} AND re.courseId=#{courseId}  group by re.projectId) exerciserecord")
	Integer queryAccomplishNumber(@Param("studentId")Integer studentId,@Param("courseId")Integer courseId);

	
	/**
	 * 练习总次数
	 * @param studentId
	 * @return
	 */
	@Select("SELECT count(*) FROM record AS re,hr_project_management As pm WHERE re.projectId=pm.projectId AND pm.projectPermissions=0 AND re.courseId=#{courseId} AND re.studentId=#{studentId}")
	Integer querySumNumber(@Param("studentId")Integer studentId,@Param("courseId")Integer courseId);
	
	
	/**
	 * 学生姓名、练习时长、练习平均分
	 * @param studentId
	 * @return
	 */
	@Select("SELECT stu.studentName as studentName,SUM(re.timeSum) as totaltime,avg(re.score) as avg,SUM(integral) as integral" + 
			" FROM record re,student stu,hr_project_management  pm WHERE re.studentId=stu.studentId and re.projectId=pm.projectId and pm.projectPermissions=0 and re.studentId=#{studentId} and re.courseId=#{courseId}")
	PracticeRecordVo getByPracticeVO(@Param("studentId")Integer studentId,@Param("courseId")Integer courseId);
	
	
	/**
	 * 全国平均积分、全国最高积分
	 * @return
	 */
	@Select("SELECT sum(integral)/count(studentID) as avgintegral,max(integral) heightintegral FROM " + 
			"  (SELECT re.studentId as studentID,SUM(re.integral) as integral FROM record re,hr_project_management pm WHERE re.projectId=pm.projectId AND pm.projectPermissions=0 AND re.courseId=#{courseId} GROUP BY re.studentId) Trainingpoints") 
	PracticeRecordVo queryCountry(Integer courseId);
}
