package com.yipin.liuwanr.mapper;

import java.util.List;

import com.yipin.liuwanr.entity.UserInfo;
import com.yipin.liuwanr.entity.UserM;
import com.yipin.liuwanr.vo.UserVO;
import org.apache.ibatis.annotations.*;

import com.yipin.liuwanr.entity.Student;

import io.lettuce.core.dynamic.annotation.Param;
@Mapper
public interface StudentMapper {

	//添加学生
	@Insert("INSERT INTO student(studentName,workNumber,phone,email,roleId,schoolId,professionalId,gradeId,classId,isdel,uniqueIdentificationAccount)"
			+ "VALUES(#{studentName},#{workNumber},#{phone},#{email},#{roleId},#{schoolId},#{professionalId},#{gradeId},#{classId},0,#{uniqueIdentificationAccount})")
	void addStudent(Student student);

	//通过专业id查询所有学生信息
	@Select("SELECT u.logInNumber,u.userName,u.lastLoginTime,o.roleId, o.gradeId, o.classId, o.professionalId FROM hr_user_info u,hr_organization_relationship o WHERE u.userId = o.userId AND o.roleId = 4 AND o.professionalId = #{professionalId} AND o.schoolId = #{schoolId}")
	List<Student> queryStudentByProfessionalIds(Integer professionalId, Integer schoolId);

	//通过年级id查询所有学生信息
	@Select("SELECT u.logInNumber,u.userName,u.lastLoginTime,o.roleId, o.gradeId, o.classId, o.professionalId FROM hr_user_info u,hr_organization_relationship o WHERE u.userId = o.userId AND o.roleId = 4 AND o.gradeId = #{gradeId} AND o.schoolId = #{schoolId}")
	List<Student> queryStudentByGradeIds(Integer gradeId, Integer schoolId);

	//通过班级id查询所有学生信息
	@Select("SELECT u.logInNumber,u.userName,u.lastLoginTime,o.roleId, o.gradeId, o.classId, o.professionalId FROM hr_user_info u,hr_organization_relationship o WHERE u.userId = o.userId AND o.roleId = 4 AND o.classId = #{classId} AND o.schoolId = #{schoolId}")
	List<Student> queryStudentByClassIds(Integer classId, Integer schoolId);

	@Select("select s.studentId,studentName from experimental_class_student ecs left join student s on ecs.studentId=s.studentId where ecs.experimentalClassId=#{experimentalClassId} ")
	List<Student> getByStudents(Integer experimentalClassId);

	//删除学生
	@Update({ "<script>",
			"UPDATE student SET isdel = 1 where studentId = #{studentId}  ",
			"</script> " })
	void deleteStudent(Integer studentId);

	//删除用户
	@Update({ "<script>",
			"UPDATE user SET isdel = 1 where phone = #{phone}  ",
			"</script> " })
	void deleteUser(String phone);

	//查询学生详情
	@Select({ "<script>",
			"SELECT uniqueIdentificationAccount,studentName,workNumber,phone,email,roleId,schoolId,professionalId,gradeId,classId from student where isdel = 0 and studentId = #{studentId}",
			"</script> " })
	List<Student> queryStudentDetails(Integer studentId);

	//查询学生详情
	@Select({ "<script>",
			"SELECT * from student where isdel = 0 and studentId = #{studentId}",
			"</script> " })
	@Results({
			@Result(property = "student", column = "studentId",one = @One(select = "com.yipin.liuwanr.mapper.StudentMapper.queryStudentDetails")),
			@Result(property = "user", column = "studentId",one = @One(select = "com.yipin.liuwanr.mapper.StudentMapper.queryStudentDetailsU"))
	})
	List<UserVO> queryStudentDetailsUser(Integer studentId);

	//查询学生详情
	@Select({ "<script>",
			"SELECT s.uniqueIdentificationAccount,s.studentName,s.workNumber,s.phone,s.email,s.roleId,s.schoolId,s.professionalId,s.gradeId,s.classId,u.* from student s,user u where s.isdel = 0 and s.studentId = #{studentId} and s.phone = u.phone",
			"</script> " })
	List<UserM> queryStudentDetailsU(Integer studentId);

	//修改学生
	@Update("UPDATE student SET studentName = #{studentName},workNumber = #{workNumber},phone = #{phone},email = #{email},roleId = #{roleId}"
			+ ",schoolId = #{schoolId},professionalId = #{professionalId},gradeId = #{gradeId},classId = #{classId} where studentId = #{studentId}")
	void updateStudent(Student student);

	//修改用户
	@Update("UPDATE user SET phone = #{phone},name = #{name},userAccount = #{userAccount},workNumber = #{workNumber},provinceId = #{provinceId},cityId = #{cityId},email = #{email},schoolId = #{schoolId},uniqueIdentificationAccount = #{uniqueIdentificationAccount} where phone = #{phone}")
	void updateUser(UserM user);

//——————————————————————全承珠
	// 查询出选中学生的考核状态
	@Select({ "<script>",
			"select studentId,studentName,isAssess from student where studentId  in "
					+ "<foreach collection='students' item='stu' open='(' separator=',' close=')'>" + "#{stu.studentId}"
					+ "</foreach> ",
			"</script>" })
	List<Student> queryStudentisAssess(@Param("students") List<Student> students);

	// 修改学生的是否考核的状态
	@Update({ "<script>",
			"update student set isAssess=#{isAssess} where studentId in "
					+ "<foreach collection='students' item='stu' open='(' separator=',' close=')'>" + "#{stu.studentId}"
			+ "</foreach> ",
			"</script>" })
	void updateStudentisAssess(List<Student> students, Integer isAssess);

	
	@Insert({ "<script>",
			"insert into student(studentName, workNumber,phone,roleId,schoolId,professionalId,gradeId,classId,uniqueIdentificationAccount,email,isAssess,isdel) values ",
			"<foreach collection='list' item='student' index='index' separator=','>",
			"(#{student.studentName}, #{student.workNumber}, #{student.phone},#{student.roleId},#{student.schoolId},#{student.professionalId},#{student.gradeId}, #{student.classId} ,#{student.uniqueIdentificationAccount},#{student.email},0,0)",
			"</foreach>", "</script>" })
	void bacthAddStudent(@Param("students") List<Student> students);

	
	//查询专业、年级、班级id
	@Select("select p.stuProfessionalArchitectureId as professionalId,g.gradeId,c.classId  from class c left join grade g on (c.gradeId=g.gradeId) left join stu_professional_architecture p on (g.stuProfessionalArchitectureId=p.stuProfessionalArchitectureId) "
			+ " where  c.isdel=0 and  g.isdel=0 and p.isdel=0 and p.schoolId=#{schoolId}  and p.stuProfessionalArchitectureName=#{professionalName} and g.gradeName=#{gradeName}  and c.className=#{className};")
	Student getStudent(Student student);
	
	
	
	//========全承珠
	@Select({"<script>",
			"select studentId,workNumber,classId,loginNumber from student where isdel=0",
			"<if test='phone!=null'>and phone=#{phone} </if>",
			"<if test='workNumber!=null'>and workNumber=#{workNumber} </if>",
			"<if test='uniqueIdentificationAccount!=null'>and uniqueIdentificationAccount=#{uniqueIdentificationAccount} </if>",
			"</script>"})
	Student queryStudentQ(UserM user);


	@Update("update student set lastLoginTime=#{lastTime},loginNumber=#{loginNumber}  where studentId=#{studentId}")
	void updateStudentQ(@Param("lastTime") String lastTime,@Param("loginNumber") Integer loginNumber,@Param("studentId") Integer studentId);
	
	
	
	
	
	
	
	
	
}
