package com.yipin.liuwanr.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Delete;
import org.apache.ibatis.annotations.Insert;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Select;

import com.yipin.liuwanr.entity.Comment;
import com.yipin.liuwanr.entity.Topic;
import com.yipin.liuwanr.entity.User;
@Mapper
public interface TopicMapper {

	@Select("SELECT t.*,nickname,avatar,comment,praise,follow,opinion FROM (select * from `lw_topic` where tuid=#{tuid}) as t left join (select tuid, count(id) as comment from `lw_comment` where type= 1 GROUP BY tuid) c1 on t.`tuid`= c1.`tuid` left join (select tuid, count(id) as praise from `lw_topic_opinion` where type=2 GROUP BY tuid) c2 on t.`tuid`= c2.`tuid` left join ( select tuid, count(id) as follow from `lw_topic_opinion` where type= 3 GROUP BY tuid) as c3 on t.`tuid`= c3.`tuid` left join (select tuid, type as opinion from lw_topic_opinion where uuid=#{uuid}) as c4 on t.tuid=c4.tuid left join lw_user as u on t.uuid=u.uuid")
	Topic getById(String uuid,String tuid);

	@Select("SELECT t.*,comment,praise,follow FROM (select * from `lw_topic` where uuid=#{uuid}) t left join ( select tuid, count(cuid) as comment from `lw_comment` where type= 1 GROUP BY tuid) c1 on t.`tuid`= c1.`tuid` left join (select tuid, count(id) as praise from `lw_topic_opinion` where type=2 GROUP BY tuid) c2 on t.`tuid`= c2.`tuid` left join ( select tuid, count(id) as follow from `lw_topic_opinion` where type= 3 GROUP BY tuid) as c3 on t.`tuid`= c3.`tuid` order by createtime desc;")
	List<Topic> getAllByUser(String uuid);

	@Select("SELECT t.*,comment,praise,follow FROM (select * from `lw_topic` where uuid=#{uuid} and type= #{type} ) as t left join ( select tuid, count(cuid) as comment from `lw_comment` where type= 1 GROUP BY tuid) c1 on t.`tuid`= c1.`tuid` left join (select tuid, count(id) as praise from `lw_topic_opinion` where type=2 GROUP BY tuid) c2 on t.`tuid`= c2.`tuid` left join ( select tuid, count(id) as follow from `lw_topic_opinion` where type= 3 GROUP BY tuid) as c3 on t.`tuid`= c3.`tuid` order by createtime desc;")
	List<Topic> getTypeByUser(String uuid, int type);

	@Select("SELECT tuid, lw_topic.uuid, nickname, avatar, type, title, content, images, longitude, latitude, lw_topic.createtime FROM lw_topic join lw_user as a on lw_topic.uuid=a.uuid where longitude between #{minlongitude} and #{maxlongitude} and latitude between #{minlatitude} and #{maxlatitude}")
	List<Topic> getByLocation(double maxlatitude, double minlatitude, double maxlongitude, double minlongitude);

	@Select("select a.*,u1.nickname,u1.avatar,u2.nickname as tonickname,type,content,agree,object,opinion from lw_comment as a left join lw_user as u1 on a.uuid=u1.uuid left join lw_user as u2 on a.touuid=u2.uuid left join (select cuid, count(id) as agree from lw_comment_opinion where type=4 GROUP BY cuid) as b on a.cuid=b.cuid left join (select cuid,count(id) as object from lw_comment_opinion where type=5 GROUP BY cuid) as c on a.cuid=c.cuid left join (select cuid, type as opinion from lw_comment_opinion where uuid=#{uuid}) as d on a.cuid=d.cuid where tuid=#{tuid} and type=1")
	List<Comment> getCommentByTopic(String uuid, String tuid);
	
	@Select("select u.* from lw_topic_opinion as t left join lw_user as u on t.uuid=u.uuid where tuid=#{tuid} and type=#{type}")
	List<User> getUsersByTopic(String tuid, int type);

	@Select("SELECT a.cuid, a.tuid, a.uuid, b.nickname as nickname, b.avatar as avatar, a.touuid, c.nickname as tonickname, a.tocuid, a.type, a.content, a.image, a.createtime FROM lw_comment as a left join lw_user as b on a.uuid=b.uuid left join lw_user as c on a.touuid = c.uuid where a.cuid = #{cuid}")
	Comment getCommentById(String cuid);

	@Select("SELECT count(*) from lw_topic where uuid=#{uuid} and tuid=#{tuid}")
	int checkTopic(String uuid, String tuid);

	@Select("SELECT count(*) from lw_comment as c join lw_topic as t on c.tuid=t.tuid where cuid=#{cuid} and (c.uuid=#{uuid} or t.uuid=#{uuid})")
	int checkComment(String uuid, String cuid);
	
	@Select("SELECT count(*) from lw_comment_opinion where uuid=#{uuid} and cuid=#{cuid}")
	int checkOpinion(String uuid, String cuid);

	@Insert("INSERT INTO lw_topic(tuid, uuid, type, title, content, images, longitude, latitude, createtime) VALUES(#{tuid}, #{uuid}, #{type}, #{title}, #{content}, #{images}, #{longitude}, #{latitude}, now())")
	void create(Topic topic);

	@Insert("INSERT INTO lw_comment(cuid, tuid, uuid, touuid, tocuid, type, content, createtime) VALUES(#{cuid}, #{tuid}, #{uuid}, #{touuid}, #{tocuid}, #{type}, #{content}, now())")
	void comment(Comment comment);
	
	@Insert("INSERT INTO lw_topic_opinion(tuid, uuid, type, createtime) VALUES(#{tuid}, #{uuid}, #{type}, now())")
	void topicOpinion(String tuid, String uuid, int type);
	
	@Insert("INSERT INTO lw_comment_opinion(cuid, uuid, type, createtime) VALUES(#{cuid}, #{uuid}, #{type}, now())")
	void insertCommentOpinion(String cuid, String uuid, int type);
	
	@Insert("UPDATE lw_comment_opinion set type=#{type}, createtime=now() where cuid=#{cuid} and uuid=#{uuid}")
	void updateCommentOpinion(String cuid, String uuid, int type);

	@Delete("DELETE FROM lw_topic WHERE tuid = #{tuid}")
	void delete(String tuid);

	@Delete("DELETE FROM lw_comment WHERE cuid = #{cuid}")
	void deleteComment(String cuid);

	@Delete("DELETE FROM lw_topic_opinion WHERE tuid = #{tuid} and uuid=#{uuid} and type=#{type}")
	void deleteOpinionToTopic(String tuid, String uuid, int type);

	@Delete("DELETE FROM lw_comment_opinion WHERE cuid = #{cuid} and uuid=#{uuid} and type=#{type}")
	void deleteOpinionToComment(String cuid, String uuid, int type);
}