package com.yipin.liuwanr.mapper;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.vo.UserVO;
import org.apache.ibatis.annotations.*;
import org.apache.ibatis.mapping.FetchType;

import java.util.List;

@Mapper
public interface UserMapper {

	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city,password,createtime,updatetime FROM lw_user")
	List<User> getAll();

	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city,password,createtime,updatetime FROM lw_user WHERE uuid = #{uuid}")
	User getOne(String uuid);

	@Results({
			@Result(property="pets", column="petlist", many=@Many(select="com.yipin.liuwanr.mapper.PetMapper.getAll",fetchType=FetchType.EAGER))
	})
	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city, uuid as petlist, password,createtime,updatetime FROM lw_user WHERE uuid = #{uuid}")
	User getSelfById(String uuid);

	@Results({
			@Result(property="pets", column="petlist", many=@Many(select="com.yipin.liuwanr.mapper.PetMapper.getAll",fetchType=FetchType.EAGER))
	})
	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city, uuid as petlist, password,createtime,updatetime FROM lw_user WHERE mobile = #{key} or email = #{key}")
	User getSelfByAccount(String key);

	@Results({
			@Result(property="pets", column="petlist", many=@Many(select="com.yipin.liuwanr.mapper.PetMapper.getAll",fetchType=FetchType.EAGER))
	})
	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city, uuid as petlist, password,createtime,updatetime FROM lw_user WHERE wxid = #{value} or qqid = #{value} or aliid = #{value} or sinaid = #{value} or netid = #{value}")
	User getSelfBy3rdId(String value);

	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city,password,createtime,updatetime FROM lw_user WHERE mobile = #{value}")
	User getOneByMobile(String value);

	@Select("SELECT uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city,password,createtime,updatetime FROM lw_user WHERE email = #{value}")
	User getOneByEmail(String value);

	@Insert("INSERT INTO lw_user(uuid,mobile,email,wxid,qqid,aliid,sinaid,netid,nickname,sex,birthday,sign,avatar,country,province,city,password,createtime) VALUES(#{uuid},#{mobile},#{email},#{wxid},#{qqid},#{aliid},#{sinaid},#{netid},#{nickname},#{sex},#{birthday},#{sign},#{avatar},#{country},#{province},#{city},#{password},now())")
	void insert(User user);

	@Update({ "<script>",
			"UPDATE lw_user SET",
			"<when test='mobile!=null'>", "mobile=#{mobile},", "</when>",
			"<when test='email!=null'>", "email=#{email},", "</when>",
			"<when test='nickname!=null'>", "nickname=#{nickname},", "</when>",
			"<when test='sex!=-1'>", "sex=#{sex},", "</when>",
			"<when test='sign!=null'>", "sign=#{sign},", "</when>",
			"<when test='birthday!=null'>", "birthday=#{birthday},", "</when>",
			"<when test='avatar!=null'>", "avatar=#{avatar},", "</when>",
			"<when test='country!=null'>", "country=#{country},", "</when>",
			"<when test='province!=null'>", "province=#{province},", "</when>",
			"<when test='city!=null'>", "city=#{city},", "</when>",
			"updatetime=now() WHERE uuid =#{uuid}",
			"</script>"})
	void update(User user);

	@Delete("DELETE FROM lw_user WHERE uuid =#{id}")
	void delete(String uuid);

	@Insert("INSERT INTO lw_user_block(uuid, buuid, createtime) VALUES(#{uuid}, #{buuid}, now())")
	void blockOne(String uuid, String buuid);

	@Delete("DELETE FROM lw_user_block WHERE uuid = #{uuid} AND buuid = #{buuid}")
	void unblockOne(String uuid, String buuid);

	@Select("SELECT lw_user.uuid, lw_user.nickname, lw_user.sex, lw_user.sign, lw_user.avatar FROM lw_user_block JOIN lw_user ON lw_user_block.buuid = lw_user.uuid WHERE lw_user_block.uuid = #{uuid}")
	List<User> blockList(String uuid);

	@Update({ "UPDATE lw_user SET password=#{password}, updatetime=now() WHERE uuid=#{uuid}"})
	void changePassword(String uuid, String password);

	@Insert("INSERT INTO lw_user_config(uuid, conf1, conf2, conf3, conf4, conf5, updatetime) VALUES(#{uuid}, #{conf1}, #{conf2}, #{conf3}, #{conf4}, #{conf5}, now())")
	void genconf(Config config);

	@Select("SELECT uuid,conf1, conf2, conf3, conf4, conf5 FROM lw_user_config where uuid=#{uuid}")
	Config getconf(String uuid);

	@Update({ "<script>",
			"UPDATE lw_user_config SET",
			"<when test='conf1!=-1'>", "conf1=#{conf1},", "</when>",
			"<when test='conf2!=-1'>", "conf2=#{conf2},", "</when>",
			"<when test='conf3!=-1'>", "conf3=#{conf3},", "</when>",
			"<when test='conf4!=-1'>", "conf4=#{conf4},", "</when>",
			"<when test='conf5!=-1'>", "conf5=#{conf5},", "</when>",
			"updatetime=now() WHERE uuid =#{uuid}",
			"</script>"})
	void putconf(Config config);

	@Select("SELECT * from demo")
	List<Demo> demo(Demo demo);

	@Insert("INSERT INTO demo(symbol,code,name,trade,pricechange,changepercent,buy,sell,settlement,open,high,low,volume,amount,ticktime,"
			+ "per,pb,mktcap,nmc,turnoverratio) VALUES(#{symbol},#{code},#{name},#{trade},#{pricechange},#{changepercent},#{buy},#{sell},"
			+ "#{settlement},#{open},#{high},#{low},#{volume},#{amount},#{ticktime},#{per},#{pb},#{mktcap},#{nmc},#{turnoverratio}) ")
	void insertDemo(Demo demo);

	@Insert("INSERT INTO user(name,password,sex,documentType,countries,educationDegree,IDNumber,accountRole,provinceId,subjectsTaught,cityId,phone,teachingProfessional,WeChatID,dateBirth,email,creationTime,isdel,schoolId,uniqueIdentificationAccount,disciplineId,professionalClassId,professionalId,userAccount,workNumber)"
			+ " VALUES(#{name},#{password},#{sex},#{documentType},#{countries},#{educationDegree},#{IDNumber},#{accountRole},#{provinceId},#{subjectsTaught},#{cityId},#{phone},#{teachingProfessional},#{WeChatID},#{dateBirth},#{email},now(),0,#{schoolId},#{uniqueIdentificationAccount},#{disciplineId},#{professionalClassId},#{professionalId},#{userAccount},#{workNumber})")
	void addUser(UserM user);

//	//添加学生
//	@Insert("INSERT INTO student(name,password,sex,documentType,countries,educationDegree,IDNumber,accountRole,provinceId,subjectsTaught,cityId,phone,teachingProfessional,WeChatID,dateBirth,email,creationTime,isdel,schoolId,uniqueIdentificationAccount,disciplineId,professionalClassId,professionalId)"
//			+ " VALUES(#{name},#{password},#{sex},#{documentType},#{countries},#{educationDegree},#{IDNumber},#{accountRole},#{provinceId},#{subjectsTaught},#{cityId},#{phone},#{teachingProfessional},#{WeChatID},#{dateBirth},#{email},now(),0,#{schoolId},#{uniqueIdentificationAccount},#{disciplineId},#{professionalClassId},#{professionalId})")
//	void addStudent(Student student);
//
//	//添加员工
//	@Insert("INSERT INTO staff(name,password,sex,documentType,countries,educationDegree,IDNumber,accountRole,provinceId,subjectsTaught,cityId,phone,teachingProfessional,WeChatID,dateBirth,email,creationTime,isdel,schoolId,uniqueIdentificationAccount,disciplineId,professionalClassId,professionalId)"
//			+ " VALUES(#{name},#{password},#{sex},#{documentType},#{countries},#{educationDegree},#{IDNumber},#{accountRole},#{provinceId},#{subjectsTaught},#{cityId},#{phone},#{teachingProfessional},#{WeChatID},#{dateBirth},#{email},now(),0,#{schoolId},#{uniqueIdentificationAccount},#{disciplineId},#{professionalClassId},#{professionalId})")
//	void addStaff(Staff staff);

	//	@Select("SELECT * from user where isdel = 1 and countries =  #{countries} and provinces = #{provinces} and city = #{city}")
	@Select({"<script>",
			"SELECT u.*,s.schoolName,p.provinceName,c.cityName from user u,school s,province p,city c where u.isdel = 0 and p.provinceId = u.provinceId and p.provinceId = c.provinceId and u.cityId = c.cityId and u.schoolId = s.schoolId",
			" <if test='countries!=null and countries !=\"\" '>and u.countries = #{countries} </if>",
			" <if test='provinceId!=null and provinceId !=\"\" '>and u.provinceId = #{provinceId} </if>",
			" <if test='schoolId!=null'>and u.schoolId = #{schoolId} </if>",
			" <if test='cityId!=null and cityId !=\"\" '>and u.cityId = #{cityId} </if>",
			" <if test='accountRole!=null and accountRole !=\"\" '>and u.accountRole = #{accountRole} </if>",
			" <if test='searchContent!=null and searchContent !=\"\" '>  AND CONCAT(u.name, s.schoolName) LIKE CONCAT('%',#{searchContent},'%')</if>",
			" <if test='month==3'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 3 MONTH)</if>",
			" <if test='month==6'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 6 MONTH)</if>",
			" <if test='month==9'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 9 MONTH)</if>",
			" <if test='month==12'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 12 MONTH)</if>",
			" <if test='creationTime!=null and endTime!=null and endTime!=\"\" and creationTime!=\"\" '> and u.creationTime between #{creationTime} and #{endTime}</if>",
			"GROUP BY u.userId order by u.creationTime desc",
			"</script> "})
	List<UserM> queryUser(UserM user);

	@Select({"<script>",
			"SELECT s.schoolName,s.provinceId,s.cityId,s.provinceName,s.cityName,u.userId,u.userName,u.countries,u.creationTime,u.account,u.logInNumber,hor.schoolId,hor.platformId,hor.roleId FROM hr_userInfo u,hr_organization_relationship hor,school s WHERE u.userId = hor.userId and hor.schoolId = s.schoolId and s.isdel = 0",
			" <if test='countries!=null and countries !=\"\" '>and u.countries = #{countries} </if>",
			" <if test='provinceId!=null and provinceId !=\"\" '>and u.provinceId = #{provinceId} </if>",
			" <if test='schoolId!=null and schoolId !=\"\"'>and u.schoolId = #{schoolId} </if>",
			" <if test='cityId!=null and cityId !=\"\" '>and u.cityId = #{cityId} </if>",
			" <if test='roleId!=null and roleId !=\"\" '>and u.roleId = #{roleId} </if>",
//			" <if test='searchContent!=null and searchContent !=\"\" '>  AND CONCAT(u.name, s.schoolName) LIKE CONCAT('%',#{searchContent},'%')</if>",
			" <if test='month==3'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 3 MONTH)</if>",
			" <if test='month==6'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 6 MONTH)</if>",
			" <if test='month==9'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 9 MONTH)</if>",
			" <if test='month==12'>and u.creationTime>DATE_SUB(CURDATE(), INTERVAL 12 MONTH)</if>",
			" <if test='creationTime!=null and endTime!=null and endTime!=\"\" and creationTime!=\"\" '> and u.creationTime between #{creationTime} and #{endTime}</if>",
			"GROUP BY u.userId order by u.creationTime desc",
			"</script> "})
	List<UserInfo> queryUserInfo(UserInfo userInfo);

	@Update("UPDATE hr_userInfo SET isdel = 1 where userId = #{userId}")
	void deleteUser(Integer userId);

	//批量删除员工
	@Update({ "<script>",
			"UPDATE staff SET isdel = 1 where phone = #{phone} ",
			"</script>" })
	void deleteStaff(UserM user);

	//批量删除学生
	@Update({ "<script>",
			"UPDATE student SET isdel = 1 where phone = #{phone} ",
			"</script>" })
	void deleteStudent(UserM user);

	//修改用户
	@Update("UPDATE user SET name = #{name},sex = #{sex},documentType = #{documentType},countries = #{countries},educationDegree = #{educationDegree},"
			+ "IDNumber = #{IDNumber},accountRole = #{accountRole},provinceId = #{provinceId},subjectsTaught = #{subjectsTaught},cityId = #{cityId},"
			+ "phone = #{phone},teachingProfessional = #{teachingProfessional},WeChatID = #{WeChatID},dateBirth = #{dateBirth},email = #{email},schoolId = #{schoolId},disciplineId = #{disciplineId},professionalId = #{professionalId},professionalClassId = #{professionalClassId} where userId = #{userId}")
	void updateUser(UserM user);

	//修改员工
	@Update("UPDATE staff SET staffName = #{staffName},staffWorkNumber = #{staffWorkNumber},phone = #{phone},email = #{email},staffProfessionalArchitectureId = #{staffProfessionalArchitectureId},"
			+ "staffProfessionalArchitectureId = #{staffProfessionalArchitectureId},staffGradeId = #{staffGradeId},roleId = #{roleId} where phone = #{phone}")
	void updateStaff(Staff staff);

	//修改学生
	@Update("UPDATE student SET studentName = #{studentName},studentNumber = #{studentNumber},phone = #{phone},email = #{email},roleId = #{roleId}"
			+ ",schoolId = #{schoolId},professionalId = #{professionalId},gradeId = #{gradeId},classId = #{classId} where phone = #{phone}")
	void updateStudent(Student student);

	//登陆
	@Select("SELECT u.* from user u where isdel=0 and phone = #{phone} and password = #{password}")
	UserM logins(UserM user);

	//查询用户手机
	@Select("SELECT u.phone,u.userId from hr_user_info u where isdel=0 and phone = #{phone}")
	List<UserInfo> queryPhone(String phone);

	//查询用户详情
	@Select({"<script>",
			"SELECT u.*,schoolName from user u,school s where u.isdel = 0 and u.schoolId = s.schoolId and u.userId = #{userId}",
			"</script> "})
	List<UserM> queryUserDetails(Integer userId);

	@Select({"<script>",
			"SELECT u.*,schoolName from user u,school s where u.isdel = 0 and u.schoolId = s.schoolId and u.userId = #{userId}",
			"</script> "})
	@Results({
			@Result(property = "user", column = "userId",one = @One(select = "com.yipin.liuwanr.mapper.UserMapper.queryUserDetailss")),
	})
	List<UserVO> queryUserDetailsAdmin(Integer userId);

	@Select({"<script>",
			"SELECT u.*,schoolName from user u,school s where u.isdel = 0 and u.schoolId = s.schoolId and u.userId = #{userId}",
			"</script> "})
	List<UserM> queryUserDetailss(Integer userId);

	@Select({"<script>",
			"SELECT u.*,schoolName from user u,school s where u.isdel = 0 and u.schoolId = s.schoolId and u.userId = #{userId}",
			"</script> "})
	@Results({
			@Result(property = "user", column = "userId",one = @One(select = "com.yipin.liuwanr.mapper.UserMapper.queryUserDetails")),
			@Result(property = "staff", column = "userId",one = @One(select = "com.yipin.liuwanr.mapper.UserMapper.queryUserDetailsSta"))
	})
	List<UserVO> queryUserDetailsStaff(Integer userId);
	//查询用户详情学生角色
	//查询学生用户详情

	@Select({"<script>",
			"SELECT u.*,schoolName from user u,school s where u.isdel = 0 and u.schoolId = s.schoolId and u.userId = #{userId}",
			"</script> "})
	@Results({
			@Result(property = "user", column = "userId",one = @One(select = "com.yipin.liuwanr.mapper.UserMapper.queryUserDetails")),
			@Result(property = "student", column = "userId",one = @One(select = "com.yipin.liuwanr.mapper.UserMapper.queryUserDetailsStu"))
	})
	List<UserVO> queryUserDetailsStudent(Integer userId);
	@Select({"<script>",
			" SELECT u.userId,u.phone,s.* FROM user u,student s where u.phone = s.phone and u.userId =#{userId}",
			"</script> "})
	List<Student> queryUserDetailsStu(Integer userId);

	//查询老师用户详情
	@Select({"<script>",
			" SELECT u.userId,u.phone,s.* FROM user u,staff s where u.phone = s.phone and u.userId =#{userId}",
			"</script> "})
	List<Staff> queryUserDetailsSta(Integer userId);

	@Select({"<script>",
			"SELECT customerId,customerName,schoolId FROM customer where isdel = 0 and provinceId = #{provinceId} and cityId = #{cityId}",
			"</script> "})
	List<Customer> queryCustomer(Integer cityId,Integer provinceId);

	/**
	 * 批量插入用户
	 * @param user
	 */
	@Insert({
			"<script>",
			"insert into user(name, password,accountRole,workNumber,phone,uniqueIdentificationAccount,creationTime,isdel) values ",
			"<foreach collection='users' item='user' index='index' separator=','>",
			"(#{user.name}, #{user.password}, #{user.accountRole}, #{user.workNumber} ,#{user.phone},#{user.uniqueIdentificationAccount},now(),0)",
			"</foreach>",
			"</script>"
	})
	void addUserM(@Param("users")List<UserM> users);

	//修改用户头像
	@Update("update user set userAvatars=#{userAvatars} where userId=#{userId}")
	void updateUserAvatars(@Param("userAvatars")String userAvatars, @Param("userId")Integer userId);

	//更新用户登录次数和最后一次登录时间
	@Update({ "UPDATE user SET logInNumber=logInNumber+1, lastTimeOfLanding=now() WHERE userId=#{userId}"})
	void updateLogInNumber(UserM user);

	//更新用户登录次数和最后一次登录时间
	@Update({ "UPDATE student SET logInNumber=logInNumber+1, lastLoginTime=now() WHERE userId=#{userId}"})
	void updateStudentLogInNumber(UserM user);

	//更新用户登录次数和最后一次登录时间
	@Update({ "UPDATE staff SET logNumber=logNumber+1, lastTimeOfLanding=now() WHERE userId=#{userId}"})
	void updateStaffLogInNumber(UserM user);

	//查询账号是否存在
	@Select("SELECT userId,userAccount from user where isdel = 0 and userAccount = #{userAccount}")
	List<UserM> queryAccountIsExist(String userAccount);

	//查询学号、工号是否存在
	@Select("SELECT userId,workNumber from user where isdel = 0 and workNumber = #{workNumber}")
	List<UserM> queryWorkNumberIsExist(String workNumber);

	//========全承珠
	@Select("select userId,password,accountRole,logInNumber,workNumber,phone,uniqueIdentificationAccount,schoolId from user "
			+ " where isdel=0 and password=#{password} and  (phone=#{userAccount}  or workNumber=#{userAccount} or uniqueIdentificationAccount=#{userAccount})")
	UserM loginsQ(@Param("userAccount")String userAccount,@Param("password")String password);


	@Update("update user set lastTimeOfLanding=#{time},logInNumber=#{logInNumber}  where userId=#{userId}")
	void updateUserQ(@Param("time")String time,@Param("logInNumber") Integer logInNumber,@Param("userId") Integer userId);

	//查询用户邮箱
	@Select("SELECT u.email,u.userId from hr_user_info u where isdel = 0 and email = #{email}")
	List<UserInfo> queryEmail(String email);
}