package com.yipin.liuwanr.service;

import java.util.HashMap;

import javax.servlet.http.HttpServletResponse;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import com.aliyun.oss.OSSClient;
import com.yipin.liuwanr.AliyunOssConfig;
import com.yipin.liuwanr.entity.FilesResult;
import com.yipin.liuwanr.helper.OssConfigUtil;


@Service
public class AliyunOssService {

    @Autowired
    private AliyunOssConfig config;

    @Autowired
    private BeanFactory beanFactory;

    private static Logger logger = Logger.getLogger(AliyunOssService.class);

    /**
     * 上传文件
     *
     * @param file 上传文件
     * @return
     */
    public HashMap<String, Object> uploadFiles(MultipartFile file) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            OSSClient client = beanFactory.getBean(OSSClient.class);
            FilesResult result = OssConfigUtil.uploadFiles(file, client, config);
            resp.put("retcode", 200);
            resp.put("retvalue", result);
        } catch (Exception e) {
            logger.info(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Upload Fail");
            return resp;
        }
        return resp;
    }


    /**
     * 下载文件
     *
     * @param objectName 要下载的文件(路径+文件名)
     * @param fileurl    本地路径
     * @return
     */
    public void downloadFiles(HttpServletResponse response, String objectName) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            OSSClient client = beanFactory.getBean(OSSClient.class);
            OssConfigUtil.downloadFiles(response, client, config, objectName);
            resp.put("retcode", 200);
            resp.put("retvalue", "Download SUCCESS");
        } catch (Exception e) {
            logger.info(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Download Fail");
        }
    }

    /**
     * 根据文件路径+文件名称，删除该文件
     *
     * @param filename
     * @return
     */
    public HashMap<String, Object> deleteFile(String filename) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            OSSClient client = beanFactory.getBean(OSSClient.class);
            OssConfigUtil.deleteFile(client, config.getBucketName(), filename);
            resp.put("retcode", 200);
            resp.put("retvalue", "Delete SUCCESS");
        } catch (RuntimeException e) {
            logger.info(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Delete Fail");
            return resp;
        }
        return resp;
    }


}
