package com.yipin.liuwanr.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.Assesment;
import com.yipin.liuwanr.entity.ExperimentalClass;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.PointRecord;
import com.yipin.liuwanr.entity.Record;
import com.yipin.liuwanr.entity.Score;
import com.yipin.liuwanr.entity.Student;
import com.yipin.liuwanr.entity.Class;
import com.yipin.liuwanr.helper.AssesmentHelper;
import com.yipin.liuwanr.mapper.AssesmentMapper;

@Service
public class AssesmentService {

    private static Logger logger = Logger.getLogger(AssesmentService.class);

    @Autowired
    private AssesmentMapper mapper;

    /**
     * 考核管理列表查询
     *
     * @param assesment
     * @param pageNo
     * @param pageSize
     * @return
     */
    public HashMap<String, Object> queryAssesmentCondition(Assesment assesment, Integer pageNo, Integer pageSize) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            PageHelper.startPage(pageNo, pageSize);
            List<Assesment> assesments = mapper.getByCondition(assesment);
            PageInfo<Assesment> info = new PageInfo<Assesment>(assesments);
            int total1 = (int) info.getTotal();
            int totalPages;
            totalPages = total1 / pageSize;
            if (total1 % pageSize != 0) {
                totalPages++;
            }
            long total = total1;
            resp.put("retvalue", new PageResult(total, assesments, totalPages));
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 创建考核
     *
     * @return
     */
    @Transactional
    public HashMap<String, Object> addAssesment(Assesment assesment, List<Integer> studentIds) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            //转换时间格式
            assesment = AssesmentHelper.helpAssesment(assesment);
            String experimentalClassId=assesment.getExperimentalClassId();
            if (!StringUtils.isEmpty(experimentalClassId)) {
                List<String> classid = mapper.queryClassId(studentIds);//行政班级id
                String classId = String.join(",", classid);
                assesment.setClassId(classId);
            }
            //考核人数
            assesment.setAssessmentSize(studentIds.size());
            //判分点数量
            Integer pointNumber = mapper.queryPointNumber(assesment.getExperimentId());
            assesment.setAssessmentNumber(pointNumber);
            //添加考核
            mapper.insertAssesment(assesment);
            //得到考核id
            Integer assesmentId = assesment.getId();

            //往记录表中添加选中的学生信息，哪名学生要参与某一课程的什么考核，该考核下的 哪一项目
            mapper.insertRecore(studentIds, assesment.getExperimentId(), assesment.getCourseId(), assesmentId);

            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Add Failed");
            throw new RuntimeException();
        }
        return resp;
    }


    /**
     * 查询选中的学生有哪些正在参与考核
     *
     * @param studentIds
     * @return
     */
    public HashMap<String, Object> queryStudentisAssess(List<Integer> studentIds) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            //查询出来的学生信息
            List<Student> stu = mapper.queryStudentisAssess(studentIds);
            resp.put("retcode", 200);
            resp.put("retvalue", stu);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 根据id查询考核的信息
     *
     * @param id
     * @return
     */
    public HashMap<String, Object> queryGetById(Integer id) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        HashMap<String, Object> obj = new HashMap<>();
        try {
            //考核信息
            Assesment assesment = mapper.queryGetById(id);
            //之前选中的学生
            List<Student> students = mapper.queryStudent(id);
            obj.put("assesment", assesment);
            obj.put("students", students);

            resp.put("retvalue", obj);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 修改考核管理
     *
     * @return
     */
    @Transactional
    public HashMap<String, Object> updateAssesment(Assesment assesment, List<Integer> studentIds) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        assesment = AssesmentHelper.helpAssesment(assesment);

        try {
            //数据库存储的考核信息
            Assesment before = mapper.queryGetById(assesment.getId());
            //数据库存储的学生
            List<Student> students = mapper.queryStudent(assesment.getId());
            String experimentalClassId=assesment.getExperimentalClassId();
            if (!StringUtils.isEmpty(experimentalClassId)) {
                List<String> classid = mapper.queryClassId(studentIds);//新的行政班级id
                String classId = String.join(",", classid);
                if (!classId.equals(before.getClassId())) {
                    assesment.setClassId(classId);
                }
            } else if (!StringUtils.isEmpty(assesment.getClassId())) {
                assesment.setExperimentalClassId(null);
            }
            // 比较两批学生的信息
            for (int i = 0; i < studentIds.size(); i++) {
                for (int j = 0; j < students.size(); j++) {
                    if (studentIds.get(i).equals(students.get(j).getStudentId())) {
                        studentIds.remove(i);
                        students.remove(students.get(j));
                        i--;
                        break;
                    }
                }
            }
            //前端传来的添加
            if (studentIds.size() > 0) {
                mapper.insertRecore(studentIds, assesment.getExperimentId(), assesment.getCourseId(), assesment.getId());
            }
            //后端剩余的删除
            if (students.size() > 0) {
                mapper.deleteRecord(assesment.getId(), students);
            }
            //更新考核
            assesment.setAssessmentSize(studentIds.size());//考核人数
            //判分点数量
            Integer pointNumber = mapper.queryPointNumber(assesment.getExperimentId());
            assesment.setAssessmentNumber(pointNumber);

            mapper.updateAssesment(assesment);

            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Update Failed");
            throw new RuntimeException();
        }
        return resp;
    }


    /**
     * 启动考核前的判断
     *
     * @param assesmentId
     * @return
     */
    public HashMap<String, Object> assessmentJudgment(Integer assesmentId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        List<Student> obj = new ArrayList<Student>();
        try {
            List<Integer> datas = mapper.getStudentisAssess();
            List<Student> students = mapper.queryStudent(assesmentId);
            for (int i = 0; i < students.size(); i++) {
                Student stu = students.get(i);
                if (datas.contains(stu.getStudentId())) {
                    obj.add(stu);
                }
            }
            resp.put("retvalue", obj);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 修改考核状态
     *
     * @return
     */
    public HashMap<String, Object> updateState(Assesment assesment) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        long starttime = 0;
        long endtime = 0;
        String[] datas;
        int hour = 0;
        int minute = 0;
        try {
            String createTime = assesment.getCreationTime();
            String endTime = assesment.getEndTime();
            String timeSum = assesment.getTimesum();

            if (createTime != null && !createTime.equals("")) {
                starttime = Long.parseLong(assesment.getCreationTime());
                assesment.setCreationTime(AssesmentHelper.longPointDate(starttime));
            }
            if (endTime != null && !endTime.equals("")) {
                endtime = Long.parseLong(assesment.getEndTime());
                assesment.setEndTime(AssesmentHelper.longPointDate(endtime));
            }
            //提前结束
            if(assesment.getAssesmentState().equals(2)&&!StringUtils.isEmpty(timeSum)){
                long time=Long.parseLong(timeSum);
                String gapTime=AssesmentHelper.getGapTime(time);
                assesment.setTimesum(gapTime);
            }
            //手动发布考核
            else if (assesment.getReleaseType().equals(0)&&!StringUtils.isEmpty(timeSum)) {
                datas = timeSum.split("h");
                if (datas != null && datas.length > 0) {
                    hour = Integer.parseInt(datas[0]);
                    if (datas.length > 2) {
                        String str=datas[1];
                        String[] strs=str.split("m");
                        minute = Integer.parseInt(strs[1]);
                    }
                }
                long time = ((hour * 60) + minute) * 60 * 1000;
                endTime = AssesmentHelper.longPointDate(starttime + time);
                assesment.setEndTime(endTime);
            }
            mapper.updateAssesmentState(assesment);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 查询实验班级一级栏目
     *
     * @param staffId：教师id
     * @return
     */
    public HashMap<String, Object> queryCretionTime(Integer staffId, Integer schoolId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", mapper.queryCreationTime(staffId, schoolId));
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 查询实验班级名称，以及班级一下的学生
     *
     * @param cretionTime
     * @return
     */
    public HashMap<String, Object> queryCretionTime(String cretionTime, Integer staffId, Integer schoolId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", mapper.queryExperimentalClass(cretionTime, staffId, schoolId));
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 考核信息展示
     *
     * @param assesmentId
     * @return
     */
    public HashMap<String, Object> queryAssesment(Integer assesmentId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", mapper.queryAssesmentId(assesmentId));
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 班级筛选
     *
     * @param assesmentId
     * @return
     */
    public HashMap<String, Object> getByclass(Integer assesmentId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        HashMap<String, Object> obj = new HashMap<String, Object>();
        try {
            List<ExperimentalClass> experimentalClasses = mapper.queryExperimental(assesmentId);
            List<Class> classes = mapper.queryClass(assesmentId);
            obj.put("experimentalClass", experimentalClasses);
            obj.put("class", classes);

            resp.put("retvalue", obj);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 成绩概况
     */
    public HashMap<String, Object> queryScore(Integer assesmentId, Integer experimentalClassId, Integer classId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        Score score;
        int size = 0;
        try {
            List<Student> students=queryStudents(experimentalClassId,classId);
            //判分点数量
            Integer pointNumber = mapper.getAssesmentNumber(assesmentId);
            if (StringUtils.isEmpty(pointNumber)) {
                pointNumber = 0;
            }
            if (!students.isEmpty() && students.size() > 0) {
                List<Integer> scores = mapper.queryScore(assesmentId, students);
                score = new Score();
                if (!scores.isEmpty() && scores.size() > 0) {
                    size = scores.size();
                    score.setMin(scores.get(0));//最低分
                    score.setMax(scores.get(size - 1)); //最高分
                    score.setPeopleSize(size);//考核人数
                    double median = 0.0; //中位数
                    if (size % 2 == 1) {
                        median = scores.get((size - 1) / 2);
                    } else {
                        median = (scores.get((size / 2 - 1)) + scores.get(size / 2) + 0.0) / 2;
                    }
                    score.setMedian(median);
                    int avg = 0;//平均分
                    for (int i = 0; i < scores.size(); i++) {
                        avg += scores.get(i);
                    }
                    score.setAvg(avg * 1.0 / size);
                } else {
                    score.setMin(0);//最低分
                    score.setMax(0);//最高分
                    score.setPeopleSize(size);//考核人数
                    score.setMedian(0);//中位数
                    score.setAvg(0);//平均分
                }

                score.setPointNumber(pointNumber);
                //错误率
                Integer classError = mapper.queryRight(assesmentId, experimentalClassId, classId);
                if (StringUtils.isEmpty(classError) || size == 0) {
                    score.setError(0);
                } else {
                    double error = (classError * 1.0 / (size * pointNumber)) * 100;
                    score.setError(error);
                }

            } else {
                score = new Score(0.0, 0.0, 0, 0, 0, pointNumber, 0.0);
            }
            resp.put("retvalue", score);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    private List<Student> queryStudents(Integer experimentalClassId, Integer classId){
        List<Student> students=null;
        if (experimentalClassId != null) {
            students = mapper.getByExperimentalClassId(experimentalClassId);
        } else if (classId != null) {
            students = mapper.getByclassId(classId);
        }
        return  students;
    }


    /**
     * 成绩柱状图
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
    public HashMap<String, Object> queryHistogram(Integer assesmentId, Integer experimentalClassId,Integer classId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        List<Integer> obj = new ArrayList<Integer>();
        try {
            Integer one = 0;
            Integer two = 0;
            Integer three = 0;
            Integer four = 0;
            Integer five = 0;
            Integer six = 0;
            Integer seven = 0;
            Integer eight = 0;
            Integer nine = 0;
            Integer ten = 0;

            List<Student> students=queryStudents(experimentalClassId,classId);

            List<Record> scores = mapper.getGroupByScore(assesmentId,students);
            for (int i = 0; i < scores.size(); i++) {
                Integer score = scores.get(i).getScore();
                Integer number = scores.get(i).getNumber();
                if (score >= 0 && score <= 10) {
                    one += number;
                } else if (score > 10 && score <= 20) {
                    two += number;
                } else if (score > 20 && score <= 30) {
                    three += number;
                } else if (score > 30 && score <= 40) {
                    four += number;
                } else if (score > 40 && score <= 50) {
                    five += number;
                } else if (score > 50 && score <= 60) {
                    six += number;
                } else if (score > 60 && score <= 70) {
                    seven += number;
                } else if (score > 70 && score <= 80) {
                    eight += number;
                } else if (score > 80 && score <= 90) {
                    nine += number;
                } else if (score > 90 && score <= 100) {
                    ten += number;
                }

            }

            obj.add(ten);
            obj.add(nine);
            obj.add(eight);
            obj.add(seven);
            obj.add(six);
            obj.add(five);
            obj.add(four);
            obj.add(three);
            obj.add(two);
            obj.add(one);


            resp.put("retvalue", obj);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 错误分布折线图
     *
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
    public HashMap<String, Object> getLinechart(Integer assesmentId, Integer experimentalClassId,Integer classId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        List<Object> obj = new ArrayList<Object>();
        try {
            List<PointRecord> errors = mapper.queryError(assesmentId, experimentalClassId, classId);
            List<String> names = new ArrayList<String>();
            List<Integer> datas = new ArrayList<Integer>();

            for (int i = 0; i < errors.size(); i++) {
                PointRecord pointRecord = errors.get(i);
                names.add(pointRecord.getJudgmentPointsName());
                datas.add(pointRecord.getNumber());
            }

            obj.add(names);
            obj.add(datas);
            resp.put("retvalue", obj);
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 成绩明细
     *
     * @param assesmentId
     * @param experimentalClassId
     * @param classId
     * @return
     */
    public HashMap<String, Object> queryAssesmentScore(Integer assesmentId, Integer experimentalClassId,Integer classId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            List<Student> students=queryStudents(experimentalClassId,classId);
            if(!students.isEmpty() && students.size()>0){
                List<Record> records=mapper.queryScoreDetailed(assesmentId,students);
                resp.put("retvalue",records );
            }
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }


    /**
     * 开启考核
     *
     * @param courseId
     * @return
     */
    public HashMap<String, Object> releaseAssesment(Integer courseId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
           if(courseId!=null){
               resp.put("retvalue", mapper.releaseAssesment(courseId));
           }
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;

    }

    /**
     * 删除考核
     * @param assesmentId
     * @return
     */
    public HashMap<String, Object> deleteAssesment(Integer assesmentId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            boolean relus=mapper.deleteAssesment(assesmentId);
            if(relus){
                mapper.deleteRecord(assesmentId,null);
            }
            resp.put("retcode", 200);
        }catch (RuntimeException e){
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "DELETE Failed");
            return resp;
        }
        return resp;
    }

    /**
     * 判断考核名称是否已存在
     * @param assesmentName
     * @return
     */
    public HashMap<String, Object> isNameExistis(String assesmentName) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            Integer count=mapper.getByAssesmentName(assesmentName);
            if(count!=null && count>1){
                resp.put("retvalue", "考核名称已存在");
                resp.put("retcode", 300);
            }
            resp.put("retcode", 200);
        }catch (RuntimeException e){
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "DELETE Failed");
            return resp;
        }
        return resp;
    }


    public HashMap<String, Object> getByCourseId(Integer courseId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", mapper.getByCourseId(courseId));
            resp.put("retcode", 200);
        }catch (RuntimeException e){
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "DELETE Failed");
            return resp;
        }
        return resp;
    }
}
