package com.yipin.liuwanr.service;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.Attendance;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.helper.ExcelExportHelper;
import com.yipin.liuwanr.mapper.AttendanceMapper;
import org.springframework.util.StringUtils;

/**
 * 考勤记录
 * @author 或然
 *
 */
@Service
public class AttendanceService {
	
	@Autowired
	private AttendanceMapper mapper;
	
	private static Logger logger = Logger.getLogger(AttendanceService.class);
	
	
	/**
	 * 查询考勤记录
	 * @param studentId
	 * @param courseId
	 * @param pageNo
	 * @param pageSize
	 * @return
	 */
	public HashMap<String, Object> queryAttendanceDetailed(Integer studentId,Integer courseId,Integer pageNo,Integer pageSize){
		  HashMap<String, Object> resp = new HashMap<String, Object>();
		  try {
			  if(!StringUtils.isEmpty(courseId)&&!StringUtils.isEmpty(studentId)){
				PageHelper.startPage(pageNo, pageSize);
				List<Attendance> list = mapper.getByCourseId(studentId,courseId);
				PageInfo<Attendance> info=new PageInfo<Attendance>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
			}
			  resp.put("retcode", 200);
		  } catch (RuntimeException e) {
		   logger.error(e.getMessage());
		   resp.put("retcode", 500);
		   resp.put("retvalue", "Inquiry Failed");
		   return resp;
		  }
		  return resp;
	}
	

	/**
	 * 导出考勤记录
	 * @param response
	 * @param attendance
	 * @return
	 */
	public HashMap<String, Object> exportPractice(HttpServletResponse response,Integer studentId,Integer courseId,String[] titles) {
	    try {
			if(!StringUtils.isEmpty(courseId)&&!StringUtils.isEmpty(studentId)&&titles.length>0){
				String fileName="考勤记录.xls";
				String sheetName="考勤记录";
				List<Attendance> list = mapper.getByCourseId(studentId,courseId);
				HSSFWorkbook bos=ExcelExportHelper.exportAttendance(list, sheetName, titles);
				response.setHeader("content-Type","application/vnd.ms-excel");
				response.setHeader("Content-disposition","attachment;filename="+URLEncoder.encode(fileName,"UTF-8"));
				response.flushBuffer();
				bos.write(response.getOutputStream());
				bos.close();
			}
		} catch (Exception e) {
			logger.error(e.getMessage());
			return null;
		}
		return null;
	}
	
	
	/**
	 * 考勤个人信息展示
	 * @param studentId
	 * @param courseId
	 * @return
	 */
	public HashMap<String, Object> queryAttendance(Integer studentId,Integer courseId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		Attendance attendance=new Attendance();
	    try {
			if(!StringUtils.isEmpty(courseId)&&!StringUtils.isEmpty(studentId)){
			  attendance.setStudentName(mapper.getByStudentName(studentId));
			  List<Integer> projectIds=mapper.queryProjectIds(courseId);
			  attendance.setCount(projectIds.size());
			  List<Attendance> att=mapper.querySigIn(studentId,projectIds);
			  int absence=0;//缺勤次数
			  int signInNumber=0;//签到次数
			  for (Attendance attendance2 : att) {
				  if(attendance2.getSignIn()==0) {
					  signInNumber++;
				  }else if(attendance2.getSignIn()==1) {
					  absence++;
				  }
			  }
			  //设置缺勤次数
			  attendance.setAbsence(absence);
			  //设置考勤次数
			  attendance.setSignInNumber(signInNumber);
			  resp.put("retvalue", attendance);
		  }
			resp.put("retcode", 200);
		} catch (Exception e) {
			 logger.error(e.getMessage());
			 resp.put("retcode", 500);
			 resp.put("retvalue", "Inquiry Failed");
			 return resp;
		}
		return resp;
	}
	
}
