package com.yipin.liuwanr.service;

import java.util.HashMap;
import java.util.List;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.Course;
import com.yipin.liuwanr.entity.CourseLink;
import com.yipin.liuwanr.entity.CoursePermissions;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.ServiceConfig;
import com.yipin.liuwanr.mapper.CoursePermissionsMapper;

@Service
public class CoursePermissionsService {
	
	private static Logger logger = Logger.getLogger(CoursePermissionsService.class);
	
	@Autowired
	private CoursePermissionsMapper coursePermissionsMapper;

	public HashMap<String, Object> addCoursePermissions(CoursePermissions coursePermissions){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.addCoursePermissions(coursePermissions);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseDetails(Integer courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryCourseDetails(courseId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> deleteCourse(Integer courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.deleteCourse(courseId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> updateCourse(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.updateCourse(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseDiscipline(){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryCourseDiscipline());
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseProfessionalClass(Integer disciplineId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryCourseProfessionalClass(disciplineId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseProfessional(Integer professionalClassId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryCourseProfessional(professionalClassId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryAppConfig(ServiceConfig serviceConfig){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryAppConfig(serviceConfig));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryTrainingConfig(Integer courseId,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
			PageHelper.startPage(pageNo, pageSize);
		    List<ServiceConfig> list = coursePermissionsMapper.queryTrainingConfig(courseId);
		    PageInfo<ServiceConfig> info=new PageInfo<ServiceConfig>(list);
		    int total1 = (int) info.getTotal();
		    int totalPages;
		    totalPages = total1 / pageSize;
		    if (total1 % pageSize != 0){
		     totalPages ++;
		    }
		    long total = total1;
		    resp.put("retvalue", new PageResult(total, list,totalPages));
		    resp.put("retcode", 200);
		   }else {
		    List<ServiceConfig> list = coursePermissionsMapper.queryTrainingConfig(courseId);
		    resp.put("retvalue", list);
		    resp.put("retcode", 200);
		   }
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> addTrainingConfig(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.addTrainingConfig(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryLinkDetails(Integer linkId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", coursePermissionsMapper.queryLinkDetails(linkId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> updateLink(CourseLink courseLink){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.updateLink(courseLink);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> deleteTrainingConfig(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.deleteTrainingConfig(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> isShow(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.isShow(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> isShelves(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			coursePermissionsMapper.isShelves(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
}
