package com.yipin.liuwanr.service;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.Course;
import com.yipin.liuwanr.entity.CourseLink;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.ServiceConfig;
import com.yipin.liuwanr.mapper.CourseMapper;

@Service
public class CourseService {
	
	private static Logger logger = Logger.getLogger(CourseService.class);
	
	@Autowired
	private CourseMapper courseMapper;

	//添加课程
	public HashMap<String, Object> addCourse(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");//设置日期格式
	        String creationTime = df.format(new Date());
	        course.setCreationTime(creationTime);
			courseMapper.addCourse(course);
			Integer courseId = course.getCourseId();
			resp.put("retvalue", courseId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	//添加课程实训配置
	public HashMap<String, Object> addCoursePC(List<ServiceConfig> serviceConfigList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.addCoursePC(serviceConfigList);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	//添加项目环节
	public HashMap<String, Object> addCourseLink(List<CourseLink> courseLinkList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.addCourseLink(courseLinkList);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//查询课程
	public HashMap<String, Object> queryCourse(Course course,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<Course> list = courseMapper.queryCourse(course);
				PageInfo<Course> info=new PageInfo<Course>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<Course> list = courseMapper.queryCourse(course);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	//查询课程详情
	public HashMap<String, Object> queryCourseDetails(Integer courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryCourseDetails(courseId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询课程详情失败！");
			return resp;
		}
		return resp;
	}

	//查询课程名称是否存在
	public HashMap<String, Object> queryCourseNameIsExists(String courseName){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryCourseNameIsExists(courseName));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询课程名称失败！");
			return resp;
		}
		return resp;
	}

	//查询课程详情课程权限
	public HashMap<String, Object> queryCourseDetailsTC(Integer courseId,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<ServiceConfig> list = courseMapper.queryCourseDetailsTC(courseId);
				PageInfo<ServiceConfig> info=new PageInfo<ServiceConfig>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<ServiceConfig> list = courseMapper.queryCourseDetailsTC(courseId);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询课程详情课程权限失败！");
			return resp;
		}
		return resp;
	}

	//删除课程
	public HashMap<String, Object> deleteCourse(List<Integer> courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.deleteCourse(courseId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除课程失败！");
			return resp;
		}
		return resp;
	}
	//更新课程
	public HashMap<String, Object> updateCourse(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.updateCourse(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新课程失败！");
			return resp;
		}
		return resp;
	}
	//修改课程实训配置
	public HashMap<String, Object> updateCoursePC(ServiceConfig serviceConfig){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.updateCoursePC(serviceConfig);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新失败");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> deleteCoursePC(Integer courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.deleteCoursePC(courseId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseDiscipline(){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryCourseDiscipline());
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseProfessionalClass(Integer disciplineId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryCourseProfessionalClass(disciplineId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCourseProfessional(Integer professionalClassId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryCourseProfessional(professionalClassId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	//查询应用配置
	public HashMap<String, Object> queryAppConfig(String searchContent,List<Integer> systemId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryAppConfig(searchContent,systemId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			System.out.println(e.getMessage());
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	//查询实训配置
	public HashMap<String, Object> queryTrainingConfig(Integer courseId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryTrainingConfig(courseId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//绑定实训配置
	public HashMap<String, Object> addTrainingConfig(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.addTrainingConfig(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//查询环节详情
	public HashMap<String, Object> queryLinkDetails(CourseLink courseLink){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", courseMapper.queryLinkDetails(courseLink));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//更新环节
	public HashMap<String, Object> updateLink(CourseLink courseLink){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.updateLink(courseLink);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//删除实训配置
	public HashMap<String, Object> deleteTrainingConfig(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.deleteTrainingConfig(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//是否展示项目控制
	public HashMap<String, Object> isShow(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.isShow(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//是否上架课程控制
	public HashMap<String, Object> isShelves(Course course){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			courseMapper.isShelves(course);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	//查询配置
	public HashMap<String, Object> queryConfig(String systemId,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<ServiceConfig> list = courseMapper.queryConfig(systemId);
				PageInfo<ServiceConfig> info=new PageInfo<ServiceConfig>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<ServiceConfig> list = courseMapper.queryConfig(systemId);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	
	public HashMap<String, Object> platformQueryCourse(Integer schoolId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
	    try {
			resp.put("retvalue", courseMapper.getBySchool(schoolId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> getcouese(Integer courseId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
	    try {
			resp.put("retvalue", courseMapper.getcouese(courseId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public int deleteCourseLink(Integer courseId) {
		int i=courseMapper.deleteCourseLink(courseId);
		return i;
	}
}
