package com.yipin.liuwanr.service;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.School;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.Customer;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.UserM;
import com.yipin.liuwanr.mapper.CustomerMapper;

@Service
public class CustomerService {
	
	private static Logger logger = Logger.getLogger(CustomerService.class);
	
	@Autowired
	private CustomerMapper customerMapper;
	//添加客户
	public HashMap<String, Object> addCustomer(Customer customer){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			customerMapper.addCustomer(customer);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "添加客户失败！");
			return resp;
		}
		return resp;
	}
	//客户管理添加用户
	public HashMap<String, Object> addAdmin(UserM userm){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			customerMapper.addAdmin(userm);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "客户管理添加用户失败!");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCustomer(Customer customer,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<Customer> list = customerMapper.queryCustomer(customer);
				PageInfo<Customer> info=new PageInfo<Customer>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
			}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<Customer> list = customerMapper.queryCustomer(customer);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询客户失败！");
			return resp;
		}
		return resp;
	}
	
	public HashMap<String, Object> queryCustomerDetails(Integer customerId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", customerMapper.queryCustomerDetails(customerId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());			
			resp.put("retcode", 500);
			resp.put("retvalue", "查询客户详情失败!");
			return resp;
		}
		return resp;
	}
	//查询客户是否存在
	public HashMap<String, Object> queryCustomerIsExists(Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", customerMapper.queryCustomerIsExists(schoolId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());			
			resp.put("retcode", 500);
			resp.put("retvalue", "查询客户是否存在失败！");
			return resp;
		}
		return resp;
	}
	//删除客户
	public HashMap<String, Object> deleteCustomer(Customer customer){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			customerMapper.deleteCustomer(customer);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除客户失败！");
			return resp;
		}
		return resp;
	}
	//更新客户
	public HashMap<String, Object> updateCustomer(Customer customer){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			customerMapper.updateCustomer(customer);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新客户失败！");
			return resp;
		}
		return resp;
	}
	
	//查询行业类
	public HashMap<String, Object> queryCustomerIndustryClass(){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", customerMapper.queryCustomerIndustryClass());
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());			
			resp.put("retcode", 500);
			resp.put("retvalue", "查询行业类失败！");
			return resp;
		}
		return resp;
	}
	
	//查询行业
	public HashMap<String, Object> queryCustomerIndustry(Integer industryClassId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", customerMapper.queryCustomerIndustry(industryClassId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());			
			resp.put("retcode", 500);
			resp.put("retvalue", "查询行业失败！");
			return resp;
		}
		return resp;
	}

	//查询学校
	public HashMap<String, Object> querySchool(School school){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", customerMapper.querySchool(school));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询学校失败！");
			return resp;
		}
		return resp;
	}
}
