package com.yipin.liuwanr.service;

import java.sql.Timestamp;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;

import org.apache.mina.core.session.IoSession;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.yipin.liuwanr.entity.Relationship;
import com.yipin.liuwanr.helper.CommonDefine;
import com.yipin.liuwanr.mapper.DeviceMapper;
import com.yipin.liuwanr.mapper.PetMapper;
import com.yipin.liuwanr.tcpserver.MinaSessionManager;

@Service
public class DeviceService {

	private static Logger logger = Logger.getLogger(DeviceService.class);

	@Autowired
	PetMapper petMapper;

	@Autowired
	DeviceMapper deviceMapper;

	public HashMap<String, Object> bound(String uuid, String puid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int updatable = petMapper.check(uuid, puid);
			if (updatable == 1) {
				int status = 0;
				List<Relationship> bound = deviceMapper.check(puid, duid);
				for (Relationship m : bound) {
					String p = m.getHid();
					String d = m.getLid();
					logger.info(p + d);
					if (0 == p.compareToIgnoreCase(puid) && 0 == d.compareToIgnoreCase(duid)) {
						status = 1;
						break;
					} else if (0 == p.compareToIgnoreCase(puid) && 0 != d.compareToIgnoreCase(duid)) {
						status = 2;
					} else if (0 != p.compareToIgnoreCase(puid) && 0 == d.compareToIgnoreCase(duid)) {
						status = 3;
						break;
					}
				}
				switch (status) {
				case 0:
					deviceMapper.bundling(puid, duid);
					ret.put("retcode", 200);
					ret.put("retvalue", deviceMapper.getById(duid));
					break;
				case 1:
					ret.put("retcode", 300);
					ret.put("retvalue", "Already Bound");
					break;
				case 2:
					deviceMapper.change(puid, duid);
					ret.put("retcode", 200);
					ret.put("retvalue", "Device Changed");
					break;
				case 3:
					ret.put("retcode", 400);
					ret.put("retvalue", "Device Inuse");
				default:
					break;
				}
			} else {
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Bundling Failed");
		}
		return ret;
	}

	public HashMap<String, Object> unbundling(String uuid, String puid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int updatable = petMapper.check(uuid, puid);
			if (updatable == 1) {
				boolean status = false;
				List<Relationship> bound = deviceMapper.check(puid, duid);
				for (Relationship m : bound) {
					String p = m.getHid();
					String d = m.getLid();
					if (0 == p.compareToIgnoreCase(puid) && 0 == d.compareToIgnoreCase(duid)) {
						status = true;
						break;
					} 
				}
				if (status) {
					deviceMapper.unbundling(puid, duid);
					ret.put("retcode", 200);
					ret.put("retvalue", "Operation Done");
				}
				else {
					ret.put("retcode", 400);
					ret.put("retvalue", "Device Ownership Check Failed");
				}
				
			} else {
				ret.put("retcode", 400);
				ret.put("retvalue", "Pet Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Unbound Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> detail(String uuid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				ret.put("retcode", 200);
				ret.put("retvalue", deviceMapper.getById(duid));
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "query Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> status(String uuid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				ret.put("retcode", 200);
				ret.put("retvalue", "nothing");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "search Failed");
		}
		return ret;
	}

	public HashMap<String, Object> refresh(String uuid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				ret.put("retcode", 200);
				MinaSessionManager.getSessionByDevice(duid).write(CommonDefine.TCP_SENT_REFRESH_DATA);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "refresh Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> health(String uuid, String duid, String period) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				if(7 == period.length()){
					Calendar cal = Calendar.getInstance(); 
					cal.set(Calendar.YEAR, Integer.parseInt(period.substring(0, 4))); 
					cal.set(Calendar.MONTH, Integer.parseInt(period.substring(5)));
					int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);  
					cal.set(Calendar.DAY_OF_MONTH, lastDay);  
					SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
					String lastDayOfMonth = sdf.format(cal.getTime());
					ret.put("retcode", 200);
					ret.put("retvalue", deviceMapper.getActionByDay(duid, period + "-01 00:00:00",  lastDayOfMonth + "23:59:59"));
				}
				else if(10 == period.length()){
					ret.put("retcode", 200);
					ret.put("retvalue", deviceMapper.getActionByDay(duid, period + " 00:00:00",  period + " 23:59:59"));
				}
				else{
					ret.put("retcode", 300);
					ret.put("retvalue", "Period Invalid");
				}
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Analyze Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> track(String uuid, String duid, long from, long to) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				DateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
				ret.put("retcode", 200);
				ret.put("retvalue", deviceMapper.track(duid, sdf.format(new Timestamp(from)), sdf.format(new Timestamp(to))));
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Query Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> snapshot(String uuid, String duid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int able = deviceMapper.checkDevice(uuid, duid);
			if(able == 1){
				ret.put("retcode", 200);
				IoSession is = MinaSessionManager.getSessionByDevice(duid);
				if(null != is){
					String imgname = duid+"_"+System.currentTimeMillis()+".jpg";
					ret.put("retvalue", imgname);
					is.write(CommonDefine.TCP_SENT_SNAPSHOT + "|" + imgname);
				}
				else{
					ret.put("retcode", 404);
					ret.put("retvalue", "Device Offline");
				}
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Device Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Snapshot Failed");
		}
		return ret;
	}
}
