package com.yipin.liuwanr.service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.*;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.yipin.liuwanr.mapper.ExperimentallearningMapper;
import com.yipin.liuwanr.mapper.TeacherProjectAndCourseMapper;
import org.springframework.util.StringUtils;

/**
 * 学生端_实验学习
 * 
 * @author 86151
 *
 */
@Service
public class ExperimentallearningService {

	private static Logger logger = Logger.getLogger(ExperimentallearningService.class);

	@Autowired
	private ExperimentallearningMapper mapper;
	@Autowired
	private TeacherProjectAndCourseMapper mapper2;

	/**
	 * 获取项目信息
	 * 
	 * @param studentId
	 * @param courseId
	 * @return
	 */
	public HashMap<String, Object> queryProject(Integer studentId, Integer courseId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(!StringUtils.isEmpty(courseId)&&!StringUtils.isEmpty(studentId)){
				Integer experimentalClassId=mapper.queryExperimentalClassId(courseId,studentId);
				if(!StringUtils.isEmpty(experimentalClassId)){
					List<Integer> projectIds = mapper.queryIsAttendance(studentId, courseId);
					List<Project_Management> projects = mapper.getBycourseId(experimentalClassId,courseId);
					for (int i = 0; i < projects.size(); i++) {
						Project_Management project = projects.get(i);
						// 教师那边开启了考勤，学生这边才可以有是否已经签到
						if (project.getIsAttendance() == 1) {
							// 判断该学生签到的项目，是否在开启的项目中
							if (projectIds.contains(project.getProjectId())) {
								project.setSignin(0);
							} else {
								project.setSignin(1);
							}
							projects.set(i, project);
						}
					}
					resp.put("retvalue", projects);
				}
			}
			resp.put("retcode", 200);
	}catch(Exception e){
		logger.error(e.getMessage());
		resp.put("retcode", 500);
		resp.put("retvalue", "实验项目查询失败");
		return resp;
	}return resp;
	}

	/**
	 * 学生签到
	 */
	public HashMap<String, Object> insertAttendance(Attendance attendance) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			Attendance attendance2 = mapper.getByProjectIdAndStudentId(attendance);
			Integer courseId = attendance.getCourseId();
			Integer studentId = attendance.getStudentId();
			Integer experimentalClassId=mapper.queryExperimentalClassId(courseId,studentId);
			attendance.setExperimentalClassId(experimentalClassId);
			if (null != attendance2 && attendance2.getSignIn() == 1) {
				// 修改考勤状态
				attendance2.setSignIn(attendance.getSignIn());
				mapper.updateAttendance(attendance2);
			} else {
				mapper.insertAttendance(attendance);
			}
			resp.put("retcode", 200);
		} catch (Exception e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "考勤签到失败");
			return resp;
		}
		return resp;
	}

	/**
	 * 学生信息展示
	 */
	public HashMap<String, Object> queryStudentName(Integer courseId,Integer studentId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(!StringUtils.isEmpty(courseId)){
				//实验班级
				Integer experimentalClassId=mapper.queryExperimentalClassId(courseId,studentId);
				if(!StringUtils.isEmpty(experimentalClassId)){
					//学生信息
					List<UserM> users =mapper.queryStudentName(experimentalClassId);
					resp.put("retvalue", users);
				}
			}
			resp.put("retcode", 200);
		} catch (Exception e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	/**
	 * 授课老师
	 */
	public HashMap<String, Object> queryTeacherName(Integer courseId,Integer studentId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(!StringUtils.isEmpty(courseId)){
				//实验班级
				Integer experimentalClassId=mapper.queryExperimentalClassId(courseId,studentId);
				if(!StringUtils.isEmpty(experimentalClassId)){
					//教师信息
					UserM user =mapper.queryTeacherName(experimentalClassId);
					resp.put("retvalue",user);
				}
			}
			resp.put("retcode", 200);
		} catch (Exception e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	/**
	 * 进入考核
	 */
	public HashMap<String, Object> queryAssesment(Integer courseId, Integer studentId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> val = new HashMap<String, Object>();
		try {
			List<Assesment> assesments=new ArrayList<>();
			if(!StringUtils.isEmpty(courseId)) {
				assesments = mapper.queryAssesment(courseId);
			}
			// 查询出来该课程有多个考核开启，则不符合逻辑(一门课程一次只能开启一个考核，不能有多个)
			if(!assesments.isEmpty()&&assesments.size()>0){
				if (assesments.size() > 1) {
					resp.put("retcode", 300);
					resp.put("retvalue", "同一课程只能开启一个考核");
					return resp;
				} else {
						Assesment assesment = assesments.get(0);
						Integer assesmentId = assesment.getId();
						// 查询该考核的学生
						List<Integer> studentIds = mapper.queryStudentId(assesmentId);
						if (studentIds.contains(studentId)) {
							val.put("courseId", courseId);
							val.put("studentId", studentId);
							val.put("projectId", assesment.getExperimentId());
							val.put("assesmentId", assesmentId);
						}
				}
				resp.put("retvalue", val);
			}
			resp.put("retcode", 200);
		} catch (Exception e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询考核信息失败");
			return resp;
		}
		return resp;
	}


	public HashMap<String, Object> queryStudentCourse(Integer studentId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try{
			resp.put("retvalue",mapper.queryStudentCourse(studentId));
			resp.put("retcode",200);
		}catch(Exception e){
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询课程信息失败");
		}
			return resp;
	}

}
