package com.yipin.liuwanr.service;

import java.util.HashMap;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.yipin.liuwanr.entity.Group;
import com.yipin.liuwanr.mapper.GroupMapper;

@Service
public class GroupService {

	private static Logger logger = Logger.getLogger(GroupService.class);

	@Autowired
	GroupMapper groupMapper;

	public HashMap<String, Object> create(Group group) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			groupMapper.create(group);
			ret.put("retcode", 200);
			ret.put("retvalue", group);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Create Failed");
		}
		return ret;
	}

	public HashMap<String, Object> update( Group group) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			groupMapper.update(group);
			ret.put("retcode", 200);
			ret.put("retvalue", group);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Update Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> detail(long guid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retcode", 200);
			ret.put("retvalue", groupMapper.getById(guid));
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Query Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> addMember(String uuid, long guid, String buuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if(0 < groupMapper.check(uuid, guid)){
				groupMapper.addmember(guid, buuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Insert Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> deleteMember(String uuid, long guid, String buuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if(0 < groupMapper.check(uuid, guid)){
				groupMapper.removemember(guid, buuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> blockUser(String uuid, long guid, String buuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if(0 < groupMapper.check(uuid, guid)){
				groupMapper.removemember(guid, buuid);
				groupMapper.blockuser(guid, buuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Insert Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> unblockUser(String uuid, long guid, String buuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if(0 < groupMapper.check(uuid, guid)){
				groupMapper.unblockuser(guid, buuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> delete(String uuid, long guid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if(0 < groupMapper.check(uuid, guid)){
				groupMapper.delete(guid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> around(String uuid, double longitude, double latitude) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retvalue", groupMapper.getByLocation(uuid, longitude+0.05, longitude-0.05, latitude+0.05, latitude-0.05));
			ret.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Search Failed");
		}
		return ret;
	}
}
