package com.yipin.liuwanr.service;

import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.Student;
import com.yipin.liuwanr.helper.AssesmentHelper;
import com.yipin.liuwanr.vo.MakeupStudentsVo;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.yipin.liuwanr.entity.Makeuplist;
import com.yipin.liuwanr.helper.ExcelImportHelper;
import com.yipin.liuwanr.mapper.MakeuplistMapper;

/**
 *
 * 
 * @author 全承珠
 *
 */
@Service
public class MakeuplistService {

	private static Logger logger = Logger.getLogger(UserService.class);

	@Autowired
	private MakeuplistMapper makeuplistMapper;

	
	/**
	 * 查询数据
	 * @param staffId
	 * @return
	 */
	public HashMap<String, Object> queryAllMakeuplist(Integer staffId,long uploadTime,Integer uploadType,Integer schoolId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		String time= AssesmentHelper.longPointDate(uploadTime);
		try {
			if(uploadType.equals(0)){
				List<Makeuplist> makeuplists=makeuplistMapper.queryExperimentalClassMakeuplist(staffId,time,schoolId);
				resp.put("retvalue", makeuplists);
			}else if(uploadType.equals(1)){
				List<Makeuplist> makeuplists=makeuplistMapper.queryClassMakeuplist(staffId,time,schoolId);
				resp.put("retvalue", makeuplists);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> getStudent(Integer staffId,long uploadTime,Integer uploadType,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		String time= AssesmentHelper.longPointDate(uploadTime);
		try{
			resp.put("retvalue",makeuplistMapper.getstudent(staffId,time,schoolId,uploadType));
			resp.put("retcode", 200);
		}catch (RuntimeException e){
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return  resp;
	}

	public HashMap<String, Object> getByMakeuplist(Integer staffId,long uploadTime,Integer uploadType,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		String time= AssesmentHelper.longPointDate(uploadTime);
		try{
			if(uploadType.equals(0)){
				List<Makeuplist> makeuplists=makeuplistMapper.queryExperimentalClassMakeuplist(staffId,time,schoolId);
				resp.put("retvalue", makeuplists);
			}else if(uploadType.equals(1)){
				List<Makeuplist> makeuplists=makeuplistMapper.queryClassMakeuplist(staffId,time,schoolId);
				resp.put("retvalue", makeuplists);
			}
			resp.put("retcode", 200);
		}catch(RuntimeException e){
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}


	/**
	 * 导入数据
	 * @param file
	 * @param staffId
	 * @return
	 */
	@Transactional
	public HashMap<String, Object> addMakeuplist( MultipartFile file,Integer schoolId,Integer staffId,long uploadTime) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		MakeupStudentsVo vo=new MakeupStudentsVo();
		String time= AssesmentHelper.longPointDate(uploadTime);
		try {
			//补考学生信息
			HashMap<String,Object> obj= ExcelImportHelper.readExcel(file);
			if(obj!=null){
				Integer uploadType=(Integer) obj.get("uploadType");
				List<Makeuplist> makeuplists=(List<Makeuplist>)obj.get("makeuplists");
				if(!makeuplists.isEmpty()&&makeuplists.size()>0){
					if(uploadType!=null){
						if(uploadType.equals(0)){
							addMakeuplist(makeuplists,schoolId,staffId,uploadType,time);
						}else if(uploadType.equals(1)){
							addMakeuplist(makeuplists,schoolId,staffId,uploadType,time);
						}
						resp.put("retcode", 200);
						vo.setUploadType(uploadType);
						resp.put("retvalue", vo);
					}else{
						resp.put("retcode", 300);
						resp.put("retvalue", "文件模板错误");
					}
				}else{
					resp.put("retcode", 300);
					resp.put("retvalue", "导入文件失败");
				}
			}else{
				resp.put("retcode", 300);
				resp.put("retvalue", "导入文件失败");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "文件格式有误");
			throw new RuntimeException();
		}
		return resp;
	}

	private void addMakeuplist(List<Makeuplist> makeuplists,Integer schoolId,Integer staffId,Integer uploadType,String time){
		Student student=null;
		MakeupStudentsVo vo=null;
		for (int i=0;i<makeuplists.size();i++){
			Makeuplist makeuplist=makeuplists.get(i);
			vo=new MakeupStudentsVo();
			String studentNumber=makeuplist.getStudentNumber();//学号
			if(uploadType.equals(0)){
				String experimentalClassName=makeuplist.getClassName();
				student=makeuplistMapper.queryExperimentalClassStudent(experimentalClassName,schoolId,studentNumber);
				if(student!=null){
					vo.setExperimentalClassId(student.getIntExperimentalClassId());//实验班级id
					vo.setStudentId(student.getStudentId());//学生id
					vo.setStudentNumber(studentNumber);

				}else{
					throw  new RuntimeException("该学生不存在");
				}
			}else if(uploadType.equals(1)){
				student =makeuplistMapper.queryClassStudent(studentNumber,schoolId);
				if(student!=null){
					vo.setClassId(student.getClassId());//行政班级id
					vo.setStudentId(student.getStudentId());//学生id
					vo.setStudentNumber(studentNumber);
				}else{
					throw  new RuntimeException("该学生不存在");
				}
			}
			vo.setStaffId(staffId);
			vo.setSchoolId(schoolId);
			vo.setUploadType(uploadType);
			vo.setTime(time);
			if(student!=null){
				makeuplistMapper.addMakeuplist(vo);
			}
		}
	}

}