package com.yipin.liuwanr.service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.mapper.OrderMapper;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

@Service
public class OrderService {

    private static Logger logger = Logger.getLogger(OrderService.class);

    @Autowired
    private OrderMapper orderMapper;

    //添加合同信息
    public HashMap<String, Object> addOrder(Order order) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            long timeStamp = new Date().getTime();//获取时间戳
            String orderNumber = String.valueOf(timeStamp);//long转String
            order.setOrderNumber(orderNumber);
            orderMapper.addOrder(order);
            resp.put("orderId", order.getOrderId());
            resp.put("retcode", 200);
            orderMapper.updateOrderCustomer(order);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "添加订单失败！");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> addContractInformation(ContractInformation contractInformation) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.addContractInformation(contractInformation);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "添加信息合同失败！");
            return resp;
        }
        return resp;
    }

    //添加课程权限
    public HashMap<String, Object> addCoursePermissionss(List<CoursePermissions> coursePermissionss) throws ParseException {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            Integer size = coursePermissionss.size();
            for (int i = 0; i < size; i++) {
                CoursePermissions coursePermissionssList = coursePermissionss.get(i);
                Integer usePeriod = coursePermissionssList.getUsePeriod();
                Integer usePeriod1 = usePeriod * 1000 * (60 * 60 * 24);
                long DQSJC = System.currentTimeMillis();
                long expireSJC = usePeriod1 + DQSJC;
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                long lt = new Long(expireSJC);
                Date date = new Date(lt);
                String time = simpleDateFormat.format(date);
                coursePermissionss.get(i).setExpirationTime(time);
            }
            orderMapper.addCoursePermissionss(coursePermissionss);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "添加课程权限失败！");
            return resp;
        }
        return resp;
    }

    //绑定应用权限
    public HashMap<String, Object> bindingApplicationPermissions(ApplicationPermissions applicationPermissions) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.bindingApplicationPermissions(applicationPermissions);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryCoursePermissions(String courseId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            List<Course> list = orderMapper.queryCoursePermissions(courseId);
            resp.put("retvalue", list);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryOrder(Order order, Integer pageNo, Integer pageSize) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (pageNo != null && pageSize != null) {
                PageHelper.startPage(pageNo, pageSize);
                List<Order> list = orderMapper.queryOrder(order);
                PageInfo<Order> info = new PageInfo<Order>(list);
                int total1 = (int) info.getTotal();
                int totalPages;
                totalPages = total1 / pageSize;
                if (total1 % pageSize != 0) {
                    totalPages++;
                }
                long total = total1;
                resp.put("retvalue", new PageResult(total, list, totalPages));
                resp.put("retcode", 200);
            } else {
                List<Order> list = orderMapper.queryOrder(order);
                resp.put("retvalue", list);
                resp.put("retcode", 200);
            }
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryOrderDetails(Integer orderId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", orderMapper.queryOrderDetails(orderId));
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> deleteOrder(List<Integer> orderId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.deleteOrder(orderId);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> updateOrder(Order order) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.updateOrder(order);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> deleteCoursePermissions(Integer orderId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.deleteCoursePermissions(orderId);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> updateCoursePermissions(List<CoursePermissions> coursePermissionss) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        int size = coursePermissionss.size();
        if (coursePermissionss.isEmpty()) {
            resp.put("retcode", 200);
        } else {
            try {
                for (int i = 0; i < size; i++) {
                    CoursePermissions coursePermissions = coursePermissionss.get(i);
                    orderMapper.updateCoursePermissions(coursePermissions);
                }
                resp.put("retcode", 200);
            } catch (RuntimeException e) {
                logger.error(e.getMessage());
                resp.put("retcode", 500);
                resp.put("retvalue", "Inquiry Failed");
                return resp;
            }
        }
        return resp;
    }

    public HashMap<String, Object> updateContractInformation(ContractInformation contractInformation) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.updateContractInformation(contractInformation);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    //绑定应用权限
    public HashMap<String, Object> isDeliverGoods(CoursePermissions coursePermissions) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            orderMapper.isDeliverGoods(coursePermissions);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryOrderCustomer(Integer cityId, Integer provinceId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", orderMapper.queryOrderCustomer(cityId, provinceId));
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryOrderCustomerContact(Integer customerId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", orderMapper.queryOrderCustomerContact(customerId));
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    //查询订单课程列表
    public HashMap<String, Object> queryCourseList(String searchContent, List<Integer> courseId, Integer pageNo, Integer pageSize) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (pageNo != null && pageSize != null) {
                PageHelper.startPage(pageNo, pageSize);
                List<Course> list = orderMapper.queryCourseList(searchContent, courseId);
                PageInfo<Course> info = new PageInfo<Course>(list);
                int total1 = (int) info.getTotal();
                int totalPages;
                totalPages = total1 / pageSize;
                if (total1 % pageSize != 0) {
                    totalPages++;
                }
                long total = total1;
                resp.put("retvalue", new PageResult(total, list, totalPages));
                resp.put("retcode", 200);
            } else {
                List<Course> list = orderMapper.queryCourseList(searchContent, courseId);
                resp.put("retvalue", list);
                resp.put("retcode", 200);
            }
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public List<Integer> selectByOrderId(int orderId) {
        List<Integer> list = orderMapper.selectByOrderId(orderId);
        return list;
    }

    public int updateOrderStatus(int orderId,int orderStatus) {
        int i = orderMapper.updateOrderStatus(orderId,orderStatus);
        return i;
    }
}
