package com.yipin.liuwanr.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.yipin.liuwanr.entity.Breed;
import com.yipin.liuwanr.entity.Pet;
import com.yipin.liuwanr.entity.Position;
import com.yipin.liuwanr.entity.UploadInfo;
import com.yipin.liuwanr.helper.CommonDefine;
import com.yipin.liuwanr.helper.PushHelper;
import com.yipin.liuwanr.helper.RandomUtil;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.mapper.PetMapper;
import com.yipin.liuwanr.tcpserver.MinaSessionManager;

@Service
public class PetService {
	
	private static Logger logger = Logger.getLogger(PetService.class);
	
	@Autowired
	PetMapper petMapper;
	
	@Autowired
	RedisHelper redisHelper;

	public HashMap<String, Object> create(String uuid, Pet pet) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			pet.setPuid(RandomUtil.getUUID());
			petMapper.insert(pet);
			petMapper.boundUser(uuid, pet.getPuid());
			ret.put("retcode", 200);
			ret.put("retvalue", pet);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Create Failed");
		}
		return ret;
	}

	public HashMap<String, Object> update(String uuid, Pet pet) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int updatable = petMapper.check(uuid, pet.getPuid());
			if(0 < updatable){
				petMapper.update(pet);
				ret.put("retcode", 200);
				ret.put("retvalue", pet);
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Update Failed");
		}
		return ret;
	}

	public HashMap<String, Object> delete(String uuid, String puid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			int updatable = petMapper.check(uuid, puid);
			if(0 < updatable){
				petMapper.delete(puid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	


	public HashMap<String, Object> getOne(String uuid, String puid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			Pet pet = petMapper.check(uuid, puid)>0?petMapper.getOneSelf(puid):petMapper.getOneOther(puid);
			if(pet != null){
				ret.put("retcode", 200);
				ret.put("retvalue", pet);
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Pet not Found");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Inquery Failed");
		}
		return ret;
	}

	public HashMap<String, Object> getMyPets(String uuid) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		try {
			List<Pet> pets = petMapper.getAll(uuid);
			if(null == pets){
				result.put("retcode", 400);
				result.put("retvalue", "No Pet Found");
			}
			else{
				result.put("retcode", 200);
				result.put("retvalue", pets);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			result.put("retcode", 500);
			result.put("retvalue", "Inquiry Failed");
			return result;
		}
		return result;
	}
	
	public HashMap<String, Object> whereisMyPets(String uuid) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		List<Position> mypet = new ArrayList<Position>();
		try {
			List<Pet> petlist = petMapper.getAll(uuid);
			if(null == petlist){
				result.put("retcode", 400);
				result.put("retvalue", "No Pet Found");
			}
			else{
				if(redisHelper == null){
					logger.error("no redis helper");
				}
				for(Pet pet : petlist){
					if( null != pet.getDevice()){
						String duid = pet.getDevice().getDuid();
						UploadInfo lastinfo = redisHelper.getLastUploadInfoById(duid);
						if(lastinfo != null){
							Position pos = new Position(lastinfo.getLongitude(), lastinfo.getLatitude());
							pos.setPuid(pet.getPuid());
							pos.setDuid(duid);
							pos.setOnline(MinaSessionManager.isDeviceOnline(duid));
							mypet.add(pos);
						}
					}
				}
				result.put("retcode", 200);
				result.put("retvalue", mypet);
			}
		} catch (RuntimeException e) {
			logger.error(e.getCause());
			result.put("retcode", 500);
			result.put("retvalue", "Inquiry Failed");
			return result;
		}
		return result;
	}

	public HashMap<String, Object> getNearByPets(double longitude, double latitude) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		List<HashMap<String, Object>> aroundpet = new ArrayList<HashMap<String, Object>>();
		try {
			List<Pet> petlist = petMapper.listAround();
			if(null == petlist){
				result.put("retcode", 400);
				result.put("retvalue", "No Pet Found");
			}
			else{
				for(Pet pet : petlist){
					HashMap<String, Double> latlon = RandomUtil.randomLonLat(longitude-0.05,longitude+0.05,latitude-0.05, latitude+0.05);
					HashMap<String, Object> singlepet = new HashMap<String, Object>();
					singlepet.put("puid", pet.getPuid());
					singlepet.put("uuid", pet.getUuid());
					singlepet.putAll(latlon);
					aroundpet.add(singlepet);
				}
				result.put("retcode", 200);
				result.put("retvalue", aroundpet);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			result.put("retcode", 500);
			result.put("retvalue", "Inquiry Failed");
			return result;
		}
		return result;
	}

	public HashMap<String, Object> getBreedsByCategory(int category) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		try {
			List<Breed> breeds = petMapper.getBreeds(category);
			result.put("retcode", 200);
			result.put("retvalue", breeds);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			result.put("retcode", 500);
			result.put("retvalue", "Get Config Failed");
			return result;
		}
		return result;
	}

	public HashMap<String, Object> sayHelloToPet(String uuid, String touuid, String puid, int type, String message) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			petMapper.greet(uuid, puid, type, message);
			JSONObject attach = new JSONObject();
			attach.put("message", message);
			if(PushHelper.sendMessage(touuid, CommonDefine.NOFITY_USER, attach.toJSONString())){
				resp.put("retcode", 200);
				resp.put("retvalue", "Operation Done");
			}
			else{
				resp.put("retcode", 503);
				resp.put("retvalue", "Message Lost");
			}
			
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Operation Failed");
			return resp;
		}
		return resp;
	}



}
