package com.yipin.liuwanr.service;

import java.net.URLEncoder;
import java.util.HashMap;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.vo.UserVO;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.helper.ExcelExportHelper;
import com.yipin.liuwanr.mapper.AssesmentMapper;
import com.yipin.liuwanr.mapper.RecordMapper;
import com.yipin.liuwanr.vo.PracticeRecordVo;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 练习记录
 *
 * @author 或然
 */
@Service
public class PracticeService {


    private static Logger logger = Logger.getLogger(PracticeService.class);

    @Autowired
    private RecordMapper mapper;

    @Autowired
    private AssesmentMapper assesment;


    /**
     * 练习记录 And 考核记录
     *
     * @param studentId
     * @param projectPermissions
     * @param pageNum
     * @param pageSize
     * @return
     */
    public HashMap<String, Object> queryStudentByPage(Integer studentId, Integer projectPermissions, Integer courseId, Integer pageNum, Integer pageSize) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (!StringUtils.isEmpty(courseId) && !StringUtils.isEmpty(studentId) && projectPermissions != null) {
                PageHelper.startPage(pageNum, pageSize);
                List<Record> records = mapper.getByStudentId(projectPermissions, courseId, studentId);
                PageInfo<Record> info = new PageInfo<Record>(records);
                int total1 = (int) info.getTotal();
                int totalPages;
                totalPages = total1 / pageSize;
                if (total1 % pageSize != 0) {
                    totalPages++;
                }
                long total = total1;
                resp.put("retvalue", new PageResult(total, records, totalPages));
            }
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    /**
     * 练习记录 and 考核记录导出
     *
     * @param response
     * @param studentId：学生id
     * @param projectPermissions：权限(练习、考核)
     * @param titles(标题)
     * @return
     */
    public HashMap<String, Object> exportPractice(HttpServletResponse response, Integer studentId, Integer projectPermissions, Integer courseId, String[] titles) {
        String fileName = null;
        String sheetName = null;
        List<Record> records = null;
        try {
            if (!StringUtils.isEmpty(courseId) && !StringUtils.isEmpty(studentId)) {
                records = mapper.getByStudentId(projectPermissions, courseId, studentId);
            }
            if (records.size() > 0 && !records.isEmpty()) {
                if (projectPermissions == 0) {
                    fileName = "练习记录.xls";
                    sheetName = "练习记录";
                } else if (projectPermissions == 1) {
                    fileName = "考核记录.xls";
                    sheetName = "考核记录";
                }
                HSSFWorkbook bos = ExcelExportHelper.exportPractice(records, sheetName, titles);

                response.setHeader("content-Type", "application/vnd.ms-excel");
                response.setHeader("Content-disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
                response.flushBuffer();
                bos.write(response.getOutputStream());
                bos.close();
            }
        } catch (Exception e) {
            logger.error(e.getMessage());
            return null;
        }
        return null;
    }


    /**
     * 练习信息
     *
     * @param studentId
     * @return
     */
    public HashMap<String, Object> queryPracticeVo(Integer studentId, Integer courseId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (!StringUtils.isEmpty(courseId) && !StringUtils.isEmpty(studentId)) {
                // 学生个人的练习信息
                PracticeRecordVo practiceVo = mapper.getByPracticeVO(studentId, courseId);
                // 练习项目数量
                Integer practiceNumber = mapper.queryPracticeNumber(courseId);
                if (practiceNumber != null) {
                    practiceVo.setPracticeNumber(practiceNumber);

                    // 求完成项目数量
                    Integer accomplishNumber = mapper.queryAccomplishNumber(studentId, courseId);
                    if (accomplishNumber != null) {
                        practiceVo.setAccomplishNumber(accomplishNumber);
                    }
                } else {
                    practiceVo.setPracticeNumber(0);
                    practiceVo.setAccomplishNumber(0);
                }
                // 练习总次数
                Integer sumNumber = mapper.querySumNumber(studentId, courseId);
                if (sumNumber != null) {
                    practiceVo.setSumNumber(sumNumber);
                } else {
                    practiceVo.setSumNumber(0);
                }
                PracticeRecordVo vo = mapper.queryCountry(courseId);
                if (vo != null) {
                    //全国实训积分平均分
                    practiceVo.setAvgintegral(vo.getAvgintegral());
                    //全国最高实训积分
                    practiceVo.setHeightintegral(vo.getHeightintegral());
                } else {
                    //全国实训积分平均分
                    practiceVo.setAvgintegral(0);
                    //全国最高实训积分
                    practiceVo.setHeightintegral(0);
                }
                resp.put("retvalue", practiceVo);
            }
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryAllExperiment(Integer courseId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (!StringUtils.isEmpty(courseId)) {
                resp.put("retvalue", assesment.queryGetByAssesmentProject(courseId));
            }
            resp.put("retcode", 200);
        } catch (Exception e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }
}
