package com.yipin.liuwanr.service;

import java.util.HashMap;
import java.util.List;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.CourseSchedule;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.mapper.ExperimentallearningMapper;
import com.yipin.liuwanr.vo.CourseAndProjectVo;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.yipin.liuwanr.entity.Project_Management;
import com.yipin.liuwanr.mapper.TeacherProjectAndCourseMapper;
import org.springframework.util.StringUtils;

/**
 * 
 * @author 或然
 *
 */
@Service
public class ProjectAndCourseService {

	private static Logger logger=Logger.getLogger(ProjectAndCourseService.class);

	@Autowired
	private TeacherProjectAndCourseMapper mapper;
	@Autowired
	private ExperimentallearningMapper experimentallearningMapper;
	
	/**
	 * 根据课程查询实验项目信息
	 * @param courseId
	 * @return
	 */
	public HashMap<String, Object> queryProject(Integer courseId,Integer experimentalClassId,Integer pageNo,Integer pageSize) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			PageHelper.startPage(pageNo, pageSize);
			List<Project_Management> project=mapper.getBySystemId(courseId,experimentalClassId);
			PageInfo<Project_Management> info=new PageInfo<Project_Management>(project);
			int total1 = (int) info.getTotal();
			int totalPages;
			totalPages = total1 / pageSize;
			if (total1 % pageSize != 0){
				totalPages ++;
			}
			long total = total1;
			resp.put("retcode", 200);
			resp.put("retvalue", new PageResult(total,project,totalPages));
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
	
	/**
	 * 修改项目状态
	 */
	public HashMap<String, Object> updateIsExperiment(CourseAndProjectVo vo) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			mapper.updateIsExperiment(vo);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改项目实验失败");
			return resp;
		}
		return resp;
	}
	
	/**
	 * 修改考勤状态
	 */
	public HashMap<String, Object> updateIsAttendance(CourseAndProjectVo vo) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			mapper.updateIsAttendance(vo);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Update Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> getCourseSchedule(Integer courseId,Integer experimentalClassId,Integer studentId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Integer> obj = new HashMap<String, Integer>();
		try {
			if(!StringUtils.isEmpty(courseId)){
				if(StringUtils.isEmpty(experimentalClassId)){
					if(!StringUtils.isEmpty(studentId)){
						experimentalClassId=experimentallearningMapper.queryExperimentalClassId(courseId,studentId);
					}
				}
				if(!StringUtils.isEmpty(experimentalClassId)){
					//完成的课程项目
					Integer number=mapper.getCourseSchedule(courseId);
					//总项目数量
					List<Project_Management> project=mapper.getBySystemId(courseId,experimentalClassId);
					obj.put("total",project.size());
					if(number!=null){
						obj.put("number",number);
					}else{
						obj.put("number",0);
					}
				}

			}
			resp.put("retcode", 200);
			resp.put("retvalue",obj);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询失败");
			return resp;
		}
		return resp;
	}

	//添加课程进度
	public HashMap<String, Object> addCourseSchedule(CourseSchedule courseSchedule){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			mapper.addCourseSchedule(courseSchedule);
			resp.put("retcode", 200);
		}catch (Exception e){
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询失败");
			return resp;
		}
		return resp;
	}


	//课程视频
	public HashMap<String, Object> getCoursevideo(Integer courseId,Integer experimentalClassId,Integer studentId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(!StringUtils.isEmpty(courseId)){
				if(StringUtils.isEmpty(experimentalClassId)){
					if(!StringUtils.isEmpty(studentId)){
						experimentalClassId=experimentallearningMapper.queryExperimentalClassId(courseId,studentId);
					}
				}
				List<Project_Management> project=mapper.queryProjects(courseId,experimentalClassId);
				resp.put("retvalue", project);
				resp.put("retcode", 200);
			}
		}catch (Exception e){
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "视频失败");
			return resp;
		}
		return resp;
	}

}
