package com.yipin.liuwanr.service;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.ServiceConfig;
import com.yipin.liuwanr.mapper.ServiceConfigMapper;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

@Service
public class ServiceConfigService {

    private static Logger logger = Logger.getLogger(ServiceConfigService.class);

    @Autowired
    private ServiceConfigMapper serviceConfigMapper;

    public HashMap<String, Object> addServiceConfig(ServiceConfig serviceConfig) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            serviceConfigMapper.addServiceConfig(serviceConfig);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryServiceConfig(ServiceConfig serviceConfig, Integer pageNo, Integer pageSize) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            if (pageNo != null && pageSize != null) {
                PageHelper.startPage(pageNo, pageSize);
                List<ServiceConfig> list = serviceConfigMapper.queryServiceConfig(serviceConfig);
                PageInfo<ServiceConfig> info = new PageInfo<ServiceConfig>(list);
                int total1 = (int) info.getTotal();
                int totalPages;
                totalPages = total1 / pageSize;
                if (total1 % pageSize != 0) {
                    totalPages++;
                }
                long total = total1;
                resp.put("retvalue", new PageResult(total, list, totalPages));
                resp.put("retcode", 200);
            } else {
                List<ServiceConfig> list = serviceConfigMapper.queryServiceConfig(serviceConfig);
                resp.put("retvalue", list);
                resp.put("retcode", 200);
            }
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> queryServiceConfigDetails(Integer systemId) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            resp.put("retvalue", serviceConfigMapper.queryServiceConfigDetails(systemId));
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> deleteServiceConfig(ServiceConfig serviceConfig) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            serviceConfigMapper.deleteServiceConfig(serviceConfig);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

    public HashMap<String, Object> updateServiceConfig(ServiceConfig serviceConfig) {
        HashMap<String, Object> resp = new HashMap<String, Object>();
        try {
            serviceConfigMapper.updateServiceConfig(serviceConfig);
            resp.put("retcode", 200);
        } catch (RuntimeException e) {
            logger.error(e.getMessage());
            resp.put("retcode", 500);
            resp.put("retvalue", "Inquiry Failed");
            return resp;
        }
        return resp;
    }

}
