package com.yipin.liuwanr.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.vo.UserInfoVO;
import com.yipin.liuwanr.vo.UserVO;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.helper.ExcelImportHelper;
import com.yipin.liuwanr.mapper.StaffMapper;
import com.yipin.liuwanr.mapper.UserMapper;


@Service
public class StaffService {
	
	private static Logger logger = Logger.getLogger(StaffService.class);
	
	@Autowired
	private StaffMapper staffMapper;
	
	@Autowired
	private UserMapper userMapper;
	
	/**
	  * 读取员工表
	  * @param file
	  * @return
	  */
	 @Transactional
	 public HashMap<String, Object> readStaff(MultipartFile file,Integer schoolId){
	  HashMap<String, Object> resp = new HashMap<String, Object>();
	  try {
		  //读取excel文件中的员工信息
	   List<Staff> staffs = ExcelImportHelper.readStaff(file);
	   List<UserM> users = new ArrayList<UserM>();
	   //循环员工信息，将员工信息与用户信息进行对比
	   for (int i = 0; i < staffs.size(); i++) {
	    Staff staff=staffs.get(i);
	    staff.setSchoolId(schoolId);

	    Staff sta=staffMapper.getStaff(staff);
	    if(sta!=null) {
	     //专业
	     staff.setStaffProfessionalArchitectureId(sta.getStaffProfessionalArchitectureId());
	     //部门
	     staff.setStaffGradeId(sta.getStaffGradeId());

	     UserM user=new UserM();
	     //用户名称
	     user.setName(staff.getStaffName());
	     //用户密码
	     user.setPassword("huoran123");
	     //用户角色
	     user.setAccountRole(staff.getRoleId());
	     //工号
	     user.setWorkNumber(staff.getWorkNumber());
	     //手机号
	     user.setPhone(staff.getPhone());
	     //邮箱
	     user.setEmail(staff.getEmail());
	     //唯一标识性账号
	     user.setUniqueIdentificationAccount(staff.getUniqueIdentificationAccount());
	     //学校id
	     user.setSchoolId(schoolId);
	     users.add(user);
	    }else {
	     staffs.remove(i);
	     i--;
	    }

	   }
	   if(!staffs.isEmpty()&&staffs.size()>0) {
	    //批量插入读取的员工信息
	    staffMapper.batchAddStaff(staffs);
	    //批量插入用户信息
	    userMapper.addUserM(users);
	   }

	   resp.put("retcode", 200);
	  } catch (RuntimeException e) {
	   logger.error(e.getMessage());
	   resp.put("retcode", 500);
	   resp.put("retvalue", "Import failed");
	   return resp;
	  }
	  return resp;
	 }

//	 //添加员工
//	public HashMap<String, Object> addStaff(Staff staff){
//		HashMap<String, Object> resp = new HashMap<String, Object>();
//		try {
//			staffMapper.addStaff(staff);
//			resp.put("retcode", 200);
//		} catch (RuntimeException e) {
//			logger.error(e.getMessage());
//			resp.put("retcode", 500);
//			resp.put("retvalue", "Inquiry Failed");
//			return resp;
//		}
//		return resp;
//	}
//
//	//查询员工
//	public HashMap<String, Object> queryStaff(UserInfo userInfo, Integer pageNo, Integer pageSize){
//		HashMap<String, Object> resp = new HashMap<String, Object>();
//		try {
//			if(pageNo!=null&&pageSize!=null) {
//				PageHelper.startPage(pageNo, pageSize);
//				List<UserInfo> list = staffMapper.queryStaff(userInfo);
//				PageInfo<UserInfo> info=new PageInfo<UserInfo>(list);
//				int total1 = (int) info.getTotal();
//				int totalPages;
//				totalPages = total1 / pageSize;
//				if (total1 % pageSize != 0){
//					totalPages ++;
//			}
//				long total = total1;
//				resp.put("retvalue", new PageResult(total, list,totalPages));
//				resp.put("retcode", 200);
//			}else {
//				List<UserInfo> list = staffMapper.queryStaff(userInfo);
//				resp.put("retvalue", list);
//				resp.put("retcode", 200);
//			}
//		} catch (RuntimeException e) {
//			logger.error(e.getMessage());
//			resp.put("retcode", 500);
//			resp.put("retvalue", "Inquiry Failed");
//			return resp;
//		}
//		return resp;
//	}

	//删除员工
	public HashMap<String, Object> deleteStaff(List<OrganizationRelationship> OrganizationRelationshipList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			Integer size = OrganizationRelationshipList.size();
			for (int i = 0;i<size;i++){
				Integer organizationRelationshipId = OrganizationRelationshipList.get(i).getOrganizationRelationshipId();
				staffMapper.deleteStaff(organizationRelationshipId);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除员工失败！");
			return resp;
		}
		return resp;
	}

	//查询员工详情
	public HashMap<String, Object> queryStaffDetails(Integer userId,Integer roleId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			obj.put("staff", staffMapper.queryStaffDetails(userId,roleId));
			obj.put("user", staffMapper.queryStaffDetailsU(userId));
			obj.put("roleId", staffMapper.queryRole(userId));
			resp.put("retvalue",obj);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//修改员工
	public HashMap<String, Object> updateStaff(UserVO vo){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		Staff staff = vo.getStaff();
		UserM user = vo.getUser();
		try {
			staffMapper.updateStaff(staff);
			staffMapper.updateUser(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改员工失败！");
			return resp;
		}
		return resp;
	}

	//修改员工
	@Transactional
	public HashMap<String, Object> updateNewStaff(UserInfoVO vo){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		OrganizationRelationship OR = vo.getOrganizationRelationship();
		UserInfo userInfo = vo.getUserInfo();
		try {
			staffMapper.updateNewStaff(OR);
			staffMapper.updateNewUser(userInfo);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改员工失败！");
			throw new RuntimeException();
		}
		return resp;
	}

		//查询员工
	public HashMap<String, Object> queryStaff(UserInfo userInfo, Integer pageNo, Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<UserInfo> list = staffMapper.queryStaff(userInfo);
				PageInfo<UserInfo> info=new PageInfo<UserInfo>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
			}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<UserInfo> list = staffMapper.queryStaff(userInfo);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//添加员工
	public HashMap<String, Object> addStaff(Staff staff){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			staffMapper.addStaff(staff);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}
}
