package com.yipin.liuwanr.service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.PersonalFile;
import com.yipin.liuwanr.vo.UserVO;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.entity.PageResult;
import com.yipin.liuwanr.entity.Student;
import com.yipin.liuwanr.entity.UserM;
import com.yipin.liuwanr.helper.ExcelImportHelper;
import com.yipin.liuwanr.mapper.StudentMapper;
import com.yipin.liuwanr.mapper.UserMapper;

/**
 *
 * 
 * @author 宁智勇
 *
 */
@Service
public class StudentService {

	private static Logger logger = Logger.getLogger(StudentService.class);

	@Autowired
	private StudentMapper studentMapper;

	@Autowired
	private UserMapper userMapper;

	//添加学生
	public HashMap<String, Object> addStudent(Student student) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			studentMapper.addStudent(student);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> queryStudentByProfessionalIds(Integer professionalId,Integer pageNo, Integer pageSize ,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if (pageNo != null && pageSize != null) {
				PageHelper.startPage(pageNo, pageSize);
				List<Student> list = studentMapper.queryStudentByProfessionalIds(professionalId,schoolId);
				PageInfo<Student> info = new PageInfo<Student>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0) {
					totalPages++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list, totalPages));
				resp.put("retcode", 200);
			}else{

				List<Student> list = studentMapper.queryStudentByProfessionalIds(professionalId,schoolId);
				resp.put("retcode",200);
				resp.put("retvalue",list);
			}
		}catch (RuntimeException e){
			logger.error(e.getMessage());
			resp.put("retcode",500);
			resp.put("retvalue","Inquiry Failed");
			return resp;
		}
		return resp;
	}
	public HashMap<String, Object> queryStudentByGradeIds(Integer gradeId,Integer pageNo, Integer pageSize ,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if (pageNo != null && pageSize != null) {
				PageHelper.startPage(pageNo, pageSize);
				List<Student> list = studentMapper.queryStudentByProfessionalIds(gradeId,schoolId);
				PageInfo<Student> info = new PageInfo<Student>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0) {
					totalPages++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list, totalPages));
				resp.put("retcode", 200);
			}else{
				List<Student> list = studentMapper.queryStudentByGradeIds(gradeId,schoolId);
				resp.put("retcode",200);
				resp.put("retvalue",list);
			}
		}catch (RuntimeException e){
			logger.error(e.getMessage());
			resp.put("retcode",500);
			resp.put("retvalue","Inquiry Failed");
			return resp;
		}
		return resp;


//		List<Student> list = studentMapper.queryStudentByProfessionalIds(professionalIds,schoolId);

	}
	public HashMap<String, Object> queryStudentByClassIds(Integer classId,Integer pageNo, Integer pageSize ,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if (pageNo != null && pageSize != null) {
				PageHelper.startPage(pageNo, pageSize);
				List<Student> list = studentMapper.queryStudentByClassIds(classId,schoolId);
				PageInfo<Student> info = new PageInfo<Student>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0) {
					totalPages++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list, totalPages));
				resp.put("retcode", 200);
			}else{
				List<Student> list = studentMapper.queryStudentByClassIds(classId,schoolId);
				resp.put("retcode",200);
				resp.put("retvalue",list);
			}
		}catch (RuntimeException e){
			logger.error(e.getMessage());
			resp.put("retcode",500);
			resp.put("retvalue","Inquiry Failed");
			return resp;
		}
		return resp;
	}


	public HashMap<String, Object> deleteStudent(Integer studentId,String phone) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			studentMapper.deleteStudent(studentId);
			studentMapper.deleteUser(phone);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> queryStudentDetails(Integer studentId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", studentMapper.queryStudentDetailsUser(studentId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> updateStudent(UserVO vo) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		Student student = vo.getStudent();
		UserM user = vo.getUser();
		try {
			studentMapper.updateStudent(student);
			studentMapper.updateUser(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改学生失败！");
			return resp;
		}
		return resp;
	}

    //——————————————————————————————————全承珠
	// 学生是否在考核
	public HashMap<String, Object> queryStudentisAssess(List<Student> students) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			// 查询出来的学生信息
			List<Student> stu = studentMapper.queryStudentisAssess(students);
			// 用来储存正在参与其他考核的学生
			List<Student> studentIsassess = new ArrayList<Student>();
			for (int i = 0; i < stu.size(); i++) {
				if (stu.get(i).getIsAssess() != 0) {
					studentIsassess.add(stu.get(i));
				}
			}
			resp.put("retcode", 200);
			resp.put("retvalue", studentIsassess);
		} catch (Exception e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	/**
	 * 批量导入学生
	 * 
	 * @param classId
	 * @param file
	 * @return
	 */
	@Transactional
	public HashMap<String, Object> readStudent(Integer schoolId,MultipartFile file) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			// 读取excel文件中的学生信息
			List<Student> students = ExcelImportHelper.readStudent(file);
			List<UserM> users = new ArrayList<UserM>();
			// 循环员工信息，将员工信息与用户信息进行对比
			for (int i = 0; i < students.size(); i++) {
				Student student = students.get(i);
				// 学校id
				student.setSchoolId(schoolId);

				Student stu=studentMapper.getStudent(student);

				if(stu!=null) {
					// 专业id
					student.setProfessionalId(stu.getProfessionalId());
					// 年级
					student.setGradeId(stu.getGradeId());
					//班级
					student.setClassId(stu.getClassId());

					UserM user = new UserM();
					// 用户名称
					user.setName(student.getStudentName());
					// 用户密码
					user.setPassword("huoran123");
					// 用户角色
					user.setAccountRole(student.getRoleId());
					// 工号
					user.setWorkNumber(student.getWorkNumber());
					// 手机号
					user.setPhone(student.getPhone());
					// 邮箱
					user.setEmail(student.getEmail());
					// 唯一标识性账号
					user.setUniqueIdentificationAccount(student.getUniqueIdentificationAccount());
					// 学校id
					user.setSchoolId(schoolId);

					users.add(user);

				}else {
					students.remove(i);
					i--;
				}
			}
			if (!students.isEmpty() && students.size() > 0) {
				// 批量添加学生
				studentMapper.bacthAddStudent(students);
				// 批量添加用户
				userMapper.addUserM(users);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

}
