package com.yipin.liuwanr.service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.function.Consumer;

import org.ansj.domain.Result;
import org.ansj.domain.Term;
import org.ansj.splitWord.analysis.NlpAnalysis;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.yipin.liuwanr.entity.Comment;
import com.yipin.liuwanr.entity.Topic;
import com.yipin.liuwanr.helper.CommonDefine;
import com.yipin.liuwanr.helper.RandomUtil;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.mapper.TopicMapper;

@Service
public class TopicService {

	private static Logger logger = Logger.getLogger(TopicService.class);

	@Autowired
	TopicMapper topicMapper;
	
	@Autowired
	RedisHelper redisHelper;
	
	public HashMap<String, Object> detail(String uuid, String tuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retcode", 200);
			Topic t = topicMapper.getById(uuid,tuid);
			t.setComments(topicMapper.getCommentByTopic(uuid, tuid));
			switch(t.getType()){
			case CommonDefine.TOPIC_NORMAL:
				t.setPraises(topicMapper.getUsersByTopic(tuid, CommonDefine.COMMENT_PRAISE));
				break;
			case CommonDefine.TOPIC_QUESTION:
				t.setFollows(topicMapper.getUsersByTopic(tuid, CommonDefine.COMMENT_FOLLOW));
				break;
				default:
					break;
			}
			ret.put("retvalue", t);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Query Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> list(String uuid, String buuid, int type) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retcode", 200);
			if(0 == type){
				ret.put("retvalue", topicMapper.getAllByUser(buuid));
			}
			else{
				ret.put("retvalue", topicMapper.getTypeByUser(buuid, type));
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Create Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> around(String uuid, double latitude, double longitude) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retcode", 200);
			ret.put("retvalue", topicMapper.getByLocation(latitude+0.05, latitude-0.05, longitude+0.05, longitude-0.05));
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Search Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> tags(String uuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			ret.put("retcode", 200);
			ret.put("retvalue", new ArrayList<String>());
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Search Failed");
		}
		return ret;
	}

	public HashMap<String, Object> create(Topic topic) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			topic.setTuid(RandomUtil.getUUID());
			topicMapper.create(topic);
			topic.setCreatetime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
			ret.put("retcode", 200);
			ret.put("retvalue", topic);
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Create Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> delete(String uuid, String tuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if (0 < topicMapper.checkTopic(uuid, tuid)){
				topicMapper.delete(tuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> comment(Comment comment) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		ret.put("retcode", 200);
		ret.put("retvalue", "Operation Done");
		try {
			switch (comment.getType()) {
			case CommonDefine.COMMENT_TEXT:
				String cuid = RandomUtil.getUUID();
				comment.setCuid(cuid);
				topicMapper.comment(comment);
				ret.put("retvalue", topicMapper.getCommentById(cuid));
				break;
			case CommonDefine.COMMENT_PRAISE:
				topicMapper.topicOpinion(comment.getTuid(), comment.getUuid(), CommonDefine.COMMENT_PRAISE);
				break;
			case CommonDefine.COMMENT_FOLLOW:
				topicMapper.topicOpinion(comment.getTuid(), comment.getUuid(), CommonDefine.COMMENT_FOLLOW);
				break;
			case CommonDefine.COMMENT_AGREE:
			case CommonDefine.COMMENT_OBJECT:
				if (0 < topicMapper.checkOpinion(comment.getUuid(), comment.getTocuid())){
					topicMapper.updateCommentOpinion(comment.getTocuid(), comment.getUuid(), comment.getType());
				}
				else{
					topicMapper.insertCommentOpinion(comment.getTocuid(), comment.getUuid(), comment.getType());
				}
				break;
			case -CommonDefine.COMMENT_PRAISE:
				topicMapper.deleteOpinionToTopic(comment.getTuid(), comment.getUuid(), CommonDefine.COMMENT_PRAISE);
				break;
			case -CommonDefine.COMMENT_FOLLOW:
				topicMapper.deleteOpinionToTopic(comment.getTuid(), comment.getUuid(), CommonDefine.COMMENT_FOLLOW);
				break;
			case -CommonDefine.COMMENT_AGREE:
				topicMapper.deleteOpinionToComment(comment.getTocuid(), comment.getUuid(), CommonDefine.COMMENT_AGREE);
				break;
			case -CommonDefine.COMMENT_OBJECT:
				topicMapper.deleteOpinionToComment(comment.getTocuid(), comment.getUuid(), CommonDefine.COMMENT_OBJECT);
				break;
			default:
				break;
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Comment Failed");
		}
		return ret;
	}
	
	public HashMap<String, Object> deleteComment(String uuid, String cuid) {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		try {
			if (0 < topicMapper.checkComment(uuid, cuid)){
				topicMapper.deleteComment(cuid);
				ret.put("retcode", 200);
				ret.put("retvalue", "Operation Done");
			}
			else{
				ret.put("retcode", 400);
				ret.put("retvalue", "Ownership Check Failed");
			}
		} catch (RuntimeException e) {
			logger.info(e.getMessage());
			ret.put("retcode", 500);
			ret.put("retvalue", "Delete Failed");
		}
		return ret;
	}
	
	@Scheduled(cron = "* * 0/1 * * *")
    public void scheduled(){
		//redisHelper.opsForValue().get("tag_list");
    }
	
	public void cacheHeat(String content){
		Result parse = NlpAnalysis.parse(content);
		//parse.forEach(new TermAction());
	}
	
	class TermAction implements Consumer<Term>{
		
		/*private final Set<String> expectedNature = new HashSet<String>() {{
	        add("v");
	        add("vd");
	        add("vn");
	        add("vf");
	        add("vx");
	        add("vi");
	        add("vl");
	        add("vg");
	        add("n");
	        add("nt");
	        add("nz");
	        add("nw");
	        add("nl");
	        add("ng");
	        add("wh");
	    }};*/
	    
		@Override
		public void accept(Term t) {
			if(t.getNatureStr().startsWith("v") || t.getNatureStr().startsWith("n")){
				JSONObject job = (JSONObject)redisHelper.get("tag_list");
				if(job.containsKey(t.getName())){
					job.put(t.getName(), (int)job.get(t.getName())+1);
				}
				else{
					job.put(t.getName(), 1);
				}
				redisHelper.set("tag_list", job);
			}
		}
	}

}
