package com.yipin.liuwanr.service;

import com.aliyun.oss.OSSClient;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.AliyunOssConfig;
import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.entity.response.UserInfoListRes;
import com.yipin.liuwanr.entity.vo.UserInfoReq;
import com.yipin.liuwanr.helper.OssConfigUtil;
import com.yipin.liuwanr.helper.RandomUtil;
import com.yipin.liuwanr.mapper.*;
import com.yipin.liuwanr.util.MD5;
import com.yipin.liuwanr.util.PageUtils;
import com.yipin.liuwanr.vo.UserInfoReceiveVo;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.core.ValueOperations;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import redis.clients.jedis.JedisCluster;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.TimeUnit;
import java.util.regex.Matcher;
import java.util.regex.Pattern;


@Service
public class UserInfoService {

	private static Logger logger = Logger.getLogger(UserInfoService.class);
	private final static String RETCODE = "retcode";
	private final static String RETVALUE = "retvalue";


	@Autowired
	private StaffMapper staffMapper;
	@Autowired
	private StudentMapper studentMapper;
	@Autowired
	private UserInfoMapper userInfoMapper;
	@Autowired
	private JedisCluster jedis;
	@Resource
	StringRedisTemplate stringRedisTemplate;
	@Autowired
	private AliyunOssConfig config;
	@Autowired
	private BeanFactory beanFactory;
	@Autowired
	private OrganizationRelationshipMapper organizationRelationshipMapper;

	@Autowired
	private HrUserAccountMapper hrUserAccountMapper;

	public HashMap<String, Object> login(String id, String password){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		User user = null;
		if(null == password || password.isEmpty()){
//			user = userInfoMapper.getSelfBy3rdId(id);
		}else{
			String storedPassword = RandomUtil.parsePassword(password);
//			user = userInfoMapper.getSelfByAccount(id);
			if( null != user){
				logger.info(user.toString());
				logger.info(user.getPassword());
				logger.info(storedPassword);
				if(0 == user.getPassword().compareToIgnoreCase(storedPassword)){
					user.setPassword(null);
					resp.put("retcode", 200);
					resp.put("retvalue", user);
				}
				else{
					resp.put("retcode",500);
					resp.put("retvalue","User/Password Invalid");
				}
			}
		}
		if(null == user){
			resp.put("retcode",400);
			resp.put("retvalue","Account Invalid");
		}
		return resp;
	}

	//查询手机号
	public HashMap<String, Object>queryPhone(String phone) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userInfoMapper.queryPhone(phone));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询手机号失败！");
			return resp;
		}
		return resp;
	}

	//添加用户
	@Transactional
	public HashMap<String, Object> addUser(UserInfo user,Student student,List<Staff> staffList,List<UserProfiles> userProfilesList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		int PLsize = userProfilesList.size();
		String studentWorkNumber = student.getWorkNumber();
		try {
			if(user==null){
				resp.put("retcode", 300);
				resp.put("retvalue", "用户为空,添加用户失败！");
			}else if(PLsize<=0){
				resp.put("retcode", 300);
				resp.put("retvalue", "用户组织架构为空,添加用户失败！");
			}else {
				user.setPassword("huoran123");//设置默认密码
				String  token ="UT_"+UUID.randomUUID().toString().replace("-", "");
				user.setToken(token);

				userInfoMapper.addUser(user);
				Integer userId = user.getUserId();
				if (studentWorkNumber!=null){
					student.setUserId(userId);
					userInfoMapper.userAddStudent(student);
				}
				int size = userProfilesList.size();
//				if (size<=0){
					for (int i = 0;i<size; i++){
						UserProfiles userProfiles = userProfilesList.get(i);
						userProfiles.setUserId(userId);
						userInfoMapper.addPersonalFile(userProfiles);
					}
//				}
				int staffListSize = staffList.size();
				for (int i = 0;i<staffListSize;i++){
					Staff staff = staffList.get(i);
					staff.setUserId(userId);
					userInfoMapper.userAddStaff(staff);
				}
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "添加用户失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//查询用户信息
	public HashMap<String, Object> queryUserInfo(UserInfo userInfo,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<UserInfo> list = userInfoMapper.queryUserInfo(userInfo);
				PageInfo<UserInfo> info=new PageInfo<UserInfo>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<UserInfo> list = userInfoMapper.queryUserInfo(userInfo);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户失败！");
			return resp;
		}
		return resp;
	}
	//删除用户
	@Transactional
	public HashMap<String, Object> deleteUserInfo(List<Integer> userIdList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			int size = userIdList.size();
			for (int i=0;i<size;i++){
				Integer userId=userIdList.get(i);
				userInfoMapper.deleteUser(userId);
				userInfoMapper.deleteStaff(userId);
				userInfoMapper.deleteStudent(userId);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除用户失败");
			throw new RuntimeException();
		}
		return resp;
	}

	//删除用户组织架构
	public HashMap<String, Object> deleteOrganizationRelationship(List<Integer> userIdList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			int size = userIdList.size();
			for (int i=0;i<size;i++){
				Integer userId=userIdList.get(i);
				userInfoMapper.deleteOrganizationRelationship(userId);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除学生失败");
			return resp;
		}
		return resp;
	}

	//更新用户
	@Transactional
	public HashMap<String, Object> updateUser(UserInfo user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.updateUser(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新用户失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新用户
	@Transactional
	public HashMap<String, Object> updateUserRoleId(Integer userId,String roleId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.updateUserRoleId(userId,roleId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新用户失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新个人档案
	@Transactional
	public HashMap<String, Object> updateUserProfiles(List<UserProfiles> userProfilesList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			Integer size = userProfilesList.size();
			Integer userId = userProfilesList.get(0).getUserId();
			userInfoMapper.deleteUserProfiles(userId);
			for (int i=0; i<size; i++){
				UserProfiles userProfiles = userProfilesList.get(i);
				userInfoMapper.updateUserProfiles(userProfiles);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新用户个人档案失败！");
			throw new RuntimeException();
		}
		return resp;
	}

//	//更新用户组织架构
//	@Transactional
//	public HashMap<String, Object> updateOrganizationRelationship(List<OrganizationRelationship> OrganizationRelationshipList){
//		HashMap<String, Object> resp = new HashMap<String, Object>();
//		try {
//			Integer size = OrganizationRelationshipList.size();
//			Integer userId = OrganizationRelationshipList.get(0).getUserId();
//			Integer platformId = OrganizationRelationshipList.get(0).getPlatformId();
//			userInfoMapper.deleteOR(userId,platformId);
//			for (int i=0; i<size; i++){
//				OrganizationRelationship organizationRelationship = OrganizationRelationshipList.get(i);
//				userInfoMapper.updateOrganizationRelationship(organizationRelationship);
//			}
//			resp.put("retcode", 200);
//		} catch (RuntimeException e) {
//			logger.error(e.getMessage());
//			resp.put("retcode", 500);
//			resp.put("retvalue", "更新用户个人档案失败！");
//			throw new RuntimeException();
//		}
//		return resp;
//	}

	//更新用户组织架构
	@Transactional
	public HashMap<String, Object> updateOR(List<Staff> staffList,List<Student> studentList){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if (!staffList.isEmpty()){
				int size = staffList.size();
				Integer userId = staffList.get(0).getUserId();
				Integer platformId = staffList.get(0).getPlatformId();
				userInfoMapper.deleteStaffOR(userId,platformId);
				for (int i=0; i<size; i++){
					Staff staff = staffList.get(i);
					userInfoMapper.userAddStaff(staff);
				}
			}
			if (!studentList.isEmpty()){
				int size = studentList.size();
				Integer userId = studentList.get(0).getUserId();
				Integer platformId = studentList.get(0).getPlatformId();
				userInfoMapper.deleteStudentOR(userId,platformId);
				for (int i=0; i<size; i++){
					Student student = studentList.get(i);
					userInfoMapper.userAddStudent(student);
				}
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新用户个人档案失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新学生
	@Transactional
	public HashMap<String, Object> updateStudent(Student student){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.updateStudent(student);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新学生失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新员工
	@Transactional
	public HashMap<String, Object> updateStaff(Staff staff){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.updateStaff(staff);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新员工失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//登陆获取学校
	public HashMap<String, Object> loginSchool(UserInfo userInfo){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			UserInfo user=userInfoMapper.loginsAP(userInfo);
//			obj.put("user",user);
			if(user!=null) {
				Integer userId = user.getUserId();
				List<UserInfo> staffList = userInfoMapper.loginGetStaffSchool(userId);
				obj.put("staffList",staffList);
				List<UserInfo> studentList = userInfoMapper.loginGetStudentSchool(userId);
				obj.put("studentList",studentList);
				resp.put("retcode", 200);
				resp.put("retvalue", obj);
			}else {
				resp.put("retcode", 300);
				resp.put("retvalue", "登录失败，账号密码有误！");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "登录异常，请稍后再试！");
			return resp;
		}
		return resp;
	}
	//登陆获取学校/电子科大
	public HashMap<String, Object> loginSchoolClient(String account,String password,Integer schoolId,Integer source){
		ValueOperations<String, String> redis = stringRedisTemplate.opsForValue();
		HashMap<String, Object> resp = new HashMap<String, Object>();
		//用户登录失败次数
		String userLoginNum = redis.get(account + "LoginNum");
		if (userLoginNum != null && Integer.valueOf(userLoginNum) > 4) {
			resp.put("retcode", 500);
			resp.put("retvalue", "登录失败次数过多，账户已锁定！");
			return resp;
		}
		HashMap<String, Object> obj = new HashMap<String, Object>();
		UserInfo userInfo = new UserInfo();
		userInfo.setPassword(MD5.encrypt(password));
		userInfo.setSchoolId(schoolId);
		if (source == 0){
			//账号
			userInfo.setAccount(account);
		}else if(source == 1){
			if (checkPhone(account)){
				//手机号
				userInfo.setPhone(account);
			}else if (checkEmail(account)){
				//邮箱
				userInfo.setEmail(account);
			}else {
				//防止邮箱，手机号格式错误 sql能正确执行
				userInfo.setAccount("!@#$%^&*()_+");
			}
		}

		Integer state = userInfoMapper.queryDisableAccount(userInfo);
		if (state==null){
			resp.put("retcode",300);
			resp.put("retvalue","账号不存在");
		}else if (state==0){
			try {
				UserInfo user=userInfoMapper.loginsAP(userInfo);
				//区分密码大小写
				boolean num = false;
				if (user != null){
                    //校验密码
                    num = userInfo.getPassword().equals(user.getPassword());
				}

				if(user!=null && num) {
					Integer userId = user.getUserId();

					List<UserInfo> staffList = userInfoMapper.loginsGetStaffSchoolInfo(userId,schoolId);
					obj.put("staffList",staffList);
//					List<UserInfo> studentList = userInfoMapper.loginsGetStudentSchoolInfo(userId,schoolId);
					List<UserInfoReceiveVo> studentList = userInfoMapper.loginsGetStudentSchoolInfo(userId,schoolId);
					obj.put("studentList",studentList);

					//登录成功删除redis登录失败次数
					redis.getOperations().delete(account + "LoginNum");
					//鉴权，登录后将信息存入redis
					String loginToken = UUID.randomUUID().toString();
					redis.set(loginToken,user.getUserId().toString(),2, TimeUnit.HOURS);
					obj.put("loginToken",loginToken);

					resp.put("retcode", 200);
					resp.put("retvalue", obj);
				}else {
					//记录登录失败次数30分钟
					int loginNum = 1;
					if (userLoginNum != null) loginNum = loginNum + Integer.valueOf(userLoginNum);
					redis.set(account+"LoginNum", String.valueOf(loginNum), 30,TimeUnit.MINUTES);

					resp.put("retcode", 300);
					resp.put("retvalue", "登录失败，密码有误！");
				}
			} catch (RuntimeException e) {
				logger.error(e.getMessage());
				resp.put("retcode", 500);
				resp.put("retvalue", "登录异常，请稍后再试！");
				return resp;
			}

		}else if (state==1){
			resp.put("retcode",400);
			resp.put("retvalue","您的账号已被禁用，请联系管理员");
		}
		return resp;
	}

	//登陆
	public HashMap<String, Object> logins(UserInfo userInfo){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		Integer id = userInfo.getUserId();
		String roleId = userInfo.getRoleId();
		Integer schoolId = userInfo.getSchoolId();
		try {
			SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");//设置日期格式
			String date = df.format(new Date());// new Date()为获取当前系统时间，也可使用当前时间戳
			UserInfo user=userInfoMapper.logins(userInfo);
			String token = user.getToken();
			Integer userId = user.getUserId();
			user.setDataTime(date);
			obj.put("user",user);
			if(id!=null) {
				List<Staff> staffList = userInfoMapper.queryStaffAll(id,roleId,schoolId);
				obj.put("staffList",staffList);
				List<Student> studentList = userInfoMapper.queryStudentAll(id,roleId,schoolId);
				obj.put("studentList",studentList);
				ValueOperations<String, String> redis = stringRedisTemplate.opsForValue();
				redis.set(token,date, 24, TimeUnit.HOURS);
				resp.put("retcode", 200);
				resp.put("retvalue", obj);
			}else {
				resp.put("retcode", 300);
				resp.put("retvalue", "登录失败，账号密码有误或不存在！");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "登录异常，请稍后再试！");
			return resp;
		}
		return resp;
	}

	//登陆
	public HashMap<String, Object> adminLogins(String account,String password,Integer source){
		ValueOperations<String, String> redis = stringRedisTemplate.opsForValue();
		HashMap<String, Object> resp = new HashMap<String, Object>();
		//用户登录失败次数
		String userLoginNum = redis.get(account + "LoginNum");
		if (userLoginNum != null && Integer.valueOf(userLoginNum) > 4) {
			resp.put("retcode", 500);
			resp.put("retvalue", "登录失败次数过多，账户已锁定！");
			return resp;
		}
		UserInfo user = new UserInfo();
		user.setPassword(MD5.encrypt(password));
		try {
			if (source == 0){
				user.setAccount(account);
			}else if (source == 1){
				if (checkPhone(account)){
					//手机号
					user.setPhone(account);
				}else if (checkEmail(account)){
					//邮箱
					user.setEmail(account);
				}else {
					//防止邮箱，手机号格式错误 sql能正确执行
					user.setAccount("!@#$%^&*()_+");
				}
			}
			user = userInfoMapper.adminLogins(user);

			if(user != null){
				if (user.getRoleId().contains("1")){
					user.setSchoolId(null);
				}else {
					Integer schoolId = staffMapper.querySchoolId(user.getUserId());
					user.setSchoolId(schoolId);
				}
			}
			if (user == null){
				//记录登录失败次数30分钟
				int num = 1;
				if (userLoginNum != null) num = num + Integer.valueOf(userLoginNum);
				redis.set(account+"LoginNum", String.valueOf(num), 30,TimeUnit.MINUTES);

				resp.put("retvalue","账号密码有误，请稍后再试！");
				resp.put("retcode", 300);
			}else{
				SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");//设置日期格式
				String lastLoginTime = df.format(new Date());
				user.setLastLoginTime(lastLoginTime);
				//登录成功，重新设置最后登录时间以及登录次数
				userInfoMapper.updateLogInNumber(user);
				String token = user.getToken();
				redis.set(token,lastLoginTime, 24, TimeUnit.HOURS);
				user.setDataTime(lastLoginTime);
				//登录成功删除redis登录失败次数
				redis.getOperations().delete(account + "LoginNum");
				//鉴权，登录后将信息存入redis
				String loginToken = UUID.randomUUID().toString();
				redis.set(loginToken,user.getUserId().toString(),2, TimeUnit.HOURS);
				user.setLoginToken(loginToken);

				resp.put("retvalue",user);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "登陆异常，请稍后再试！");
			return resp;
		}
		return resp;
	}

	//登陆获取角色
	public HashMap<String, Object> loginRole(Integer userId,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			List<Staff> staffList = userInfoMapper.loginStaffRole(userId,schoolId);
			obj.put("staffList",staffList);
			List<Student> studentList = userInfoMapper.loginStudentRole(userId,schoolId);
			obj.put("studentList",studentList);
			resp.put("retcode", 200);
			resp.put("retvalue", obj);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "登录异常，请稍后再试！");
			return resp;
		}
		return resp;
	}

	//查询用户详情
	public HashMap<String, Object> queryUserInfoDetails(Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			UserInfo userInfo = userInfoMapper.queryUserInfoDetails(userId);
			obj.put("userInfo",userInfo);
			if (userInfo!=null){
				List<UserProfiles> userProfiles = userInfoMapper.queryUserProfiles(userId);
				obj.put("userProfilesList",userProfiles);
				List<Platform> staffPlatformList = userInfoMapper.queryUserPlatformStaff(userId);
				obj.put("staffPlatformList",staffPlatformList);
				List<Platform>  studentPlatformList= userInfoMapper.queryUserPlatformStudent(userId);
				obj.put("studentPlatformList",studentPlatformList);
				List<Staff> staffList = userInfoMapper.queryUserStaff(userId);
				obj.put("staffList",staffList);
				List<Student> studentList = userInfoMapper.queryUserStudent(userId);
				obj.put("studentList",studentList);
				resp.put("retvalue", obj);
				resp.put("retcode", 200);
			}else {
				resp.put("retcode", 500);
				resp.put("retvalue", "用户不存在！,查询用户详情失败！");
				return resp;
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户详情失败！");
			return resp;
		}
		return resp;
	}

	//查询用户组织架构详情
	public HashMap<String, Object> queryUserOR(Integer userId,Integer platformId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
//			resp.put("retvalue", userInfoMapper.queryUserOR(userId,platformId));
			obj.put("staff", userInfoMapper.queryStaffOR(userId,platformId));
			obj.put("student", userInfoMapper.queryStudentOR(userId,platformId));
			resp.put("retvalue",obj);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户详情失败！");
			return resp;
		}
		return resp;
	}

	//查询用户档案
	public HashMap<String, Object> queryUserProfiles(Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userInfoMapper.queryUserProfiles(userId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户详情失败！");
			return resp;
		}
		return resp;
	}

	//查询客户
	public HashMap<String, Object> queryCustomer(String searchContent, List<Integer> customerIds){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userInfoMapper.queryCustomer(searchContent,customerIds));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询客户失败！");
			return resp;
		}
		return resp;
	}

	//修改用户头像
	public HashMap<String, Object> uploadUserAvatars(MultipartFile file,Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			OSSClient client=beanFactory.getBean(OSSClient.class);
			FilesResult result=OssConfigUtil.uploadUserAvatars(file, client, config);

			//用户图片路径
			String userAvatars=result.getFileUrl();
			userInfoMapper.updateUserAvatars(userAvatars,userId);
			resp.put("retcode", 200);
			resp.put("retvalue", userAvatars);
		} catch (Exception e) {
			logger.info(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改头像失败！");
			return resp;
		}
		return resp;
	}

	//更新登录次数和时间
	public HashMap<String, Object> updateLogInNumber(UserInfo user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.updateLogInNumber(user);
			UserInfo userInfo = userInfoMapper.queryUser(user);
			String roleId = userInfo.getRoleId();
			if (roleId.contains("3")|roleId.contains("2")){
				//更新员工登录次数和时间
				userInfoMapper.updateStaffLogInNumber(user);
			}
			if (roleId.contains("4")){
				//更新学生登录次数和时间
				userInfoMapper.updateStudentLogInNumber(user);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新登录次数失败！");
			return resp;
		}
		return resp;
	}

	//查询账号是否存在
	public HashMap<String, Object> queryAccountIsExist(String account,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			obj.put("user", userInfoMapper.queryAccountIsExist(account));
			obj.put("OR", userInfoMapper.queryAccountIsExistOR(account,schoolId));
			resp.put("retcode", 200);
			resp.put("retvalue",obj);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询账号是否存在失败！");
			return resp;
		}
		return resp;
	}

	//后端查询账号是否存在
	public HashMap<String, Object> queryServerAccountIsExist(String account){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue",userInfoMapper.queryAccountIsExist(account));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询账号是否存在失败！");
			return resp;
		}
		return resp;
	}

	//查询学号、工号是否存在
	public HashMap<String, Object> queryWorkNumberIsExist(String workNumber,Integer roleId,Integer schoolId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			List<Staff> staffList = userInfoMapper.queryStaffWorkNumberIsExist(workNumber,roleId,schoolId);
			List<Student> studentList = userInfoMapper.queryStudentWorkNumberIsExist(workNumber,roleId,schoolId);
			if (!staffList.isEmpty()){
				obj.put("staffList",staffList);
			}
			if (!studentList.isEmpty()){
				obj.put("studentList",studentList);
			}
			resp.put("retvalue",obj);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//添加个人档案
	public HashMap<String, Object> addPersonalFile(List<UserProfiles> userProfilesList,Integer userId) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			Integer size =  userProfilesList.size();
			for (int i = 0; i < size; i++){
				UserProfiles userProfiles = userProfilesList.get(i);
				userProfiles.setUserId(userId);
				userInfoMapper.addPersonalFile(userProfiles);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "添加个人档案失败");
			return resp;
		}
		return resp;
	}

	//查询平台
	public HashMap<String, Object> queryPlatform(String platformId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userInfoMapper.queryPlatform(platformId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//删除平台
	public HashMap<String, Object> deletePlatform(Integer platformId,Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userInfoMapper.deletePlatform(platformId,userId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//查询员工信息和学生信息
	public HashMap<String, Object> queryStuAndSta(Integer platformId,Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		try {
			obj.put("Staff", userInfoMapper.queryStaff(platformId,userId));
			obj.put("Student", userInfoMapper.queryStudent1(platformId,userId));
			resp.put("retvalue", obj);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//查询token
	public HashMap<String, Object>queryToken(String token) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			boolean tokens = stringRedisTemplate.hasKey(token);
			String data = stringRedisTemplate.opsForValue().get(token);
			if (!tokens){
				resp.put("retvalue",data);
				resp.put("retcode", 200);
			}else{
				resp.put("retvalue",data);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询token失败！");
			return resp;
		}
		return resp;
	}

	public HashMap<String, Object> queryUserIds(){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userInfoMapper.queryUserIds());
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	/**
	 * 验证邮箱
	 * @param email
	 * @return
	 */
	public boolean checkEmail(String email){
		boolean flag = false;
		try{
			Pattern regex = Pattern.compile("^([a-zA-Z]|[0-9])(\\w|\\-)+@[a-zA-Z0-9]+\\.([a-zA-Z]{2,4})$");
			Matcher matcher = regex.matcher(email);
			flag = matcher.matches();
		}catch(Exception e){
			flag = false;
		}
		return flag;
	}

	/**
	 * 验证手机号码
	 * @param phone
	 * @return
	 */
	public  boolean checkPhone(String phone){
		boolean flag = false;
		try{
			Pattern regex = Pattern.compile("^1[3456789]\\d{9}$");
			Matcher matcher = regex.matcher(phone);
			flag = matcher.matches();
		}catch(Exception e){
			flag = false;
		}
		return flag;
	}

	public List queryPage(Integer page, Integer size, UserInfoReq userInfoReq) {
		//分页参数
		if (page <= 0) {
			page = 1;
		}
		if (size <= 0) {
			size = 10;
		}
		List<UserInfoListRes> positionVO = hrUserAccountMapper.pageByCondition(new Page(page, size),userInfoReq);
		return positionVO;
	}


}
