package com.yipin.liuwanr.service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import com.yipin.liuwanr.entity.*;
import com.yipin.liuwanr.mapper.StaffMapper;
import com.yipin.liuwanr.mapper.StudentMapper;
import com.yipin.liuwanr.entity.*;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import com.aliyun.oss.OSSClient;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.yipin.liuwanr.AliyunOssConfig;
import com.yipin.liuwanr.helper.OssConfigUtil;
import com.yipin.liuwanr.helper.RandomUtil;
import com.yipin.liuwanr.mapper.UserMapper;

import redis.clients.jedis.JedisCluster;


@Service
public class UserService {

	private static Logger logger = Logger.getLogger(UserService.class);

	@Autowired
	private UserMapper userMapper;
	@Autowired
	private StaffMapper staffMapper;
	@Autowired
	private StudentMapper studentMapper;

	@Autowired
	private JedisCluster jedis;

	@Autowired
	private AliyunOssConfig config;

	@Autowired
	private BeanFactory beanFactory;

	public HashMap<String, Object> login(String id, String password){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		User user = null;
		if(null == password || password.isEmpty()){
			user = userMapper.getSelfBy3rdId(id);
		}else{
			String storedPassword = RandomUtil.parsePassword(password);
			user = userMapper.getSelfByAccount(id);
			if( null != user){
				logger.info(user.toString());
				logger.info(user.getPassword());
				logger.info(storedPassword);
				if(0 == user.getPassword().compareToIgnoreCase(storedPassword)){
					user.setPassword(null);
					resp.put("retcode", 200);
					resp.put("retvalue", user);
				}
				else{
					resp.put("retcode",500);
					resp.put("retvalue","User/Password Invalid");
				}
			}
		}
		if(null == user){
			resp.put("retcode",400);
			resp.put("retvalue","Account Invalid");
		}
		return resp;
	}


	public HashMap<String, Object> demo(Demo demo) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		try {
			result.put("retcode", 200);
			result.put("retvalue", userMapper.demo(demo));//遍历demo表
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			result.put("retcode", 500);
			result.put("retvalue", "Inquiry Failed");
			return result;
		}
		return result;
	}

	public HashMap<String, Object> insert(Demo demo) {
		HashMap<String, Object> result = new HashMap<String, Object>();
		try {
			userMapper.insertDemo(demo);
			result.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			result.put("retcode", 500);
			result.put("retvalue", "Inquiry Failed");
			return result;
		}
		return result;
	}

	//查询手机号
	public HashMap<String, Object>queryPhone(String phone) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userMapper.queryPhone(phone));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询手机号失败！");
			return resp;
		}
		return resp;
	}

	//添加用户
	public HashMap<String, Object> addUser(UserM user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			user.setPassword("huoran123");//设置默认密码
			userMapper.addUser(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "添加用户失败！");
			return resp;
		}
		return resp;
	}

	//查询用户
	public HashMap<String, Object> queryUser(UserM user,Integer pageNo,Integer pageSize){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if(pageNo!=null&&pageSize!=null) {
				PageHelper.startPage(pageNo, pageSize);
				List<UserM> list = userMapper.queryUser(user);
				PageInfo<UserM> info=new PageInfo<UserM>(list);
				int total1 = (int) info.getTotal();
				int totalPages;
				totalPages = total1 / pageSize;
				if (total1 % pageSize != 0){
					totalPages ++;
				}
				long total = total1;
				resp.put("retvalue", new PageResult(total, list,totalPages));
				resp.put("retcode", 200);
			}else {
				List<UserM> list = userMapper.queryUser(user);
				resp.put("retvalue", list);
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户失败！");
			return resp;
		}
		return resp;
	}

	//删除用户
	public HashMap<String, Object> deleteUser(Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.deleteUser(userId);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除用户失败");
			return resp;
		}
		return resp;
	}

	//批量删除员工
	public HashMap<String, Object> deleteStaff(UserM user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.deleteStaff(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除员工失败");
			return resp;
		}
		return resp;
	}

	//批量删除学生
	public HashMap<String, Object> deleteStudent(UserM user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.deleteStudent(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "删除学生失败");
			return resp;
		}
		return resp;
	}

	//更新用户
	@Transactional
	public HashMap<String, Object> updateUser(UserM user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.updateUser(user);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新用户失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新学生
	@Transactional
	public HashMap<String, Object> updateStudent(Student student){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.updateStudent(student);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新学生失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//更新员工
	@Transactional
	public HashMap<String, Object> updateStaff(Staff staff){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			userMapper.updateStaff(staff);
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新员工失败！");
			throw new RuntimeException();
		}
		return resp;
	}

	//登陆
	public HashMap<String, Object> logins(UserM userM){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		HashMap<String, Object> obj = new HashMap<String, Object>();
		Student student;
		Staff staff;
		try {
			UserM user=userMapper.logins(userM);
			if(user!=null) {
				int loginNumber=user.getLogInNumber()+1;
				Integer userId=user.getUserId();
				long time=System.currentTimeMillis();
				Date date = new Date(time);
				SimpleDateFormat sd = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
				String lastTime=sd.format(date);
				if(user.getAccountRole().equals(4)) {
					student=studentMapper.queryStudentQ(user);
					if(student!=null) {
						Integer studentId=student.getStudentId();
						studentMapper.updateStudentQ(lastTime,loginNumber, studentId);
						obj.put("student",student);
					}
				}else if(user.getAccountRole().equals(3)) {
					staff =staffMapper.queryStaffQ(user);
					if(staff!=null) {
						Integer staffId=staff.getStaffId();
						staffMapper.updateStaffQ(lastTime,loginNumber, staffId);
						obj.put("staff",staff);
					}
				}
				user.setPassword(null);
				obj.put("user",user);
				userMapper.updateUserQ(lastTime,loginNumber, userId);
				resp.put("retcode", 200);
				resp.put("retvalue", obj);
			}else {
				resp.put("retcode", 300);
				resp.put("retvalue", "登录失败，账号密码有误或不存在！");
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "登录异常，请稍后再试！");
			return resp;
		}
		return resp;
	}

	//查询用户详情
	public HashMap<String, Object> queryUserDetails(Integer userId,Integer roleId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			if (roleId == 3){
				resp.put("retvalue", userMapper.queryUserDetailsStaff(userId));
				resp.put("retcode", 200);
			}else if (roleId == 4){
				resp.put("retvalue", userMapper.queryUserDetailsStudent(userId));
				resp.put("retcode", 200);
			}else{
				resp.put("retvalue", userMapper.queryUserDetailsAdmin(userId));
				resp.put("retcode", 200);
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询用户详情失败！");
			return resp;
		}
		return resp;
	}

	//查询客户
	public HashMap<String, Object> queryCustomer(Integer cityId,Integer provinceId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userMapper.queryCustomer(cityId,provinceId));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询客户失败！");
			return resp;
		}
		return resp;
	}

	//修改用户头像
	public HashMap<String, Object> uploadUserAvatars(MultipartFile file,Integer userId){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			OSSClient client=beanFactory.getBean(OSSClient.class);
			FilesResult result=OssConfigUtil.uploadUserAvatars(file, client, config);

			//用户图片路径
			String userAvatars=result.getFileUrl();
			userMapper.updateUserAvatars(userAvatars,userId);
			resp.put("retcode", 200);
			resp.put("retvalue", userAvatars);
		} catch (Exception e) {
			logger.info(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "修改头像失败！");
			return resp;
		}
		return resp;
	}

	//更新登录次数和时间
	public HashMap<String, Object> updateLogInNumber(UserM user){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			Integer accountRole = user.getAccountRole();
			userMapper.updateLogInNumber(user);
			if (accountRole==3){
				//更新员工登录次数和时间
				userMapper.updateStaffLogInNumber(user);
			}
			if (accountRole==4){
				//更新学生登录次数和时间
				userMapper.updateStudentLogInNumber(user);
			}
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "更新登录次数失败！");
			return resp;
		}
		return resp;
	}

	//查询账号是否存在
	public HashMap<String, Object> queryAccountIsExist(String userAccount){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userMapper.queryAccountIsExist(userAccount));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

	//查询学号、工号是否存在
	public HashMap<String, Object> queryWorkNumberIsExist(String workNumber){
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userMapper.queryWorkNumberIsExist(workNumber));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "Inquiry Failed");
			return resp;
		}
		return resp;
	}

    public HashMap<String, Object> queryEmail(String email) {
		HashMap<String, Object> resp = new HashMap<String, Object>();
		try {
			resp.put("retvalue", userMapper.queryEmail(email));
			resp.put("retcode", 200);
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			resp.put("retcode", 500);
			resp.put("retvalue", "查询手机号失败！");
			return resp;
		}
		return resp;
    }
}
