package com.yipin.liuwanr.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yipin.liuwanr.entity.HrUserAccount;
import com.yipin.liuwanr.entity.HrUserInfo;
import com.yipin.liuwanr.entity.UserInfo;
import com.yipin.liuwanr.entity.response.UserAccountListRes;
import com.yipin.liuwanr.entity.response.UserInfoListRes;
import com.yipin.liuwanr.entity.response.UserSysDetailRes;
import com.yipin.liuwanr.entity.vo.UserInfoReq;
import com.yipin.liuwanr.mapper.HrUserAccountMapper;
import com.yipin.liuwanr.mapper.HrUserInfoMapper;
import com.yipin.liuwanr.service.IHrUserAccountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yipin.liuwanr.util.MD5;
import com.yipin.liuwanr.util.PageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 各个平台账号表 服务实现类
 * </p>
 *
 * @author Qyq
 * @since 2021-06-18
 */
@Service
public class HrUserAccountServiceImpl extends ServiceImpl<HrUserAccountMapper, HrUserAccount> implements IHrUserAccountService {
    @Resource
    private HrUserAccountMapper hrUserAccountMapper;
    @Resource
    private HrUserInfoMapper hrUserInfoMapper;

    public List queryPage(Integer page, Integer size, UserInfoReq userInfoReq) {
        //分页参数
        if (page <= 0) {
            page = 1;
        }
        if (size <= 0) {
            size = 10;
        }
        List<UserInfoListRes> positionVO = hrUserAccountMapper.pageByCondition(new Page(page, size),userInfoReq);
        return positionVO;
    }

    public PageUtils queryPage2(Integer page, Integer size, UserInfoReq userInfoReq) {
        //分页参数
        if (page <= 0) {
            page = 1;
        }
        if (size <= 0) {
            size = 10;
        }
        IPage<UserInfoListRes> positionVO = hrUserAccountMapper.pageByCondition2(new Page(page, size));

        return new PageUtils(positionVO);
    }

    @Override
    public int resetPwd(Integer userId) {
        HrUserAccount hrUserAccount = new HrUserAccount();
        hrUserAccount.setPassword(MD5.encrypt("111aaa"));
        return this.getBaseMapper().update(hrUserAccount,new QueryWrapper<HrUserAccount>().eq("user_id",userId));
    }

    @Override
    @Transactional
    public int delUserAccount(Integer userId,Integer isdel) {
        //设置用户表用户为已删除
        HrUserInfo hrUserInfo = new HrUserInfo();
        hrUserInfo.setIsdel(isdel);
        hrUserInfoMapper.update(hrUserInfo,new QueryWrapper<HrUserInfo>().eq("userId",userId));
        //设置账号表与用户相关的所有账号都设置为已删除
        HrUserAccount hrUserAccount = new HrUserAccount();
        hrUserAccount.setIsdel(isdel);
        int userId1 = hrUserAccountMapper.update(hrUserAccount, new QueryWrapper<HrUserAccount>().eq("user_id", userId));
        return userId1;
    }

    @Override
    public UserSysDetailRes selectUserSysBind(Integer userId, Integer platformId) {
        //根据用户id以及平台id将对应的用户及账号信息查询出来
        List<UserAccountListRes> list = hrUserAccountMapper.selectUserSysBindById(userId,platformId);

        //先根据院校分组，再根据平台端分组
        Map<String, Map<Integer, List<UserAccountListRes>>> group2 = list.stream().collect(Collectors.groupingBy(UserAccountListRes::getSchoolName, Collectors.groupingBy(UserAccountListRes::getType)));
        UserSysDetailRes res = new UserSysDetailRes();
        res.setUserId(userId);
        res.setPlatformId(platformId);
        res.setMap(group2);
        return res;
    }

    @Override
    public HrUserAccount selectAccountDetail(Integer accountId) {

        return hrUserAccountMapper.selectOne(new QueryWrapper<HrUserAccount>().eq("id",accountId));
    }
}
