package com.yipin.liuwanr.service.impl;

import com.yipin.liuwanr.entity.SysPermission;
import com.yipin.liuwanr.entity.SysRolePermission;
import com.yipin.liuwanr.mapper.SysPermissionMapper;
import com.yipin.liuwanr.mapper.SysRolePermissionMapper;
import com.yipin.liuwanr.service.ISysPermissionService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.beanutils.ConvertUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 菜单权限表 服务实现类
 * </p>
 *
 * @author Qyq
 * @since 2021-02-26
 */
@Service
public class SysPermissionServiceImpl extends ServiceImpl<SysPermissionMapper, SysPermission> implements ISysPermissionService {
    @Resource
    private SysRolePermissionMapper rolePermissionMapper;

    @Resource
    private SysPermissionMapper permissionMapper;

    @Override
    public List getPermission(String roleIds) {
        //截取字符串
        String[] strArr = roleIds.split(",");
        //转换long类型的数组
        Long[] strArrNum = (Long[]) ConvertUtils.convert(strArr,Long.class);

        //根据角色id查询对应的权限id
        List<SysRolePermission> rolePermissionList = rolePermissionMapper.queryPermissionsByRoleIds(Arrays.asList(strArrNum));
        List<Long> permissionList = new ArrayList();
        for(SysRolePermission res : rolePermissionList){
            permissionList.add(res.getPermissionId());
        }

        if(permissionList.size()>0){
            Long[] permissionIds = permissionList.toArray(new Long[permissionList.size()]);
            //根据权限ids查询对应权限
            List<SysPermission> permissionEntityList = permissionMapper.queryPermissionsByIds(Arrays.asList(permissionIds));
            return getListDepartmentAndEmployeeTree(permissionEntityList, 0L);
        }else{
            return null;
        }

    }

    private List<SysPermission> getListDepartmentAndEmployeeTree(List<SysPermission> list, Long parentId) {
        return list.stream()
                .filter(dept -> parentId.equals(dept.getParentId())) // 过滤出部门id为所选id的部门信息(也为递归的结果条件，找不到所对应的部门id)
                .peek(dept -> {
                    dept.setChildren(getListDepartmentAndEmployeeTree(list, dept.getId())); // 设置该部门的子部门:递归调用

                    //SysPermission permission = permissionService.getById(dept.getId());
                    /*dept.setUserDept(employeeDao.employeeListByDeptId(dept.getId(),account));*/
                })
                .sorted(Comparator.comparingInt(menu -> (menu.getSort() == null ? 0 : menu.getSort()))) // 根据所选排序信息进行排序
                .collect(Collectors.toList());
    }
}
