package com.yipin.liuwanr.tcpserver;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.nio.channels.ServerSocketChannel;
import java.nio.charset.Charset;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;

import org.apache.mina.core.polling.AbstractPollingIoAcceptor;
import org.apache.mina.core.service.IoAcceptor;
import org.apache.mina.core.session.IdleStatus;
import org.apache.mina.filter.codec.ProtocolCodecFilter;
import org.apache.mina.filter.codec.textline.TextLineCodecFactory;
import org.apache.mina.filter.logging.LoggingFilter;
import org.apache.mina.transport.socket.nio.NioSession;
import org.apache.mina.transport.socket.nio.NioSocketAcceptor;
import org.jboss.logging.Logger;

public class MinaContextManager {

	private static Logger logger = Logger.getLogger(MinaContextManager.class);

	private static IoAcceptor acceptor = null;
	
	private static MinaContextManager instance = null;
	
	private int minaPort = 0;
	
	private int minaBufferSize = 0;
	
	private int minaIdleTime = 0;
	
	private MinaContextManager(int port, int bufferSize, int idleTime){
		this.minaPort = port;
		this.minaBufferSize = bufferSize;
		this.minaIdleTime = idleTime;
	}
	
	public static MinaContextManager getInstance(int minaPort, int minaBufferSize, int minaIdleTime){
		if(instance == null){
			instance = new MinaContextManager( minaPort, minaBufferSize, minaIdleTime);
		}
		return instance;
	}

	@PostConstruct
	public void constructInstance() {
		logger.info("Mina Initialized");
	}

	@PreDestroy
	public void destroyInstance(){
		if (acceptor != null) {
			try {
				acceptor.unbind();
				acceptor.dispose();
				logger.info("Mina stoped");
			} catch (Exception e) {
				logger.error(e.getMessage());
			}
		}
	}
	
	public void startServer(TimeServerHandler handler){
		if (acceptor == null) {
			try {
				acceptor = new NioSocketAcceptor();
				acceptor.getFilterChain().addLast("codec", new ProtocolCodecFilter(new TextLineCodecFactory(Charset.forName("UTF-8"))));
				acceptor.getSessionConfig().setReadBufferSize(minaBufferSize);
				acceptor.getSessionConfig().setIdleTime(IdleStatus.BOTH_IDLE, minaIdleTime);
				((NioSocketAcceptor) acceptor).setReuseAddress(true);
				acceptor.setHandler(handler);
				acceptor.bind(new InetSocketAddress(minaPort));
				logger.info("Mina started on port(s): " + minaPort);
			} catch (IOException e) {
				logger.error(e.getMessage());
			}
		}
	}
}