package com.yipin.liuwanr.tcpserver;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.apache.mina.core.service.IoHandler;
import org.apache.mina.core.session.IdleStatus;
import org.apache.mina.core.session.IoSession;
import org.jboss.logging.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSON;
import com.yipin.liuwanr.entity.ImagePart;
import com.yipin.liuwanr.entity.Position;
import com.yipin.liuwanr.entity.Speed;
import com.yipin.liuwanr.entity.UploadInfo;
import com.yipin.liuwanr.helper.CommonDefine;
import com.yipin.liuwanr.helper.GCJWGSUtil;
import com.yipin.liuwanr.helper.OSSHelper;
import com.yipin.liuwanr.helper.RedisHelper;
import com.yipin.liuwanr.helper.SensorUtil;
import com.yipin.liuwanr.mapper.DeviceMapper;

import io.netty.util.internal.StringUtil;

@Service
public class TimeServerHandler implements IoHandler {

	private static Logger logger = Logger.getLogger(TimeServerHandler.class);

	@Autowired
	DeviceMapper deviceMapper;

	@Autowired
	RedisHelper redisHelper;

	@Override
	public void exceptionCaught(IoSession arg0, Throwable arg1) throws Exception {
	}

	@Override
	public void inputClosed(IoSession arg0) throws Exception {
	}

	@Override
	public void messageReceived(IoSession arg0, Object arg1) throws Exception {
		String checkedStr = checkMessage(arg1.toString());
		if (null == checkedStr) {
			arg0.write("MSG|2\r");
		} else {
			String key = StringUtils.left(checkedStr.toString(), 3);
			String value = StringUtils.substring(checkedStr.toString(), 4);
			int ret = handleMessage(arg0, key, value);
			if(ret > -1){
				arg0.write("MSG|" + key + "|" + ret + "\r");
			}
		}
	}

	@Override
	public void messageSent(IoSession arg0, Object arg1) throws Exception {

	}

	@Override
	public void sessionClosed(IoSession arg0) throws Exception {
		MinaSessionManager.removeSession(arg0);
	}

	@Override
	public void sessionCreated(IoSession arg0) throws Exception {
	}

	@Override
	public void sessionIdle(IoSession arg0, IdleStatus arg1) throws Exception {
	}

	@Override
	public void sessionOpened(IoSession arg0) throws Exception {
	}

	private String checkMessage(String msg) {
		int flagindex = msg.indexOf("SG|");
		if (flagindex >= 0) {
			return StringUtils.substring(msg, flagindex + 3).trim();
		}
		return null;
	}

	private int handleMessage(IoSession arg0, String key, String arg1) {
		try {
			switch (key.toUpperCase()) {
			case CommonDefine.TCP_RECV_SAY_HELLO:
				MinaSessionManager.setSessionForDevice(arg1, arg0);
				break;
			case CommonDefine.TCP_RECV_UPLOAD_DATA:
				logger.info(arg0.getAttribute("ID").toString() + ":" + key + ":" + arg1);
				handleData(arg0.getAttribute("ID").toString(), arg1.split("\\|"));
				break;
			case CommonDefine.TCP_RECV_UPLOAD_LOC:
				handleLocation(arg0.getAttribute("ID").toString(), arg1.split("\\|"));
				break;
			case CommonDefine.TCP_RECV_UPLOAD_PIC:
				handleImage(arg0.getAttribute("ID").toString(), arg1.split("\\|"));
				break;
			case CommonDefine.TCP_RECV_SAY_GOODBYE:
				MinaSessionManager.removeSessionByDevice(arg1);
				break;
			default:
				return -1;
			}
		} catch (RuntimeException e) {
			logger.error(e.getMessage());
			return 1;
		}
		return 0;
	}

	private boolean handleData(String id, String[] args) {
		for (String s : args) {
			logger.info(s);
		}
		UploadInfo lastinfo = redisHelper.getLastUploadInfoById(id);
		if (args.length < 12) {
			return false;
		}
		UploadInfo info = new UploadInfo();
		info.setDuid(id);
		double longitude2 = Double.parseDouble(StringUtil.isNullOrEmpty(args[0]) ? "0.00" : args[0]);
		double latitude2 = Double.parseDouble(StringUtil.isNullOrEmpty(args[1]) ? "0.00" : args[1]);
		Position gcj = GCJWGSUtil.toGCJ02Piont(latitude2, longitude2);
		info.setLongitude(gcj.getLongitude());
		info.setLatitude(gcj.getLatitude());
		if (lastinfo != null) {
			info.setDistance(
					SensorUtil.algorithm(lastinfo.getLongitude(), lastinfo.getLatitude(), longitude2, latitude2));
		} else {
			info.setDistance(0.00);
		}
		info.setQuatity(Integer.parseInt(StringUtil.isNullOrEmpty(args[2]) ? "0" : args[2]));
		info.setBssid1(args[3]);
		info.setRssi1(Integer.parseInt(StringUtil.isNullOrEmpty(args[4]) ? "0" : args[4]));
		info.setBssid2(args[5]);
		info.setRssi2(Integer.parseInt(StringUtil.isNullOrEmpty(args[6]) ? "0" : args[6]));
		info.setBssid3(args[7]);
		info.setRssi3(Integer.parseInt(StringUtil.isNullOrEmpty(args[8]) ? "0" : args[8]));
		ArrayList<Speed> gsensor = new ArrayList<Speed>();
		for (int i = 9; i < args.length; i += 3) {
			gsensor.add(
					new Speed(Float.parseFloat(args[i]), Float.parseFloat(args[i + 1]), Float.parseFloat(args[i + 2])));
		}
		info.setGsensorstr(JSON.toJSONString(gsensor));
		info.setGsensor(gsensor);
		int[] moves = SensorUtil.countMoves(gsensor);
		info.setStep(moves[0]);
		info.setJump(moves[1]);
		info.setRoll(moves[2]);
		info.setMove(moves[3]);
		info.setServertime(com.yipin.liuwanr.helper.StringUtils.getCurTime());
		deviceMapper.uploadInfo(info);
		redisHelper.setLastUploadInfoById(id, info);
		return true;
	}

	private boolean handleLocation(String id, String[] args) {
		logger.info(args[0]);
		return true;
	}

	private boolean handleImage(String id, String[] args) {
		ImagePart ip = new ImagePart();
		ip.setImgname(args[0]);
		ip.setTotal(Integer.parseUnsignedInt(args[1]));
		ip.setIndex(Integer.parseUnsignedInt(args[2]));
		ip.setLength(Integer.parseUnsignedInt(args[3]));
		ip.setChecksum(Integer.parseUnsignedInt(args[4]));
		ip.setContent(args[5]);
		logger.info(ip.toString());
		if (ip.getContent().length() != ip.getLength()) {
			throw new RuntimeException("package length invalid");
		}
		List<ImagePart> image;
		if (redisHelper.confirm(args[0])) {
			image = redisHelper.getImageByName(args[0]);
			for(int i=0;i<image.size();i++){
				if(ip.getIndex() == image.get(i).getIndex()){
					image.remove(i);
					break;
				}
			}
			image.add(ip);
		} else {
			image = new ArrayList<ImagePart>();
			image.add(ip);
		}
		if(image.size() == ip.getTotal()){
			Collections.sort(image, new SortByIndex());
			StringBuilder imagebase64 = new StringBuilder();
			for(ImagePart p : image){
				imagebase64.append(p.getContent());
			}
			OSSHelper.getInstance().put(ip.getImgname(), imagebase64.toString());
			redisHelper.remove(ip.getImgname());
		}
		else{
			redisHelper.setImageByName(ip.getImgname(), image);
		}
		return true;
	}

	class SortByIndex implements Comparator<ImagePart> {
		@Override
		public int compare(ImagePart o1, ImagePart o2) {
			return o1.getIndex() - o2.getIndex();
		}
	}
}
