package com.yipin.liuwanr.service;

import com.yipin.liuwanr.entity.Course;
import com.yipin.liuwanr.entity.CourseLink;
import com.yipin.liuwanr.entity.ServiceConfig;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * @auther River
 * @date 2020/8/14 9:26
 */
@SpringBootTest
@RunWith(SpringRunner.class)
public class CourseServiceTest {

    @Autowired
    private CourseService courseService;

    /**
     * 添加课程
     */
    @Test
    @Transactional
    public void addCourseTest(){
        Course course = new Course();
        course.setCourseHours(1);
        course.setCourseIntroduction("这是一个课程简介");
        course.setCourseName("测试课程");
        course.setCourseType(2);
        course.setDisciplineId(2);
        course.setMarketPrice(1);
        course.setProfessionalClassId(5);
        course.setProfessionalId(24);
        course.setSystemId("1");
        course.setTeachingGoal("这是一个教学目标");
        HashMap<String, Object> addCourse = courseService.addCourse(course);
        for (String s : addCourse.keySet()) {
            System.out.println("key:" + s + "," + "value:" + addCourse.get(s));
        }
    }

    /**
     * 添加实训配置
     */
    @Test
    @Transactional
    public void addCoursePCTest(){
        List<ServiceConfig> serviceConfigList = new ArrayList<>();
        ServiceConfig serviceConfig = new ServiceConfig();
        serviceConfig.setCourseId(85);
        serviceConfig.setProjectId(289);
        serviceConfig.setProjectName("练习项目二：基础语法训练——初阶（数据转换与拼接)");
        serviceConfig.setSystemId(1);
        serviceConfig.setSystemName("Python程序设计实训系统");
        serviceConfig.setIsShow(0);
        serviceConfigList.add(serviceConfig);
        HashMap<String, Object> coursePC = courseService.addCoursePC(serviceConfigList);
        for (String s : coursePC.keySet()) {
            System.out.println("key:" + s + "," + "value:" + coursePC.get(s));
        }
    }

    /**
     * 添加项目环节
     */
    @Test
    @Transactional
    public void addCourseLinkTest(){
        List<CourseLink> courseLinkList = new ArrayList<>();
        CourseLink courseLink = new CourseLink();
        courseLink.setCourseId(85);
        courseLink.setLinkId(87);
        courseLink.setFileLink("http://liuwanr.oss-cn-shenzhen.aliyuncs.com/py/20200814/1597370762315.py");
        courseLink.setLinkName("测试环节");
        courseLink.setProjectId(292);
        courseLinkList.add(courseLink);
        HashMap<String, Object> addCourseLink = courseService.addCourseLink(courseLinkList);
        for (String s : addCourseLink.keySet()) {
            System.out.println("key:" + s + "," + "value:" + addCourseLink.get(s));
        }
    }

    /**
     * 查询课程
     */
    @Test
    @Transactional
    public void queryCourseTest(){
        Course course = new Course();
        Integer pageNo = 1;
        Integer pageSize = 10;
        HashMap<String, Object> queryCourse = courseService.queryCourse(course, pageNo, pageSize);
        for (String s : queryCourse.keySet()) {
            System.out.println("key:" + s + "," + "value:" + queryCourse.get(s));
        }
    }

    /**
     * 查询课程详情
     */
    @Test
    @Transactional
    public void queryCourseDetailsTest(){
        Integer courseId = 85;
        HashMap<String, Object> courseDetails = courseService.queryCourseDetails(courseId);
        for (String s : courseDetails.keySet()) {
            System.out.println("key:" + s + "," + "value:" + courseDetails.get(s));
        }
    }

    /**
     * 查询课程名称是否存在
     */
    @Test
    @Transactional
    public void queryCourseNameIsExists(){
        String courseName = "测试课程";
        HashMap<String, Object> isExists = courseService.queryCourseNameIsExists(courseName);
        for (String s : isExists.keySet()) {
            System.out.println("key:" + s + "," + "value:" + isExists.get(s));
        }
    }

    /**
     * 查询课程详情课程权限
     */
    @Test
    @Transactional
    public void queryCourseDetailsTCTest(){
        Integer courseId = 85;
        Integer pageNo = 1;
        Integer pageSize = 10;
        HashMap<String, Object> detailsTC = courseService.queryCourseDetailsTC(courseId, pageNo, pageSize);
        for (String s : detailsTC.keySet()) {
            System.out.println("key:" + s + "," + "value:" + detailsTC.get(s));
        }
    }

    /**
     * 删除课程
     */
    @Test
    @Transactional
    public void deleteCourseTest(){
        List<Integer> courseIds = new ArrayList<>();
        courseIds.add(85);
        HashMap<String, Object> deleteCourse = courseService.deleteCourse(courseIds);
        for (String s : deleteCourse.keySet()) {
            System.out.println("key:" + s + "," + "value:" + deleteCourse.get(s));
        }
    }

    /**
     * 更新课程
     */
    @Test
    @Transactional
    public void updateCourseTest(){
        Course course = new Course();
        course.setCourseId(87);
        course.setCourseHours(1);
        course.setCourseIntroduction("简介");
        course.setCourseName("呵呵");
        course.setCourseType(1);
        course.setDisciplineId(1);
        course.setMarketPrice(2);
        course.setProfessionalClassId(1);
        course.setProfessionalId(1);
        course.setSystemId("1");
        course.setTeachingGoal("目标");
        HashMap<String, Object> updateCourse = courseService.updateCourse(course);
        for (String s : updateCourse.keySet()) {
            System.out.println("key:" + s + "," + "value:" + updateCourse.get(s));
        }
    }

    /**
     * 修改课程实训配置
     */
    @Test
    @Transactional
    public void updateCoursePCTest(){
        ServiceConfig serviceConfig = new ServiceConfig();
        serviceConfig.setCourseId(85);
        serviceConfig.setProjectId(289);
        serviceConfig.setProjectName("练习项目二：基础语法训练——初阶（数据转换与拼接)");
        serviceConfig.setSystemId(1);
        serviceConfig.setSystemName("Python程序设计实训系统");
        serviceConfig.setIsShow(0);
        HashMap<String, Object> coursePC = courseService.updateCoursePC(serviceConfig);
        for (String s : coursePC.keySet()) {
            System.out.println("key:" + s + "," + "value:" + coursePC.get(s));
        }
    }

    /**
     * 删除课程实训配置
     */
    @Test
    @Transactional
    public void deleteCoursePCTest(){
        Integer courseId = 85;
        HashMap<String, Object> coursePC = courseService.deleteCoursePC(courseId);
        for (String s : coursePC.keySet()) {
            System.out.println("key:" + s + "," + "value:" + coursePC.get(s));
        }
    }

    /**
     * 查看学科类别
     */
    @Test
    @Transactional
    public void queryCourseDisciplineTest(){
        HashMap<String, Object> discipline = courseService.queryCourseDiscipline();
        for (String s : discipline.keySet()) {
            System.out.println("key:" + s + "," + "value:" + discipline.get(s));
        }
    }

    /**
     * 查询课程专业类
     */
    @Test
    @Transactional
    public void queryCourseProfessionalClassTest(){
        Integer disciplineId = 1;
        HashMap<String, Object> courseProfessionalClass = courseService.queryCourseProfessionalClass(disciplineId);
        for (String s : courseProfessionalClass.keySet()) {
            System.out.println("key:" + s + "," + "value:" + courseProfessionalClass.get(s));
        }
    }

    /**
     * 查询课程专业
     */
    @Test
    @Transactional
    public void queryCourseProfessionalTest(){
        Integer professionalClassId = 2;
        HashMap<String, Object> courseProfessional = courseService.queryCourseProfessional(professionalClassId);
        for (String s : courseProfessional.keySet()) {
            System.out.println("key:" + s + "," + "value:" + courseProfessional.get(s));
        }
    }

    /**
     * 查询应用配置
     */
    @Test
    @Transactional
    public void queryAppConfigTest(){
        String searchContent = "Python";
        List<Integer> systemId = new ArrayList<>();
        systemId.add(1);
        HashMap<String, Object> appConfig = courseService.queryAppConfig(searchContent, systemId);
        for (String s : appConfig.keySet()) {
            System.out.println("key:" + s + "," + "value:" + appConfig.get(s));
        }
    }

    /**
     * 查询实训配置
     */
    @Test
    @Transactional
    public void queryTrainingConfigTest(){
        Integer courseId = 85;
        HashMap<String, Object> trainingConfig = courseService.queryTrainingConfig(courseId);
        for (String s : trainingConfig.keySet()) {
            System.out.println("key:" + s + "," + "value:" + trainingConfig.get(s));
        }
    }

    /**
     * 绑定实训配置
     */
    @Test
    @Transactional
    public void addTrainingConfigTest(){
        Course course = new Course();
        course.setSystemId("1");
        course.setCourseId(85);
        HashMap<String, Object> trainingConfig = courseService.addTrainingConfig(course);
        for (String s : trainingConfig.keySet()) {
            System.out.println("key:" + s + "," + "value:" + trainingConfig.get(s));
        }
    }

    /**
     * 查询环节详情
     */
    @Test
    @Transactional
    public void queryLinkDetailsTest(){
        CourseLink courseLink = new CourseLink();
        courseLink.setProjectId(289);
        courseLink.setCourseId(77);
        HashMap<String, Object> linkDetails = courseService.queryLinkDetails(courseLink);
        for (String s : linkDetails.keySet()) {
            System.out.println("key:" + s + "," + "value:" + linkDetails.get(s));
        }
    }

    /**
     * 更新环节
     */
    @Test
    @Transactional
    public void updateLinkTest(){
        CourseLink courseLink = new CourseLink();
        courseLink.setFileLink("www.baidu.com");
        courseLink.setProjectId(1);
        courseLink.setLinkName("测试");
        courseLink.setLinkId(1);
        HashMap<String, Object> link = courseService.updateLink(courseLink);
        for (String s : link.keySet()) {
            System.out.println("key:" + s + "," + "value:" + link.get(s));
        }
    }

    /**
     * 删除实训配置
     */
    @Test
    @Transactional
    public void deleteTrainingConfigTest(){
        Course course = new Course();
        course.setCourseId(87);
        HashMap<String, Object> deleteTrainingConfig = courseService.deleteTrainingConfig(course);
        for (String s : deleteTrainingConfig.keySet()) {
            System.out.println("key:" + s + "," + "value:" + deleteTrainingConfig.get(s));
        }
    }

    /**
     * 是否上架课程控制
     */
    @Test
    @Transactional
    public void isShelvesTest(){
        Course course = new Course();
        course.setCourseId(87);
        course.setIsShelves(1);
        HashMap<String, Object> shelves = courseService.isShelves(course);
        for (String s : shelves.keySet()) {
            System.out.println("key:" + s + "," + "value:" + shelves.get(s));
        }
    }

    /**
     * 查询配置
     */
    @Test
    @Transactional
    public void queryConfigTest(){
        String systemId = "1";
        Integer pageNo = 1;
        Integer pageSize = 10;
        HashMap<String, Object> queryConfig = courseService.queryConfig(systemId, pageNo, pageSize);
        for (String s : queryConfig.keySet()) {
            System.out.println("key:" + s + "," + "value:" + queryConfig.get(s));
        }
    }

    /**
     *
     */
    @Test
    @Transactional
    public void platformQueryCourseTest(){
        Integer schoolId = 305;
        HashMap<String, Object> platformQueryCourse = courseService.platformQueryCourse(schoolId);
        for (String s : platformQueryCourse.keySet()) {
            System.out.println("key:" + s + "," + "value:" + platformQueryCourse.get(s));
        }
    }

    /**
     * 获取课程
     */
    @Test
    @Transactional
    public void getcoueseTest(){
        Integer courseId = 87;
        HashMap<String, Object> getcouese = courseService.getcouese(courseId);
        for (String s : getcouese.keySet()) {
            System.out.println("key:" + s + "," + "value:" + getcouese.get(s));
        }
    }
}
